Package: nhlscraper
Title: Scraper for National Hockey League Data
Version: 0.6.1
Authors@R: c(person('Rento', 'Saijo', email = 'rentosaijo0527@gmail.com', role = c('aut', 'cre', 'cph'), comment = c(ORCID = '0009-0008-4919-7349')), person('Lars', 'Skytte', email = 'lars.sunesen.skytte@gmail.com', role = 'ctb'), person('Jack', 'Pallotta', email = 'jackjpallotta@gmail.com', role = 'ctb', comment = c(ORCID = '0009-0004-0744-6977')))
Description: Scrapes and cleans data from the 'NHL' and 'ESPN' APIs into data.frames and lists. Wraps 125+ endpoints documented in <https://github.com/RentoSaijo/nhlscraper/wiki> from high-level multi-season summaries and award winners to low-level decisecond replays and bookmakers' odds, making them more accessible. Features cleaning and visualization tools, primarily for play-by-plays.
License: GPL (>= 3)
Encoding: UTF-8
RoxygenNote: 7.3.3
Depends: R (>= 4.1.0)
Imports: httr2 (>= 1.2.0), jsonlite (>= 2.0.0), xml2 (>= 1.5.0), arrow
        (>= 23.0.0)
Suggests: testthat (>= 3.0.0), knitr (>= 1.50.0), rmarkdown (>= 2.29.0)
Config/testthat/edition: 3
VignetteBuilder: knitr
URL: https://rentosaijo.github.io/nhlscraper/,
        https://github.com/RentoSaijo/nhlscraper
BugReports: https://github.com/RentoSaijo/nhlscraper/issues
Copyright: Copyright: NHL and the NHL Shield are registered trademarks
        of the National Hockey League. NHL and NHL team marks are the
        property of the NHL and its teams.
NeedsCompilation: yes
Packaged: 2026-05-24 13:44:48 UTC; rsai_91
Author: Rento Saijo [aut, cre, cph] (ORCID:
    <https://orcid.org/0009-0008-4919-7349>),
  Lars Skytte [ctb],
  Jack Pallotta [ctb] (ORCID: <https://orcid.org/0009-0004-0744-6977>)
Maintainer: Rento Saijo <rentosaijo0527@gmail.com>
Repository: CRAN
Date/Publication: 2026-05-24 14:10:02 UTC
Built: R 4.6.0; aarch64-apple-darwin23; 2026-05-24 18:43:28 UTC; unix
Archs: nhlscraper.so.dSYM
