# Generated by roxygen2: do not edit by hand

export(add_deltas)
export(add_goalie_biometrics)
export(add_shift_times)
export(add_shooter_biometrics)
export(attendance)
export(award_winners)
export(awards)
export(boxscore)
export(bracket)
export(calculate_expected_goals)
export(calculate_xG)
export(coach_career_statistics)
export(coach_career_stats)
export(coach_franchise_statistics)
export(coach_franchise_stats)
export(coaches)
export(combine_reports)
export(contracts)
export(countries)
export(draft_picks)
export(draft_prospects)
export(draft_rankings)
export(draft_tracker)
export(drafts)
export(draw_NHL_rink)
export(espn_futures)
export(espn_game_odds)
export(espn_game_summary)
export(espn_games)
export(espn_injuries)
export(espn_pbp)
export(espn_play_by_play)
export(espn_player_summary)
export(espn_players)
export(espn_team_summary)
export(espn_teams)
export(espn_transactions)
export(expansion_draft_picks)
export(expansion_drafts)
export(franchise_playoff_situational_results)
export(franchise_season_statistics)
export(franchise_season_stats)
export(franchise_statistics)
export(franchise_stats)
export(franchise_team_statistics)
export(franchise_team_stats)
export(franchise_versus_franchise)
export(franchise_vs_franchise)
export(franchises)
export(game_odds)
export(game_rosters)
export(game_type_now)
export(games)
export(gc_pbp)
export(gc_pbp_raw)
export(gc_pbps)
export(gc_pbps_raw)
export(gc_play_by_play)
export(gc_play_by_play_raw)
export(gc_play_by_plays)
export(gc_play_by_plays_raw)
export(gc_summary)
export(general_managers)
export(get_attendance)
export(get_award_winners)
export(get_awards)
export(get_bracket)
export(get_configuration)
export(get_countries)
export(get_draft_picks)
export(get_draft_rankings)
export(get_draft_tracker)
export(get_drafts)
export(get_espn_athlete)
export(get_espn_athletes)
export(get_espn_coach)
export(get_espn_coach_career)
export(get_espn_coaches)
export(get_espn_event)
export(get_espn_event_odds)
export(get_espn_event_officials)
export(get_espn_event_play_by_play)
export(get_espn_event_stars)
export(get_espn_events)
export(get_espn_futures)
export(get_espn_injuries)
export(get_espn_team)
export(get_espn_teams)
export(get_espn_transactions)
export(get_franchise_season_by_season)
export(get_franchise_team_totals)
export(get_franchise_vs_franchise)
export(get_franchises)
export(get_game_boxscore)
export(get_game_landing)
export(get_game_story)
export(get_games)
export(get_gc_play_by_play)
export(get_glossary)
export(get_goalie_leaders)
export(get_goalie_milestones)
export(get_goalie_statistics)
export(get_goalies)
export(get_officials)
export(get_partner_odds)
export(get_player_game_log)
export(get_player_landing)
export(get_players)
export(get_schedule)
export(get_scoreboards)
export(get_scores)
export(get_season_now)
export(get_seasons)
export(get_series)
export(get_series_schedule)
export(get_shift_charts)
export(get_skater_leaders)
export(get_skater_milestones)
export(get_skater_statistics)
export(get_skaters)
export(get_spotlight_players)
export(get_standings)
export(get_standings_information)
export(get_streams)
export(get_team_prospects)
export(get_team_roster)
export(get_team_roster_statistics)
export(get_team_schedule)
export(get_team_scoreboard)
export(get_team_seasons)
export(get_team_statistics)
export(get_teams)
export(get_tv_schedule)
export(get_venues)
export(get_wsc_play_by_play)
export(glossary)
export(gms)
export(goalie_edge_5_vs_5)
export(goalie_edge_five_versus_five)
export(goalie_edge_leaders)
export(goalie_edge_save_percentage)
export(goalie_edge_seasons)
export(goalie_edge_shot_location)
export(goalie_edge_summary)
export(goalie_game_report)
export(goalie_game_scoring)
export(goalie_game_statistics)
export(goalie_game_stats)
export(goalie_leaders)
export(goalie_milestones)
export(goalie_regular_statistics)
export(goalie_regular_stats)
export(goalie_report_configs)
export(goalie_report_configurations)
export(goalie_scoring)
export(goalie_season_report)
export(goalie_season_statistics)
export(goalie_season_stats)
export(goalie_series_statistics)
export(goalie_series_stats)
export(goalie_statistics)
export(goalie_stats)
export(ig_game_cum_xG)
export(ig_game_cumulative_expected_goals)
export(ig_game_shot_locations)
export(ig_game_shot_locs)
export(location)
export(lottery_odds)
export(officials)
export(penalty_shots)
export(ping)
export(player_game_log)
export(player_seasons)
export(player_summary)
export(players)
export(playoff_season_statistics)
export(playoff_season_stats)
export(ps)
export(pss)
export(replay)
export(replays)
export(roster)
export(roster_statistics)
export(roster_stats)
export(schedule)
export(scores)
export(season_now)
export(seasons)
export(series)
export(series_schedule)
export(shift_chart)
export(shift_chart_summaries)
export(shift_chart_summary)
export(shift_charts)
export(shifts)
export(skater_edge_leaders)
export(skater_edge_seasons)
export(skater_edge_shot_location)
export(skater_edge_shot_speed)
export(skater_edge_skating_distance)
export(skater_edge_skating_speed)
export(skater_edge_summary)
export(skater_edge_zone_time)
export(skater_game_report)
export(skater_leaders)
export(skater_milestones)
export(skater_playoff_statistics)
export(skater_playoff_stats)
export(skater_regular_statistics)
export(skater_regular_stats)
export(skater_report_configs)
export(skater_report_configurations)
export(skater_season_report)
export(skater_season_statistics)
export(skater_season_stats)
export(skater_series_statistics)
export(skater_series_stats)
export(skater_statistics)
export(skater_stats)
export(spotlight_players)
export(standings)
export(standings_rules)
export(streams)
export(team_edge_leaders)
export(team_edge_seasons)
export(team_edge_shot_location)
export(team_edge_shot_speed)
export(team_edge_skating_distance)
export(team_edge_skating_speed)
export(team_edge_summary)
export(team_edge_zone_time)
export(team_game_report)
export(team_logos)
export(team_month_schedule)
export(team_prospects)
export(team_report_configs)
export(team_report_configurations)
export(team_season_report)
export(team_season_schedule)
export(team_season_statistics)
export(team_season_stats)
export(team_seasons)
export(team_week_schedule)
export(teams)
export(tv_schedule)
export(venues)
export(wsc_pbp)
export(wsc_pbp_raw)
export(wsc_pbps)
export(wsc_pbps_raw)
export(wsc_play_by_play)
export(wsc_play_by_play_raw)
export(wsc_play_by_plays)
export(wsc_play_by_plays_raw)
export(wsc_summary)
export(x_game_cum_xG)
export(x_game_cumulative_expected_goals)
export(x_game_shot_locations)
export(x_game_shot_locs)
useDynLib(nhlscraper, .registration = TRUE)
