# Generated by data-raw/build_xg_ridge_specs.R. Do not edit by hand.

XG_RIDGE_MODEL_SPECS <-
list(sd = list(coefficients = c(`(Intercept)` = -3.22787367141254, 
distance = -0.844397672863668, angle = -0.437501387022007, xCoordNorm = 0.382296310281, 
shotType_snap = 0.217161232990873, shotType_slap = 0.145733315294426, 
shotType_tip.in = -0.13813603966555, dDistancePerSecond = 0.134836427724351, 
dDistance = -0.132126819850828, dAnglePerSecond = 0.123949457168983, 
shotType_wrist = 0.113686185991433, dXCoordNormPerSecond = -0.102806393143214, 
dAngle = -0.0889687439678296, avgSecondsElapsedInShiftFor = 0.0884868022674456, 
minSecondsElapsedInShiftFor = 0.0802266848926595, typeDescKeyPrev_giveaway.against = 0.0702133378300738, 
crossedRoyalRoad_yes = 0.0681967805345412, zoneCode_N = -0.0633204449743235, 
shotType_deflected = -0.0429071127228005, typeDescKeyPrev_takeaway.for = 0.0421277255495227, 
zoneCode_O = 0.0411923859370841, typeDescKeyPrev_given.hit = -0.0404519703310082, 
typeDescKeyPrev_takeaway.against = -0.0375644395488907, typeDescKeyPrev_tip.in.shot.on.goal.for = 0.0352867327824331, 
shooterSecondsElapsedSinceLastShift = -0.035112566546137, typeDescKeyPrev_post.missed.shot.for = 0.0344203147638533, 
avgSecondsElapsedInShiftAgainst = 0.033720487370499, typeDescKeyPrev_won.faceoff = -0.0334709291097645, 
typeDescKeyPrev_lost.faceoff = -0.030131186541664, shooterPositionCode_D = -0.0286202481343203, 
typeDescKeyPrev_taken.hit = -0.0285319909038956, fenwickFor = -0.0281533031382358, 
goalDifferential = 0.0270142915900183, shooterSecondsElapsedInShift = -0.0263349221114251, 
typeDescKeyPrev_wrist.shot.on.goal.for = 0.02602013197317, typeDescKeyPrev_wide.missed.shot.against = 0.0255046483641207, 
fenwickDifferential = -0.0247828807747691, goalsFor = 0.0247594881961234, 
maxSecondsElapsedSinceLastShiftAgainst = 0.0244603204179417, 
secondsElapsedInSequence = 0.0244228360648075, shooterAge = -0.0238311761771997, 
goalieAge = -0.022549263746433, typeDescKeyPrev_slap.shot.on.goal.for = 0.0212588950623637, 
typeDescKeyPrev_post.missed.shot.against = -0.0208901510785224, 
minSecondsElapsedInShiftAgainst = 0.0195462135690771, dSecondsElapsedInSequence = -0.0193140139095899, 
goalieWeight = -0.0186592927322434, typeDescKeyPrev_blocked.shot.against = 0.017976944607056, 
dYCoordNormPerSecond = 0.0171236848669715, isRebound_yes = -0.0165133656374864, 
typeDescKeyPrev_blocked.shot.for = -0.0158735257481945, shooterHandCode_R = 0.0150376845568847, 
shooterWeight = 0.014444865405606, secondsElapsedInPeriod = -0.0141852198665849, 
typeDescKeyPrev_other.shot.on.goal.against = 0.0140008988900591, 
corsiDifferential = 0.0133534605788409, periodNumber = 0.0131925230169041, 
minSecondsElapsedSinceLastShiftAgainst = -0.0120736472366711, 
shooterHeight = -0.0115324408919261, minSecondsElapsedSinceLastShiftFor = 0.0111797494599343, 
typeDescKeyPrev_other.missed.shot.against = 0.0111167920596775, 
typeDescKeyPrev_wrist.shot.on.goal.against = 0.0110954905039129, 
goalieHandCode_R = -0.0109638245914837, typeDescKeyPrev_giveaway.for = 0.0108764295886965, 
shooterPositionCode_R = 0.010532602488184, fenwickAgainst = -0.0105081795194286, 
typeDescKeyPrev_snap.shot.on.goal.against = -0.0100832987473275, 
avgSecondsElapsedSinceLastShiftFor = -0.00961730810323688, dYCoordNorm = -0.00959851243408236, 
typeDescKeyPrev_backhand.shot.on.goal.for = -0.00929347666737915, 
typeDescKeyPrev_other.shot.on.goal.for = 0.00922835094399347, 
isHome_yes = 0.00827747447052165, shooterPositionCode_L = 0.00825648614273755, 
typeDescKeyPrev_high.missed.shot.for = 0.00821946846552225, secondsElapsedInGame = 0.00744617590756035, 
goalsAgainst = -0.00718147985175807, isRush_yes = 0.00704239044427655, 
typeDescKeyPrev_tip.in.shot.on.goal.against = 0.00699134666579523, 
typeDescKeyPrev_high.missed.shot.against = 0.00668033204783943, 
maxSecondsElapsedInShiftAgainst = -0.0063570601797447, corsiAgainst = -0.00621187245589276, 
typeDescKeyPrev_snap.shot.on.goal.for = 0.00611463421246356, 
typeDescKeyPrev_deflected.shot.on.goal.against = 0.00576625439102478, 
isBehindNet_yes = -0.0043988220776942, typeDescKeyPrev_wide.missed.shot.for = -0.00415544985638108, 
isPlayoff_yes = -0.00374612055559669, shotsFor = 0.00368301470260814, 
maxSecondsElapsedInShiftFor = 0.00327183376046586, corsiFor = 0.00301798843405002, 
dXCoordNorm = -0.00287523645397623, shotDifferential = 0.00285323849626911, 
typeDescKeyPrev_deflected.shot.on.goal.for = 0.0020058672830322, 
yCoordNorm = 0.00196555392677064, shotType_other = -0.00175697635451625, 
isOvertime_yes = 0.00161471916964574, shotsAgainst = 0.0012302520886071, 
goalieHeight = 0.00114844451058863, typeDescKeyPrev_slap.shot.on.goal.against = -0.00113110575857476, 
maxSecondsElapsedSinceLastShiftFor = 0.000810198009182974, avgSecondsElapsedSinceLastShiftAgainst = -0.000689695743102425, 
typeDescKeyPrev_other.missed.shot.for = 0.000228850375413098), 
    raw_terms = c("distance", "angle", "xCoordNorm", "dDistancePerSecond", 
    "dDistance", "dAnglePerSecond", "dXCoordNormPerSecond", "dAngle", 
    "avgSecondsElapsedInShiftFor", "minSecondsElapsedInShiftFor", 
    "shooterSecondsElapsedSinceLastShift", "avgSecondsElapsedInShiftAgainst", 
    "fenwickFor", "goalDifferential", "shooterSecondsElapsedInShift", 
    "fenwickDifferential", "goalsFor", "maxSecondsElapsedSinceLastShiftAgainst", 
    "secondsElapsedInSequence", "shooterAge", "goalieAge", "minSecondsElapsedInShiftAgainst", 
    "dSecondsElapsedInSequence", "goalieWeight", "dYCoordNormPerSecond", 
    "shooterWeight", "secondsElapsedInPeriod", "corsiDifferential", 
    "periodNumber", "minSecondsElapsedSinceLastShiftAgainst", 
    "shooterHeight", "minSecondsElapsedSinceLastShiftFor", "fenwickAgainst", 
    "avgSecondsElapsedSinceLastShiftFor", "dYCoordNorm", "secondsElapsedInGame", 
    "goalsAgainst", "maxSecondsElapsedInShiftAgainst", "corsiAgainst", 
    "shotsFor", "maxSecondsElapsedInShiftFor", "corsiFor", "dXCoordNorm", 
    "shotDifferential", "yCoordNorm", "shotsAgainst", "goalieHeight", 
    "maxSecondsElapsedSinceLastShiftFor", "avgSecondsElapsedSinceLastShiftAgainst"
    ), active_dummy_terms = c("shotType_snap", "shotType_slap", 
    "shotType_tip.in", "shotType_wrist", "typeDescKeyPrev_giveaway.against", 
    "crossedRoyalRoad_yes", "zoneCode_N", "shotType_deflected", 
    "typeDescKeyPrev_takeaway.for", "zoneCode_O", "typeDescKeyPrev_given.hit", 
    "typeDescKeyPrev_takeaway.against", "typeDescKeyPrev_tip.in.shot.on.goal.for", 
    "typeDescKeyPrev_post.missed.shot.for", "typeDescKeyPrev_won.faceoff", 
    "typeDescKeyPrev_lost.faceoff", "shooterPositionCode_D", 
    "typeDescKeyPrev_taken.hit", "typeDescKeyPrev_wrist.shot.on.goal.for", 
    "typeDescKeyPrev_wide.missed.shot.against", "typeDescKeyPrev_slap.shot.on.goal.for", 
    "typeDescKeyPrev_post.missed.shot.against", "typeDescKeyPrev_blocked.shot.against", 
    "isRebound_yes", "typeDescKeyPrev_blocked.shot.for", "shooterHandCode_R", 
    "typeDescKeyPrev_other.shot.on.goal.against", "typeDescKeyPrev_other.missed.shot.against", 
    "typeDescKeyPrev_wrist.shot.on.goal.against", "goalieHandCode_R", 
    "typeDescKeyPrev_giveaway.for", "shooterPositionCode_R", 
    "typeDescKeyPrev_snap.shot.on.goal.against", "typeDescKeyPrev_backhand.shot.on.goal.for", 
    "typeDescKeyPrev_other.shot.on.goal.for", "isHome_yes", "shooterPositionCode_L", 
    "typeDescKeyPrev_high.missed.shot.for", "isRush_yes", "typeDescKeyPrev_tip.in.shot.on.goal.against", 
    "typeDescKeyPrev_high.missed.shot.against", "typeDescKeyPrev_snap.shot.on.goal.for", 
    "typeDescKeyPrev_deflected.shot.on.goal.against", "isBehindNet_yes", 
    "typeDescKeyPrev_wide.missed.shot.for", "isPlayoff_yes", 
    "typeDescKeyPrev_deflected.shot.on.goal.for", "shotType_other", 
    "isOvertime_yes", "typeDescKeyPrev_slap.shot.on.goal.against", 
    "typeDescKeyPrev_other.missed.shot.for"), active_dummy_by_var = list(
        crossedRoyalRoad = "crossedRoyalRoad_yes", goalieHandCode = "goalieHandCode_R", 
        isBehindNet = "isBehindNet_yes", isHome = "isHome_yes", 
        isOvertime = "isOvertime_yes", isPlayoff = "isPlayoff_yes", 
        isRebound = "isRebound_yes", isRush = "isRush_yes", shooterHandCode = "shooterHandCode_R", 
        shooterPositionCode = c("shooterPositionCode_D", "shooterPositionCode_R", 
        "shooterPositionCode_L"), shotType = c("shotType_snap", 
        "shotType_slap", "shotType_tip.in", "shotType_wrist", 
        "shotType_deflected", "shotType_other"), typeDescKeyPrev = c("typeDescKeyPrev_giveaway.against", 
        "typeDescKeyPrev_takeaway.for", "typeDescKeyPrev_given.hit", 
        "typeDescKeyPrev_takeaway.against", "typeDescKeyPrev_tip.in.shot.on.goal.for", 
        "typeDescKeyPrev_post.missed.shot.for", "typeDescKeyPrev_won.faceoff", 
        "typeDescKeyPrev_lost.faceoff", "typeDescKeyPrev_taken.hit", 
        "typeDescKeyPrev_wrist.shot.on.goal.for", "typeDescKeyPrev_wide.missed.shot.against", 
        "typeDescKeyPrev_slap.shot.on.goal.for", "typeDescKeyPrev_post.missed.shot.against", 
        "typeDescKeyPrev_blocked.shot.against", "typeDescKeyPrev_blocked.shot.for", 
        "typeDescKeyPrev_other.shot.on.goal.against", "typeDescKeyPrev_other.missed.shot.against", 
        "typeDescKeyPrev_wrist.shot.on.goal.against", "typeDescKeyPrev_giveaway.for", 
        "typeDescKeyPrev_snap.shot.on.goal.against", "typeDescKeyPrev_backhand.shot.on.goal.for", 
        "typeDescKeyPrev_other.shot.on.goal.for", "typeDescKeyPrev_high.missed.shot.for", 
        "typeDescKeyPrev_tip.in.shot.on.goal.against", "typeDescKeyPrev_high.missed.shot.against", 
        "typeDescKeyPrev_snap.shot.on.goal.for", "typeDescKeyPrev_deflected.shot.on.goal.against", 
        "typeDescKeyPrev_wide.missed.shot.for", "typeDescKeyPrev_deflected.shot.on.goal.for", 
        "typeDescKeyPrev_slap.shot.on.goal.against", "typeDescKeyPrev_other.missed.shot.for"
        ), zoneCode = c("zoneCode_N", "zoneCode_O")), dummy_term_to_var = c(isPlayoff_yes = "isPlayoff", 
    isPlayoff_unknown = "isPlayoff", isPlayoff_new = "isPlayoff", 
    isHome_yes = "isHome", isHome_unknown = "isHome", isHome_new = "isHome", 
    isOvertime_yes = "isOvertime", isOvertime_unknown = "isOvertime", 
    isOvertime_new = "isOvertime", zoneCode_N = "zoneCode", zoneCode_O = "zoneCode", 
    zoneCode_unknown = "zoneCode", zoneCode_new = "zoneCode", 
    isBehindNet_yes = "isBehindNet", isBehindNet_unknown = "isBehindNet", 
    isBehindNet_new = "isBehindNet", crossedRoyalRoad_yes = "crossedRoyalRoad", 
    crossedRoyalRoad_unknown = "crossedRoyalRoad", crossedRoyalRoad_new = "crossedRoyalRoad", 
    typeDescKeyPrev_backhand.shot.on.goal.for = "typeDescKeyPrev", 
    typeDescKeyPrev_blocked.shot.against = "typeDescKeyPrev", 
    typeDescKeyPrev_blocked.shot.for = "typeDescKeyPrev", typeDescKeyPrev_deflected.shot.on.goal.against = "typeDescKeyPrev", 
    typeDescKeyPrev_deflected.shot.on.goal.for = "typeDescKeyPrev", 
    typeDescKeyPrev_giveaway.against = "typeDescKeyPrev", typeDescKeyPrev_giveaway.for = "typeDescKeyPrev", 
    typeDescKeyPrev_given.hit = "typeDescKeyPrev", typeDescKeyPrev_high.missed.shot.against = "typeDescKeyPrev", 
    typeDescKeyPrev_high.missed.shot.for = "typeDescKeyPrev", 
    typeDescKeyPrev_lost.faceoff = "typeDescKeyPrev", typeDescKeyPrev_other.missed.shot.against = "typeDescKeyPrev", 
    typeDescKeyPrev_other.missed.shot.for = "typeDescKeyPrev", 
    typeDescKeyPrev_other.shot.on.goal.against = "typeDescKeyPrev", 
    typeDescKeyPrev_other.shot.on.goal.for = "typeDescKeyPrev", 
    typeDescKeyPrev_post.missed.shot.against = "typeDescKeyPrev", 
    typeDescKeyPrev_post.missed.shot.for = "typeDescKeyPrev", 
    typeDescKeyPrev_slap.shot.on.goal.against = "typeDescKeyPrev", 
    typeDescKeyPrev_slap.shot.on.goal.for = "typeDescKeyPrev", 
    typeDescKeyPrev_snap.shot.on.goal.against = "typeDescKeyPrev", 
    typeDescKeyPrev_snap.shot.on.goal.for = "typeDescKeyPrev", 
    typeDescKeyPrev_takeaway.against = "typeDescKeyPrev", typeDescKeyPrev_takeaway.for = "typeDescKeyPrev", 
    typeDescKeyPrev_taken.hit = "typeDescKeyPrev", typeDescKeyPrev_tip.in.shot.on.goal.against = "typeDescKeyPrev", 
    typeDescKeyPrev_tip.in.shot.on.goal.for = "typeDescKeyPrev", 
    typeDescKeyPrev_wide.missed.shot.against = "typeDescKeyPrev", 
    typeDescKeyPrev_wide.missed.shot.for = "typeDescKeyPrev", 
    typeDescKeyPrev_won.faceoff = "typeDescKeyPrev", typeDescKeyPrev_wrist.shot.on.goal.against = "typeDescKeyPrev", 
    typeDescKeyPrev_wrist.shot.on.goal.for = "typeDescKeyPrev", 
    typeDescKeyPrev_unknown = "typeDescKeyPrev", typeDescKeyPrev_new = "typeDescKeyPrev", 
    shotType_deflected = "shotType", shotType_other = "shotType", 
    shotType_slap = "shotType", shotType_snap = "shotType", shotType_tip.in = "shotType", 
    shotType_wrist = "shotType", shotType_unknown = "shotType", 
    shotType_new = "shotType", isRebound_yes = "isRebound", isRebound_unknown = "isRebound", 
    isRebound_new = "isRebound", isRush_yes = "isRush", isRush_unknown = "isRush", 
    isRush_new = "isRush", shooterHandCode_R = "shooterHandCode", 
    shooterHandCode_unknown = "shooterHandCode", shooterHandCode_new = "shooterHandCode", 
    shooterPositionCode_D = "shooterPositionCode", shooterPositionCode_L = "shooterPositionCode", 
    shooterPositionCode_R = "shooterPositionCode", shooterPositionCode_unknown = "shooterPositionCode", 
    shooterPositionCode_new = "shooterPositionCode", goalieHandCode_R = "goalieHandCode", 
    goalieHandCode_unknown = "goalieHandCode", goalieHandCode_new = "goalieHandCode"
    ), dummy_term_to_level = c(isPlayoff_yes = "yes", isPlayoff_unknown = "unknown", 
    isPlayoff_new = "new", isHome_yes = "yes", isHome_unknown = "unknown", 
    isHome_new = "new", isOvertime_yes = "yes", isOvertime_unknown = "unknown", 
    isOvertime_new = "new", zoneCode_N = "N", zoneCode_O = "O", 
    zoneCode_unknown = "unknown", zoneCode_new = "new", isBehindNet_yes = "yes", 
    isBehindNet_unknown = "unknown", isBehindNet_new = "new", 
    crossedRoyalRoad_yes = "yes", crossedRoyalRoad_unknown = "unknown", 
    crossedRoyalRoad_new = "new", typeDescKeyPrev_backhand.shot.on.goal.for = "backhand-shot-on-goal-for", 
    typeDescKeyPrev_blocked.shot.against = "blocked-shot-against", 
    typeDescKeyPrev_blocked.shot.for = "blocked-shot-for", typeDescKeyPrev_deflected.shot.on.goal.against = "deflected-shot-on-goal-against", 
    typeDescKeyPrev_deflected.shot.on.goal.for = "deflected-shot-on-goal-for", 
    typeDescKeyPrev_giveaway.against = "giveaway-against", typeDescKeyPrev_giveaway.for = "giveaway-for", 
    typeDescKeyPrev_given.hit = "given-hit", typeDescKeyPrev_high.missed.shot.against = "high-missed-shot-against", 
    typeDescKeyPrev_high.missed.shot.for = "high-missed-shot-for", 
    typeDescKeyPrev_lost.faceoff = "lost-faceoff", typeDescKeyPrev_other.missed.shot.against = "other-missed-shot-against", 
    typeDescKeyPrev_other.missed.shot.for = "other-missed-shot-for", 
    typeDescKeyPrev_other.shot.on.goal.against = "other-shot-on-goal-against", 
    typeDescKeyPrev_other.shot.on.goal.for = "other-shot-on-goal-for", 
    typeDescKeyPrev_post.missed.shot.against = "post-missed-shot-against", 
    typeDescKeyPrev_post.missed.shot.for = "post-missed-shot-for", 
    typeDescKeyPrev_slap.shot.on.goal.against = "slap-shot-on-goal-against", 
    typeDescKeyPrev_slap.shot.on.goal.for = "slap-shot-on-goal-for", 
    typeDescKeyPrev_snap.shot.on.goal.against = "snap-shot-on-goal-against", 
    typeDescKeyPrev_snap.shot.on.goal.for = "snap-shot-on-goal-for", 
    typeDescKeyPrev_takeaway.against = "takeaway-against", typeDescKeyPrev_takeaway.for = "takeaway-for", 
    typeDescKeyPrev_taken.hit = "taken-hit", typeDescKeyPrev_tip.in.shot.on.goal.against = "tip-in-shot-on-goal-against", 
    typeDescKeyPrev_tip.in.shot.on.goal.for = "tip-in-shot-on-goal-for", 
    typeDescKeyPrev_wide.missed.shot.against = "wide-missed-shot-against", 
    typeDescKeyPrev_wide.missed.shot.for = "wide-missed-shot-for", 
    typeDescKeyPrev_won.faceoff = "won-faceoff", typeDescKeyPrev_wrist.shot.on.goal.against = "wrist-shot-on-goal-against", 
    typeDescKeyPrev_wrist.shot.on.goal.for = "wrist-shot-on-goal-for", 
    typeDescKeyPrev_unknown = "unknown", typeDescKeyPrev_new = "new", 
    shotType_deflected = "deflected", shotType_other = "other", 
    shotType_slap = "slap", shotType_snap = "snap", shotType_tip.in = "tip-in", 
    shotType_wrist = "wrist", shotType_unknown = "unknown", shotType_new = "new", 
    isRebound_yes = "yes", isRebound_unknown = "unknown", isRebound_new = "new", 
    isRush_yes = "yes", isRush_unknown = "unknown", isRush_new = "new", 
    shooterHandCode_R = "R", shooterHandCode_unknown = "unknown", 
    shooterHandCode_new = "new", shooterPositionCode_D = "D", 
    shooterPositionCode_L = "L", shooterPositionCode_R = "R", 
    shooterPositionCode_unknown = "unknown", shooterPositionCode_new = "new", 
    goalieHandCode_R = "R", goalieHandCode_unknown = "unknown", 
    goalieHandCode_new = "new"), dummy_map = list(crossedRoyalRoad = c(yes = "crossedRoyalRoad_yes", 
    unknown = "crossedRoyalRoad_unknown", new = "crossedRoyalRoad_new"
    ), goalieHandCode = c(R = "goalieHandCode_R", unknown = "goalieHandCode_unknown", 
    new = "goalieHandCode_new"), isBehindNet = c(yes = "isBehindNet_yes", 
    unknown = "isBehindNet_unknown", new = "isBehindNet_new"), 
        isHome = c(yes = "isHome_yes", unknown = "isHome_unknown", 
        new = "isHome_new"), isOvertime = c(yes = "isOvertime_yes", 
        unknown = "isOvertime_unknown", new = "isOvertime_new"
        ), isPlayoff = c(yes = "isPlayoff_yes", unknown = "isPlayoff_unknown", 
        new = "isPlayoff_new"), isRebound = c(yes = "isRebound_yes", 
        unknown = "isRebound_unknown", new = "isRebound_new"), 
        isRush = c(yes = "isRush_yes", unknown = "isRush_unknown", 
        new = "isRush_new"), shooterHandCode = c(R = "shooterHandCode_R", 
        unknown = "shooterHandCode_unknown", new = "shooterHandCode_new"
        ), shooterPositionCode = c(D = "shooterPositionCode_D", 
        L = "shooterPositionCode_L", R = "shooterPositionCode_R", 
        unknown = "shooterPositionCode_unknown", new = "shooterPositionCode_new"
        ), shotType = c(deflected = "shotType_deflected", other = "shotType_other", 
        slap = "shotType_slap", snap = "shotType_snap", `tip-in` = "shotType_tip.in", 
        wrist = "shotType_wrist", unknown = "shotType_unknown", 
        new = "shotType_new"), typeDescKeyPrev = c(`backhand-shot-on-goal-for` = "typeDescKeyPrev_backhand.shot.on.goal.for", 
        `blocked-shot-against` = "typeDescKeyPrev_blocked.shot.against", 
        `blocked-shot-for` = "typeDescKeyPrev_blocked.shot.for", 
        `deflected-shot-on-goal-against` = "typeDescKeyPrev_deflected.shot.on.goal.against", 
        `deflected-shot-on-goal-for` = "typeDescKeyPrev_deflected.shot.on.goal.for", 
        `giveaway-against` = "typeDescKeyPrev_giveaway.against", 
        `giveaway-for` = "typeDescKeyPrev_giveaway.for", `given-hit` = "typeDescKeyPrev_given.hit", 
        `high-missed-shot-against` = "typeDescKeyPrev_high.missed.shot.against", 
        `high-missed-shot-for` = "typeDescKeyPrev_high.missed.shot.for", 
        `lost-faceoff` = "typeDescKeyPrev_lost.faceoff", `other-missed-shot-against` = "typeDescKeyPrev_other.missed.shot.against", 
        `other-missed-shot-for` = "typeDescKeyPrev_other.missed.shot.for", 
        `other-shot-on-goal-against` = "typeDescKeyPrev_other.shot.on.goal.against", 
        `other-shot-on-goal-for` = "typeDescKeyPrev_other.shot.on.goal.for", 
        `post-missed-shot-against` = "typeDescKeyPrev_post.missed.shot.against", 
        `post-missed-shot-for` = "typeDescKeyPrev_post.missed.shot.for", 
        `slap-shot-on-goal-against` = "typeDescKeyPrev_slap.shot.on.goal.against", 
        `slap-shot-on-goal-for` = "typeDescKeyPrev_slap.shot.on.goal.for", 
        `snap-shot-on-goal-against` = "typeDescKeyPrev_snap.shot.on.goal.against", 
        `snap-shot-on-goal-for` = "typeDescKeyPrev_snap.shot.on.goal.for", 
        `takeaway-against` = "typeDescKeyPrev_takeaway.against", 
        `takeaway-for` = "typeDescKeyPrev_takeaway.for", `taken-hit` = "typeDescKeyPrev_taken.hit", 
        `tip-in-shot-on-goal-against` = "typeDescKeyPrev_tip.in.shot.on.goal.against", 
        `tip-in-shot-on-goal-for` = "typeDescKeyPrev_tip.in.shot.on.goal.for", 
        `wide-missed-shot-against` = "typeDescKeyPrev_wide.missed.shot.against", 
        `wide-missed-shot-for` = "typeDescKeyPrev_wide.missed.shot.for", 
        `won-faceoff` = "typeDescKeyPrev_won.faceoff", `wrist-shot-on-goal-against` = "typeDescKeyPrev_wrist.shot.on.goal.against", 
        `wrist-shot-on-goal-for` = "typeDescKeyPrev_wrist.shot.on.goal.for", 
        unknown = "typeDescKeyPrev_unknown", new = "typeDescKeyPrev_new"
        ), zoneCode = c(N = "zoneCode_N", O = "zoneCode_O", unknown = "zoneCode_unknown", 
        new = "zoneCode_new")), known_levels = list(isPlayoff = c("no", 
    "yes"), isHome = c("no", "yes"), isOvertime = c("no", "yes"
    ), zoneCode = c("D", "N", "O"), isBehindNet = c("no", "yes"
    ), crossedRoyalRoad = c("no", "yes"), typeDescKeyPrev = c("backhand-shot-on-goal-against", 
    "backhand-shot-on-goal-for", "blocked-shot-against", "blocked-shot-for", 
    "deflected-shot-on-goal-against", "deflected-shot-on-goal-for", 
    "giveaway-against", "giveaway-for", "given-hit", "high-missed-shot-against", 
    "high-missed-shot-for", "lost-faceoff", "other-missed-shot-against", 
    "other-missed-shot-for", "other-shot-on-goal-against", "other-shot-on-goal-for", 
    "post-missed-shot-against", "post-missed-shot-for", "slap-shot-on-goal-against", 
    "slap-shot-on-goal-for", "snap-shot-on-goal-against", "snap-shot-on-goal-for", 
    "takeaway-against", "takeaway-for", "taken-hit", "tip-in-shot-on-goal-against", 
    "tip-in-shot-on-goal-for", "wide-missed-shot-against", "wide-missed-shot-for", 
    "won-faceoff", "wrist-shot-on-goal-against", "wrist-shot-on-goal-for"
    ), shotType = c("backhand", "deflected", "other", "slap", 
    "snap", "tip-in", "wrist"), isRebound = c("no", "yes"), isRush = c("no", 
    "yes"), shooterHandCode = c("L", "R"), shooterPositionCode = c("C", 
    "D", "L", "R"), goalieHandCode = c("L", "R")), logical_vars = c("crossedRoyalRoad", 
    "isBehindNet", "isHome", "isOvertime", "isPlayoff", "isRebound", 
    "isRush"), has_unknown = c(crossedRoyalRoad = TRUE, goalieHandCode = TRUE, 
    isBehindNet = TRUE, isHome = TRUE, isOvertime = TRUE, isPlayoff = TRUE, 
    isRebound = TRUE, isRush = TRUE, shooterHandCode = TRUE, 
    shooterPositionCode = TRUE, shotType = TRUE, typeDescKeyPrev = TRUE, 
    zoneCode = TRUE), has_new = c(crossedRoyalRoad = TRUE, goalieHandCode = TRUE, 
    isBehindNet = TRUE, isHome = TRUE, isOvertime = TRUE, isPlayoff = TRUE, 
    isRebound = TRUE, isRush = TRUE, shooterHandCode = TRUE, 
    shooterPositionCode = TRUE, shotType = TRUE, typeDescKeyPrev = TRUE, 
    zoneCode = TRUE), medians = c(distance = 33.9411254969543, 
    angle = 31.8659776936037, xCoordNorm = 64, shotType_snap = 0, 
    shotType_slap = 0, shotType_tip.in = 0, dDistancePerSecond = -1.34742835543301, 
    dDistance = -14.9899563782146, dAnglePerSecond = 0.302473865727572, 
    shotType_wrist = 1, dXCoordNormPerSecond = 1.16666666666667, 
    dAngle = 4.49800470013907, avgSecondsElapsedInShiftFor = 26.2, 
    minSecondsElapsedInShiftFor = 13, typeDescKeyPrev_giveaway.against = 0, 
    crossedRoyalRoad_yes = 0, zoneCode_N = 0, shotType_deflected = 0, 
    typeDescKeyPrev_takeaway.for = 0, zoneCode_O = 1, typeDescKeyPrev_given.hit = 0, 
    typeDescKeyPrev_takeaway.against = 0, typeDescKeyPrev_tip.in.shot.on.goal.for = 0, 
    shooterSecondsElapsedSinceLastShift = 164, typeDescKeyPrev_post.missed.shot.for = 0, 
    avgSecondsElapsedInShiftAgainst = 31, typeDescKeyPrev_won.faceoff = 0, 
    typeDescKeyPrev_lost.faceoff = 0, shooterPositionCode_D = 0, 
    typeDescKeyPrev_taken.hit = 0, fenwickFor = 20, goalDifferential = 0, 
    shooterSecondsElapsedInShift = 26, typeDescKeyPrev_wrist.shot.on.goal.for = 0, 
    typeDescKeyPrev_wide.missed.shot.against = 0, fenwickDifferential = 0, 
    goalsFor = 1, maxSecondsElapsedSinceLastShiftAgainst = 221, 
    secondsElapsedInSequence = 47, shooterAge = 28, goalieAge = 28, 
    typeDescKeyPrev_slap.shot.on.goal.for = 0, typeDescKeyPrev_post.missed.shot.against = 0, 
    minSecondsElapsedInShiftAgainst = 18, dSecondsElapsedInSequence = 10, 
    goalieWeight = 201, typeDescKeyPrev_blocked.shot.against = 0, 
    dYCoordNormPerSecond = 0, isRebound_yes = 0, typeDescKeyPrev_blocked.shot.for = 0, 
    shooterHandCode_R = 0, shooterWeight = 201, secondsElapsedInPeriod = 574, 
    typeDescKeyPrev_other.shot.on.goal.against = 0, corsiDifferential = 1, 
    periodNumber = 2, minSecondsElapsedSinceLastShiftAgainst = 112, 
    shooterHeight = 73, minSecondsElapsedSinceLastShiftFor = 105, 
    typeDescKeyPrev_other.missed.shot.against = 0, typeDescKeyPrev_wrist.shot.on.goal.against = 0, 
    goalieHandCode_R = 0, typeDescKeyPrev_giveaway.for = 0, shooterPositionCode_R = 0, 
    fenwickAgainst = 20, typeDescKeyPrev_snap.shot.on.goal.against = 0, 
    avgSecondsElapsedSinceLastShiftFor = 163.6, dYCoordNorm = 0, 
    typeDescKeyPrev_backhand.shot.on.goal.for = 0, typeDescKeyPrev_other.shot.on.goal.for = 0, 
    isHome_yes = 1, shooterPositionCode_L = 0, typeDescKeyPrev_high.missed.shot.for = 0, 
    secondsElapsedInGame = 1736, goalsAgainst = 1, isRush_yes = 0, 
    typeDescKeyPrev_tip.in.shot.on.goal.against = 0, typeDescKeyPrev_high.missed.shot.against = 0, 
    maxSecondsElapsedInShiftAgainst = 43, corsiAgainst = 27, 
    typeDescKeyPrev_snap.shot.on.goal.for = 0, typeDescKeyPrev_deflected.shot.on.goal.against = 0, 
    isBehindNet_yes = 0, typeDescKeyPrev_wide.missed.shot.for = 0, 
    isPlayoff_yes = 0, shotsFor = 13, maxSecondsElapsedInShiftFor = 38, 
    corsiFor = 28, dXCoordNorm = 12, shotDifferential = 0, typeDescKeyPrev_deflected.shot.on.goal.for = 0, 
    yCoordNorm = 0, shotType_other = 0, isOvertime_yes = 0, shotsAgainst = 13, 
    goalieHeight = 75, typeDescKeyPrev_slap.shot.on.goal.against = 0, 
    maxSecondsElapsedSinceLastShiftFor = 214, avgSecondsElapsedSinceLastShiftAgainst = 169.6, 
    typeDescKeyPrev_other.missed.shot.for = 0), normalize_means = c(distance = 36.3007994468372, 
    angle = 34.3283512744358, xCoordNorm = 59.2567478984105, 
    shotType_snap = 0.174876369376314, shotType_slap = 0.105616999407412, 
    shotType_tip.in = 0.0870999375947223, dDistancePerSecond = -7.20523105149532, 
    dDistance = -32.9401886746547, dAnglePerSecond = 0.405452701172801, 
    shotType_wrist = 0.521839225125728, dXCoordNormPerSecond = 7.01635321671675, 
    dAngle = 1.38695676867213, avgSecondsElapsedInShiftFor = 27.3430355185671, 
    minSecondsElapsedInShiftFor = 15.9005501103892, typeDescKeyPrev_giveaway.against = 0.0792966558112948, 
    crossedRoyalRoad_yes = 0.441913272396415, zoneCode_N = 0.0287955781403227, 
    shotType_deflected = 0.0186429211962934, typeDescKeyPrev_takeaway.for = 0.0402540261892401, 
    zoneCode_O = 0.960831510994342, typeDescKeyPrev_given.hit = 0.0871156700176728, 
    typeDescKeyPrev_takeaway.against = 0.0146993271767118, typeDescKeyPrev_tip.in.shot.on.goal.for = 0.0100163092784586, 
    shooterSecondsElapsedSinceLastShift = 195.380750856106, typeDescKeyPrev_post.missed.shot.for = 0.00592587931133941, 
    avgSecondsElapsedInShiftAgainst = 32.5713774785119, typeDescKeyPrev_won.faceoff = 0.146217138901562, 
    typeDescKeyPrev_lost.faceoff = 0.0723691455721096, shooterPositionCode_D = 0.303688204353686, 
    typeDescKeyPrev_taken.hit = 0.114290808594098, fenwickFor = 21.0978556707519, 
    goalDifferential = -0.0893916272045058, shooterSecondsElapsedInShift = 28.6568863437325, 
    typeDescKeyPrev_wrist.shot.on.goal.for = 0.0686510496148178, 
    typeDescKeyPrev_wide.missed.shot.against = 0.0242646403305906, 
    fenwickDifferential = 0.623444456680773, goalsFor = 1.29255489304574, 
    maxSecondsElapsedSinceLastShiftAgainst = 259.220426977959, 
    secondsElapsedInSequence = 65.9611671360173, shooterAge = 27.7450193771009, 
    goalieAge = 28.6089076978745, typeDescKeyPrev_slap.shot.on.goal.for = 0.0118832234685797, 
    typeDescKeyPrev_post.missed.shot.against = 0.00190886731798898, 
    minSecondsElapsedInShiftAgainst = 21.247061970014, dSecondsElapsedInSequence = 14.4934212251362, 
    goalieWeight = 201.744442521593, typeDescKeyPrev_blocked.shot.against = 0.0398344949105612, 
    dYCoordNormPerSecond = 0.118797340663537, isRebound_yes = 0.102423317548469, 
    typeDescKeyPrev_blocked.shot.for = 0.0963820671354929, shooterHandCode_R = 0.375254996355322, 
    shooterWeight = 201.209293666651, secondsElapsedInPeriod = 581.135828495613, 
    typeDescKeyPrev_other.shot.on.goal.against = 0.00052441409834862, 
    corsiDifferential = 0.944842125135692, periodNumber = 1.97567767411859, 
    minSecondsElapsedSinceLastShiftAgainst = 137.961539470027, 
    shooterHeight = 73.2677763268988, minSecondsElapsedSinceLastShiftFor = 129.907178704592, 
    typeDescKeyPrev_other.missed.shot.against = 0.00144738291144219, 
    typeDescKeyPrev_wrist.shot.on.goal.against = 0.0227071304584952, 
    goalieHandCode_R = 0.0529343590873097, typeDescKeyPrev_giveaway.for = 0.0284756855403301, 
    shooterPositionCode_R = 0.174205119330428, fenwickAgainst = 20.4744112140711, 
    typeDescKeyPrev_snap.shot.on.goal.against = 0.00771937552769169, 
    avgSecondsElapsedSinceLastShiftFor = 189.955641384665, dYCoordNorm = 0.202214076323228, 
    typeDescKeyPrev_backhand.shot.on.goal.for = 0.0107190241702458, 
    typeDescKeyPrev_other.shot.on.goal.for = 0.00287378925895044, 
    isHome_yes = 0.508172993722763, shooterPositionCode_L = 0.201831254031433, 
    typeDescKeyPrev_high.missed.shot.for = 0.0042162893507229, 
    secondsElapsedInGame = 1751.94903743792, goalsAgainst = 1.38194652025025, 
    isRush_yes = 0.0751275637294233, typeDescKeyPrev_tip.in.shot.on.goal.against = 0.00301013692452108, 
    typeDescKeyPrev_high.missed.shot.against = 0.00190886731798898, 
    maxSecondsElapsedInShiftAgainst = 45.287704062636, corsiAgainst = 28.4937883150051, 
    typeDescKeyPrev_snap.shot.on.goal.for = 0.0215848842880292, 
    typeDescKeyPrev_deflected.shot.on.goal.against = 0.00071844731473761, 
    isBehindNet_yes = 0.0210604701896806, typeDescKeyPrev_wide.missed.shot.for = 0.0684727488213793, 
    isPlayoff_yes = 0.0639522992936142, shotsFor = 14.1932675718054, 
    maxSecondsElapsedInShiftFor = 39.578580830567, corsiFor = 29.4386304401408, 
    dXCoordNorm = 32.2281568417685, shotDifferential = 0.340003880664328, 
    typeDescKeyPrev_deflected.shot.on.goal.for = 0.00234413101961833, 
    yCoordNorm = 0.559964130075673, shotType_other = 0.0170382140553467, 
    isOvertime_yes = 0.00318843771795961, shotsAgainst = 13.8532636911411, 
    goalieHeight = 74.9203100336149, typeDescKeyPrev_slap.shot.on.goal.against = 0.00436312529826052, 
    maxSecondsElapsedSinceLastShiftFor = 252.561972636072, avgSecondsElapsedSinceLastShiftAgainst = 196.324328094438, 
    typeDescKeyPrev_other.missed.shot.for = 0.00285805683599998
    ), normalize_sds = c(distance = 23.7965266074563, angle = 22.5379315511933, 
    xCoordNorm = 23.698385334075, shotType_snap = 0.379862319157004, 
    shotType_slap = 0.30734759510749, shotType_tip.in = 0.281982189948842, 
    dDistancePerSecond = 26.6574028380376, dDistance = 60.3035150311097, 
    dAnglePerSecond = 14.0976613368947, shotType_wrist = 0.499524130335086, 
    dXCoordNormPerSecond = 27.9095640411456, dAngle = 37.7462322925232, 
    avgSecondsElapsedInShiftFor = 13.3763328136724, minSecondsElapsedInShiftFor = 13.2996730659043, 
    typeDescKeyPrev_giveaway.against = 0.270201922750787, crossedRoyalRoad_yes = 0.496615772428559, 
    zoneCode_N = 0.167231992992742, shotType_deflected = 0.135260706155197, 
    typeDescKeyPrev_takeaway.for = 0.196554934219564, zoneCode_O = 0.19399617479603, 
    typeDescKeyPrev_given.hit = 0.282005225316335, typeDescKeyPrev_takeaway.against = 0.120346719564196, 
    typeDescKeyPrev_tip.in.shot.on.goal.for = 0.0995792891517513, 
    shooterSecondsElapsedSinceLastShift = 114.117774308454, typeDescKeyPrev_post.missed.shot.for = 0.0767515091571383, 
    avgSecondsElapsedInShiftAgainst = 16.781545415302, typeDescKeyPrev_won.faceoff = 0.353324697499104, 
    typeDescKeyPrev_lost.faceoff = 0.25909883132144, shooterPositionCode_D = 0.459850832151485, 
    typeDescKeyPrev_taken.hit = 0.318164973754328, fenwickFor = 13.726685831327, 
    goalDifferential = 1.64550956996529, shooterSecondsElapsedInShift = 18.0840546271316, 
    typeDescKeyPrev_wrist.shot.on.goal.for = 0.252860472007036, 
    typeDescKeyPrev_wide.missed.shot.against = 0.153870048158856, 
    fenwickDifferential = 9.26362662352026, goalsFor = 1.37955533874177, 
    maxSecondsElapsedSinceLastShiftAgainst = 123.470202092802, 
    secondsElapsedInSequence = 62.041377883281, shooterAge = 4.1775147554224, 
    goalieAge = 3.73765834905587, typeDescKeyPrev_slap.shot.on.goal.for = 0.10836085107495, 
    typeDescKeyPrev_post.missed.shot.against = 0.0436489809144454, 
    minSecondsElapsedInShiftAgainst = 15.6667165744879, dSecondsElapsedInSequence = 14.6259743066056, 
    goalieWeight = 15.6274708019463, typeDescKeyPrev_blocked.shot.against = 0.195570725067292, 
    dYCoordNormPerSecond = 11.3885682057416, isRebound_yes = 0.303204986242277, 
    typeDescKeyPrev_blocked.shot.for = 0.295115267307653, shooterHandCode_R = 0.48418995601075, 
    shooterWeight = 15.4987256298557, secondsElapsedInPeriod = 342.168747397364, 
    typeDescKeyPrev_other.shot.on.goal.against = 0.0228941441612783, 
    corsiDifferential = 12.3909219329857, periodNumber = 0.815371370627598, 
    minSecondsElapsedSinceLastShiftAgainst = 96.4462724200546, 
    shooterHeight = 2.1603020920171, minSecondsElapsedSinceLastShiftFor = 93.5658440505107, 
    typeDescKeyPrev_other.missed.shot.against = 0.0380170431975969, 
    typeDescKeyPrev_wrist.shot.on.goal.against = 0.148968564002121, 
    goalieHandCode_R = 0.223903049594715, typeDescKeyPrev_giveaway.for = 0.166327886875221, 
    shooterPositionCode_R = 0.379286765052536, fenwickAgainst = 13.4425846646873, 
    typeDescKeyPrev_snap.shot.on.goal.against = 0.0875204372611295, 
    avgSecondsElapsedSinceLastShiftFor = 88.3246457971612, dYCoordNorm = 31.6148668192733, 
    typeDescKeyPrev_backhand.shot.on.goal.for = 0.102976610455359, 
    typeDescKeyPrev_other.shot.on.goal.for = 0.0535307913408025, 
    isHome_yes = 0.499934508575746, shooterPositionCode_L = 0.401367965512214, 
    typeDescKeyPrev_high.missed.shot.for = 0.0647960976643637, 
    secondsElapsedInGame = 1027.24828127115, goalsAgainst = 1.44212169204754, 
    isRush_yes = 0.263597756591535, typeDescKeyPrev_tip.in.shot.on.goal.against = 0.0547822210060903, 
    typeDescKeyPrev_high.missed.shot.against = 0.0436489809144611, 
    maxSecondsElapsedInShiftAgainst = 24.3221059695226, corsiAgainst = 18.436756204371, 
    typeDescKeyPrev_snap.shot.on.goal.for = 0.145324078561471, 
    typeDescKeyPrev_deflected.shot.on.goal.against = 0.0267943074764607, 
    isBehindNet_yes = 0.143586332580056, typeDescKeyPrev_wide.missed.shot.for = 0.252556065033873, 
    isPlayoff_yes = 0.244668585309574, shotsFor = 9.46069044666863, 
    maxSecondsElapsedInShiftFor = 20.3630538539914, corsiFor = 18.8919707756306, 
    dXCoordNorm = 63.6463974344396, shotDifferential = 6.72140058907313, 
    typeDescKeyPrev_deflected.shot.on.goal.for = 0.0483595733396074, 
    yCoordNorm = 20.9149926069331, shotType_other = 0.129414068578287, 
    isOvertime_yes = 0.0563763092997843, shotsAgainst = 9.32646008471507, 
    goalieHeight = 1.61614230921098, typeDescKeyPrev_slap.shot.on.goal.against = 0.0659098719237357, 
    maxSecondsElapsedSinceLastShiftFor = 121.777046220713, avgSecondsElapsedSinceLastShiftAgainst = 90.4660313322339, 
    typeDescKeyPrev_other.missed.shot.for = 0.0533844855029514
    )), ev = list(coefficients = c(`(Intercept)` = -2.25155785904054, 
distance = -0.347012229429611, xCoordNorm = 0.229999108551498, 
angle = -0.174994363438993, shotType_snap = 0.145936085503686, 
avgSecondsElapsedInShiftFor = 0.0898990756364799, minSecondsElapsedInShiftFor = 0.0720914431918606, 
dSecondsElapsedInSequence = -0.0696285655862927, dAngle = -0.0678013689318382, 
typeDescKeyPrev_blocked.shot.for = -0.0666122449768758, dYCoordNorm = -0.0638430600428616, 
typeDescKeyPrev_blocked.shot.against = 0.0636371112323108, skaterCountAgainst = -0.0528435860439824, 
skaterCountFor = -0.0527855486675944, maxSecondsElapsedSinceLastShiftAgainst = -0.0495230428049249, 
avgSecondsElapsedInShiftAgainst = 0.0493007292224438, typeDescKeyPrev_giveaway.for = -0.0492839712471866, 
shooterPositionCode_D = -0.049031024183541, goalieHeight = -0.0473969637256579, 
typeDescKeyPrev_snap.shot.on.goal.for = 0.0464459550897196, isOvertime_yes = 0.0452560520475805, 
shotType_other = 0.0410296776203072, typeDescKeyPrev_wide.missed.shot.for = 0.0397997077971771, 
shotType_slap = 0.0397204841984181, shooterAge = 0.038703571493319, 
yCoordNorm = 0.0378832804932377, minSecondsElapsedInShiftAgainst = -0.0377906726576768, 
typeDescKeyPrev_other.missed.shot.for = 0.0365039439199717, goalDifferential = 0.0357258666252162, 
shooterHeight = -0.0350959752911113, typeDescKeyPrev_slap.shot.on.goal.for = -0.0332647259629092, 
periodNumber = 0.0327434254012294, typeDescKeyPrev_post.missed.shot.against = 0.0318868242011377, 
secondsElapsedInPeriod = -0.0316863631429213, typeDescKeyPrev_other.shot.on.goal.against = -0.0312787235006244, 
goalieAge = -0.0311850034308387, isPlayoff_yes = 0.0311549466779367, 
shooterWeight = 0.0310840996328743, typeDescKeyPrev_other.missed.shot.against = -0.0303716771271543, 
typeDescKeyPrev_taken.hit = -0.029281756109804, secondsElapsedInGame = 0.0289393307626774, 
secondsElapsedInSequence = 0.0288725476196743, shooterSecondsElapsedInShift = -0.028651118078253, 
typeDescKeyPrev_deflected.shot.on.goal.against = 0.028558684185321, 
shooterHandCode_R = -0.028056280811865, isRebound_yes = 0.0274926666377523, 
typeDescKeyPrev_backhand.shot.on.goal.for = 0.0273577300523961, 
typeDescKeyPrev_wrist.shot.on.goal.for = -0.0262563696596323, 
dAnglePerSecond = 0.0231147942223715, shooterPositionCode_R = -0.0213845904825497, 
typeDescKeyPrev_high.missed.shot.against = 0.0208008275446357, 
typeDescKeyPrev_high.missed.shot.for = -0.0206650575069266, manDifferential = 0.0202193700845522, 
isEmptyNetFor_yes = -0.0202141432077523, strengthState_penalty.kill = -0.0202088288953459, 
crossedRoyalRoad_yes = 0.0192980466396642, goalsAgainst = -0.0186230791850835, 
shotDifferential = -0.0185359608649035, zoneCode_N = 0.0184457101547008, 
dDistance = -0.0176378458648437, typeDescKeyPrev_tip.in.shot.on.goal.against = -0.0160982096257462, 
avgSecondsElapsedSinceLastShiftFor = -0.0157103199246219, goalieWeight = -0.0152153593170259, 
goalsFor = 0.0150770515532062, typeDescKeyPrev_slap.shot.on.goal.against = 0.0150504779729718, 
isRush_yes = 0.014948055888642, shooterSecondsElapsedSinceLastShift = 0.0141531119762345, 
zoneCode_O = -0.0138612803071167, typeDescKeyPrev_wrist.shot.on.goal.against = 0.0138083614985251, 
typeDescKeyPrev_lost.faceoff = -0.013563344406401, dYCoordNormPerSecond = 0.0130970192951924, 
maxSecondsElapsedSinceLastShiftFor = -0.0123017284800889, typeDescKeyPrev_takeaway.for = 0.012009113841486, 
dDistancePerSecond = 0.0116636565547126, typeDescKeyPrev_takeaway.against = -0.0111772776346153, 
avgSecondsElapsedSinceLastShiftAgainst = 0.0111355704578853, 
minSecondsElapsedSinceLastShiftAgainst = 0.010842317888819, shooterPositionCode_L = 0.0106325588754725, 
typeDescKeyPrev_other.shot.on.goal.for = -0.0105668226674142, 
maxSecondsElapsedInShiftAgainst = 0.0101818505831751, shotType_tip.in = -0.00988285488611214, 
shotType_wrist = -0.00936561921955064, maxSecondsElapsedInShiftFor = 0.0090398975683844, 
shotsFor = -0.00873401704679281, typeDescKeyPrev_giveaway.against = 0.00861189558962555, 
typeDescKeyPrev_deflected.shot.on.goal.for = -0.00854385624926819, 
isBehindNet_yes = 0.00844849209793505, typeDescKeyPrev_post.missed.shot.for = 0.00842037504275693, 
shotType_deflected = -0.0078876736972527, typeDescKeyPrev_wide.missed.shot.against = -0.00785643985547647, 
typeDescKeyPrev_given.hit = -0.00751605764518238, goalieHandCode_R = 0.00697824891204184, 
shotsAgainst = 0.00619507992616124, corsiAgainst = 0.00613275107026916, 
corsiDifferential = -0.0057903029006726, typeDescKeyPrev_snap.shot.on.goal.against = -0.0054970538655398, 
typeDescKeyPrev_won.faceoff = 0.00404869186959835, fenwickDifferential = 0.00291784666289579, 
dXCoordNorm = -0.00197008239839765, dXCoordNormPerSecond = 0.00192187690157279, 
fenwickFor = 0.00191725567402822, typeDescKeyPrev_tip.in.shot.on.goal.for = 0.00167054654121044, 
isHome_yes = 0.00149003273855938, corsiFor = 0.00121776686340797, 
fenwickAgainst = -0.000407966324717708, minSecondsElapsedSinceLastShiftFor = 0.000317195784304764
), raw_terms = c("distance", "xCoordNorm", "angle", "avgSecondsElapsedInShiftFor", 
"minSecondsElapsedInShiftFor", "dSecondsElapsedInSequence", "dAngle", 
"dYCoordNorm", "skaterCountAgainst", "skaterCountFor", "maxSecondsElapsedSinceLastShiftAgainst", 
"avgSecondsElapsedInShiftAgainst", "goalieHeight", "shooterAge", 
"yCoordNorm", "minSecondsElapsedInShiftAgainst", "goalDifferential", 
"shooterHeight", "periodNumber", "secondsElapsedInPeriod", "goalieAge", 
"shooterWeight", "secondsElapsedInGame", "secondsElapsedInSequence", 
"shooterSecondsElapsedInShift", "dAnglePerSecond", "manDifferential", 
"goalsAgainst", "shotDifferential", "dDistance", "avgSecondsElapsedSinceLastShiftFor", 
"goalieWeight", "goalsFor", "shooterSecondsElapsedSinceLastShift", 
"dYCoordNormPerSecond", "maxSecondsElapsedSinceLastShiftFor", 
"dDistancePerSecond", "avgSecondsElapsedSinceLastShiftAgainst", 
"minSecondsElapsedSinceLastShiftAgainst", "maxSecondsElapsedInShiftAgainst", 
"maxSecondsElapsedInShiftFor", "shotsFor", "shotsAgainst", "corsiAgainst", 
"corsiDifferential", "fenwickDifferential", "dXCoordNorm", "dXCoordNormPerSecond", 
"fenwickFor", "corsiFor", "fenwickAgainst", "minSecondsElapsedSinceLastShiftFor"
), active_dummy_terms = c("shotType_snap", "typeDescKeyPrev_blocked.shot.for", 
"typeDescKeyPrev_blocked.shot.against", "typeDescKeyPrev_giveaway.for", 
"shooterPositionCode_D", "typeDescKeyPrev_snap.shot.on.goal.for", 
"isOvertime_yes", "shotType_other", "typeDescKeyPrev_wide.missed.shot.for", 
"shotType_slap", "typeDescKeyPrev_other.missed.shot.for", "typeDescKeyPrev_slap.shot.on.goal.for", 
"typeDescKeyPrev_post.missed.shot.against", "typeDescKeyPrev_other.shot.on.goal.against", 
"isPlayoff_yes", "typeDescKeyPrev_other.missed.shot.against", 
"typeDescKeyPrev_taken.hit", "typeDescKeyPrev_deflected.shot.on.goal.against", 
"shooterHandCode_R", "isRebound_yes", "typeDescKeyPrev_backhand.shot.on.goal.for", 
"typeDescKeyPrev_wrist.shot.on.goal.for", "shooterPositionCode_R", 
"typeDescKeyPrev_high.missed.shot.against", "typeDescKeyPrev_high.missed.shot.for", 
"isEmptyNetFor_yes", "strengthState_penalty.kill", "crossedRoyalRoad_yes", 
"zoneCode_N", "typeDescKeyPrev_tip.in.shot.on.goal.against", 
"typeDescKeyPrev_slap.shot.on.goal.against", "isRush_yes", "zoneCode_O", 
"typeDescKeyPrev_wrist.shot.on.goal.against", "typeDescKeyPrev_lost.faceoff", 
"typeDescKeyPrev_takeaway.for", "typeDescKeyPrev_takeaway.against", 
"shooterPositionCode_L", "typeDescKeyPrev_other.shot.on.goal.for", 
"shotType_tip.in", "shotType_wrist", "typeDescKeyPrev_giveaway.against", 
"typeDescKeyPrev_deflected.shot.on.goal.for", "isBehindNet_yes", 
"typeDescKeyPrev_post.missed.shot.for", "shotType_deflected", 
"typeDescKeyPrev_wide.missed.shot.against", "typeDescKeyPrev_given.hit", 
"goalieHandCode_R", "typeDescKeyPrev_snap.shot.on.goal.against", 
"typeDescKeyPrev_won.faceoff", "typeDescKeyPrev_tip.in.shot.on.goal.for", 
"isHome_yes"), active_dummy_by_var = list(crossedRoyalRoad = "crossedRoyalRoad_yes", 
    goalieHandCode = "goalieHandCode_R", isBehindNet = "isBehindNet_yes", 
    isEmptyNetFor = "isEmptyNetFor_yes", isHome = "isHome_yes", 
    isOvertime = "isOvertime_yes", isPlayoff = "isPlayoff_yes", 
    isRebound = "isRebound_yes", isRush = "isRush_yes", shooterHandCode = "shooterHandCode_R", 
    shooterPositionCode = c("shooterPositionCode_D", "shooterPositionCode_R", 
    "shooterPositionCode_L"), shotType = c("shotType_snap", "shotType_other", 
    "shotType_slap", "shotType_tip.in", "shotType_wrist", "shotType_deflected"
    ), strengthState = "strengthState_penalty.kill", typeDescKeyPrev = c("typeDescKeyPrev_blocked.shot.for", 
    "typeDescKeyPrev_blocked.shot.against", "typeDescKeyPrev_giveaway.for", 
    "typeDescKeyPrev_snap.shot.on.goal.for", "typeDescKeyPrev_wide.missed.shot.for", 
    "typeDescKeyPrev_other.missed.shot.for", "typeDescKeyPrev_slap.shot.on.goal.for", 
    "typeDescKeyPrev_post.missed.shot.against", "typeDescKeyPrev_other.shot.on.goal.against", 
    "typeDescKeyPrev_other.missed.shot.against", "typeDescKeyPrev_taken.hit", 
    "typeDescKeyPrev_deflected.shot.on.goal.against", "typeDescKeyPrev_backhand.shot.on.goal.for", 
    "typeDescKeyPrev_wrist.shot.on.goal.for", "typeDescKeyPrev_high.missed.shot.against", 
    "typeDescKeyPrev_high.missed.shot.for", "typeDescKeyPrev_tip.in.shot.on.goal.against", 
    "typeDescKeyPrev_slap.shot.on.goal.against", "typeDescKeyPrev_wrist.shot.on.goal.against", 
    "typeDescKeyPrev_lost.faceoff", "typeDescKeyPrev_takeaway.for", 
    "typeDescKeyPrev_takeaway.against", "typeDescKeyPrev_other.shot.on.goal.for", 
    "typeDescKeyPrev_giveaway.against", "typeDescKeyPrev_deflected.shot.on.goal.for", 
    "typeDescKeyPrev_post.missed.shot.for", "typeDescKeyPrev_wide.missed.shot.against", 
    "typeDescKeyPrev_given.hit", "typeDescKeyPrev_snap.shot.on.goal.against", 
    "typeDescKeyPrev_won.faceoff", "typeDescKeyPrev_tip.in.shot.on.goal.for"
    ), zoneCode = c("zoneCode_N", "zoneCode_O")), dummy_term_to_var = c(isPlayoff_yes = "isPlayoff", 
isPlayoff_unknown = "isPlayoff", isPlayoff_new = "isPlayoff", 
isHome_yes = "isHome", isHome_unknown = "isHome", isHome_new = "isHome", 
isOvertime_yes = "isOvertime", isOvertime_unknown = "isOvertime", 
isOvertime_new = "isOvertime", zoneCode_N = "zoneCode", zoneCode_O = "zoneCode", 
zoneCode_unknown = "zoneCode", zoneCode_new = "zoneCode", isBehindNet_yes = "isBehindNet", 
isBehindNet_unknown = "isBehindNet", isBehindNet_new = "isBehindNet", 
crossedRoyalRoad_yes = "crossedRoyalRoad", crossedRoyalRoad_unknown = "crossedRoyalRoad", 
crossedRoyalRoad_new = "crossedRoyalRoad", typeDescKeyPrev_backhand.shot.on.goal.for = "typeDescKeyPrev", 
typeDescKeyPrev_blocked.shot.against = "typeDescKeyPrev", typeDescKeyPrev_blocked.shot.for = "typeDescKeyPrev", 
typeDescKeyPrev_deflected.shot.on.goal.against = "typeDescKeyPrev", 
typeDescKeyPrev_deflected.shot.on.goal.for = "typeDescKeyPrev", 
typeDescKeyPrev_giveaway.against = "typeDescKeyPrev", typeDescKeyPrev_giveaway.for = "typeDescKeyPrev", 
typeDescKeyPrev_given.hit = "typeDescKeyPrev", typeDescKeyPrev_high.missed.shot.against = "typeDescKeyPrev", 
typeDescKeyPrev_high.missed.shot.for = "typeDescKeyPrev", typeDescKeyPrev_lost.faceoff = "typeDescKeyPrev", 
typeDescKeyPrev_other.missed.shot.against = "typeDescKeyPrev", 
typeDescKeyPrev_other.missed.shot.for = "typeDescKeyPrev", typeDescKeyPrev_other.shot.on.goal.against = "typeDescKeyPrev", 
typeDescKeyPrev_other.shot.on.goal.for = "typeDescKeyPrev", typeDescKeyPrev_post.missed.shot.against = "typeDescKeyPrev", 
typeDescKeyPrev_post.missed.shot.for = "typeDescKeyPrev", typeDescKeyPrev_slap.shot.on.goal.against = "typeDescKeyPrev", 
typeDescKeyPrev_slap.shot.on.goal.for = "typeDescKeyPrev", typeDescKeyPrev_snap.shot.on.goal.against = "typeDescKeyPrev", 
typeDescKeyPrev_snap.shot.on.goal.for = "typeDescKeyPrev", typeDescKeyPrev_takeaway.against = "typeDescKeyPrev", 
typeDescKeyPrev_takeaway.for = "typeDescKeyPrev", typeDescKeyPrev_taken.hit = "typeDescKeyPrev", 
typeDescKeyPrev_tip.in.shot.on.goal.against = "typeDescKeyPrev", 
typeDescKeyPrev_tip.in.shot.on.goal.for = "typeDescKeyPrev", 
typeDescKeyPrev_wide.missed.shot.against = "typeDescKeyPrev", 
typeDescKeyPrev_wide.missed.shot.for = "typeDescKeyPrev", typeDescKeyPrev_won.faceoff = "typeDescKeyPrev", 
typeDescKeyPrev_wrist.shot.on.goal.against = "typeDescKeyPrev", 
typeDescKeyPrev_wrist.shot.on.goal.for = "typeDescKeyPrev", typeDescKeyPrev_unknown = "typeDescKeyPrev", 
typeDescKeyPrev_new = "typeDescKeyPrev", shotType_deflected = "shotType", 
shotType_other = "shotType", shotType_slap = "shotType", shotType_snap = "shotType", 
shotType_tip.in = "shotType", shotType_wrist = "shotType", shotType_unknown = "shotType", 
shotType_new = "shotType", isRebound_yes = "isRebound", isRebound_unknown = "isRebound", 
isRebound_new = "isRebound", isRush_yes = "isRush", isRush_unknown = "isRush", 
isRush_new = "isRush", shooterHandCode_R = "shooterHandCode", 
shooterHandCode_unknown = "shooterHandCode", shooterHandCode_new = "shooterHandCode", 
shooterPositionCode_D = "shooterPositionCode", shooterPositionCode_L = "shooterPositionCode", 
shooterPositionCode_R = "shooterPositionCode", shooterPositionCode_unknown = "shooterPositionCode", 
shooterPositionCode_new = "shooterPositionCode", goalieHandCode_R = "goalieHandCode", 
goalieHandCode_unknown = "goalieHandCode", goalieHandCode_new = "goalieHandCode", 
isEmptyNetFor_yes = "isEmptyNetFor", isEmptyNetFor_unknown = "isEmptyNetFor", 
isEmptyNetFor_new = "isEmptyNetFor", strengthState_penalty.kill = "strengthState", 
strengthState_unknown = "strengthState", strengthState_new = "strengthState"
), dummy_term_to_level = c(isPlayoff_yes = "yes", isPlayoff_unknown = "unknown", 
isPlayoff_new = "new", isHome_yes = "yes", isHome_unknown = "unknown", 
isHome_new = "new", isOvertime_yes = "yes", isOvertime_unknown = "unknown", 
isOvertime_new = "new", zoneCode_N = "N", zoneCode_O = "O", zoneCode_unknown = "unknown", 
zoneCode_new = "new", isBehindNet_yes = "yes", isBehindNet_unknown = "unknown", 
isBehindNet_new = "new", crossedRoyalRoad_yes = "yes", crossedRoyalRoad_unknown = "unknown", 
crossedRoyalRoad_new = "new", typeDescKeyPrev_backhand.shot.on.goal.for = "backhand-shot-on-goal-for", 
typeDescKeyPrev_blocked.shot.against = "blocked-shot-against", 
typeDescKeyPrev_blocked.shot.for = "blocked-shot-for", typeDescKeyPrev_deflected.shot.on.goal.against = "deflected-shot-on-goal-against", 
typeDescKeyPrev_deflected.shot.on.goal.for = "deflected-shot-on-goal-for", 
typeDescKeyPrev_giveaway.against = "giveaway-against", typeDescKeyPrev_giveaway.for = "giveaway-for", 
typeDescKeyPrev_given.hit = "given-hit", typeDescKeyPrev_high.missed.shot.against = "high-missed-shot-against", 
typeDescKeyPrev_high.missed.shot.for = "high-missed-shot-for", 
typeDescKeyPrev_lost.faceoff = "lost-faceoff", typeDescKeyPrev_other.missed.shot.against = "other-missed-shot-against", 
typeDescKeyPrev_other.missed.shot.for = "other-missed-shot-for", 
typeDescKeyPrev_other.shot.on.goal.against = "other-shot-on-goal-against", 
typeDescKeyPrev_other.shot.on.goal.for = "other-shot-on-goal-for", 
typeDescKeyPrev_post.missed.shot.against = "post-missed-shot-against", 
typeDescKeyPrev_post.missed.shot.for = "post-missed-shot-for", 
typeDescKeyPrev_slap.shot.on.goal.against = "slap-shot-on-goal-against", 
typeDescKeyPrev_slap.shot.on.goal.for = "slap-shot-on-goal-for", 
typeDescKeyPrev_snap.shot.on.goal.against = "snap-shot-on-goal-against", 
typeDescKeyPrev_snap.shot.on.goal.for = "snap-shot-on-goal-for", 
typeDescKeyPrev_takeaway.against = "takeaway-against", typeDescKeyPrev_takeaway.for = "takeaway-for", 
typeDescKeyPrev_taken.hit = "taken-hit", typeDescKeyPrev_tip.in.shot.on.goal.against = "tip-in-shot-on-goal-against", 
typeDescKeyPrev_tip.in.shot.on.goal.for = "tip-in-shot-on-goal-for", 
typeDescKeyPrev_wide.missed.shot.against = "wide-missed-shot-against", 
typeDescKeyPrev_wide.missed.shot.for = "wide-missed-shot-for", 
typeDescKeyPrev_won.faceoff = "won-faceoff", typeDescKeyPrev_wrist.shot.on.goal.against = "wrist-shot-on-goal-against", 
typeDescKeyPrev_wrist.shot.on.goal.for = "wrist-shot-on-goal-for", 
typeDescKeyPrev_unknown = "unknown", typeDescKeyPrev_new = "new", 
shotType_deflected = "deflected", shotType_other = "other", shotType_slap = "slap", 
shotType_snap = "snap", shotType_tip.in = "tip-in", shotType_wrist = "wrist", 
shotType_unknown = "unknown", shotType_new = "new", isRebound_yes = "yes", 
isRebound_unknown = "unknown", isRebound_new = "new", isRush_yes = "yes", 
isRush_unknown = "unknown", isRush_new = "new", shooterHandCode_R = "R", 
shooterHandCode_unknown = "unknown", shooterHandCode_new = "new", 
shooterPositionCode_D = "D", shooterPositionCode_L = "L", shooterPositionCode_R = "R", 
shooterPositionCode_unknown = "unknown", shooterPositionCode_new = "new", 
goalieHandCode_R = "R", goalieHandCode_unknown = "unknown", goalieHandCode_new = "new", 
isEmptyNetFor_yes = "yes", isEmptyNetFor_unknown = "unknown", 
isEmptyNetFor_new = "new", strengthState_penalty.kill = "penalty-kill", 
strengthState_unknown = "unknown", strengthState_new = "new"), 
    dummy_map = list(crossedRoyalRoad = c(yes = "crossedRoyalRoad_yes", 
    unknown = "crossedRoyalRoad_unknown", new = "crossedRoyalRoad_new"
    ), goalieHandCode = c(R = "goalieHandCode_R", unknown = "goalieHandCode_unknown", 
    new = "goalieHandCode_new"), isBehindNet = c(yes = "isBehindNet_yes", 
    unknown = "isBehindNet_unknown", new = "isBehindNet_new"), 
        isEmptyNetFor = c(yes = "isEmptyNetFor_yes", unknown = "isEmptyNetFor_unknown", 
        new = "isEmptyNetFor_new"), isHome = c(yes = "isHome_yes", 
        unknown = "isHome_unknown", new = "isHome_new"), isOvertime = c(yes = "isOvertime_yes", 
        unknown = "isOvertime_unknown", new = "isOvertime_new"
        ), isPlayoff = c(yes = "isPlayoff_yes", unknown = "isPlayoff_unknown", 
        new = "isPlayoff_new"), isRebound = c(yes = "isRebound_yes", 
        unknown = "isRebound_unknown", new = "isRebound_new"), 
        isRush = c(yes = "isRush_yes", unknown = "isRush_unknown", 
        new = "isRush_new"), shooterHandCode = c(R = "shooterHandCode_R", 
        unknown = "shooterHandCode_unknown", new = "shooterHandCode_new"
        ), shooterPositionCode = c(D = "shooterPositionCode_D", 
        L = "shooterPositionCode_L", R = "shooterPositionCode_R", 
        unknown = "shooterPositionCode_unknown", new = "shooterPositionCode_new"
        ), shotType = c(deflected = "shotType_deflected", other = "shotType_other", 
        slap = "shotType_slap", snap = "shotType_snap", `tip-in` = "shotType_tip.in", 
        wrist = "shotType_wrist", unknown = "shotType_unknown", 
        new = "shotType_new"), strengthState = c(`penalty-kill` = "strengthState_penalty.kill", 
        unknown = "strengthState_unknown", new = "strengthState_new"
        ), typeDescKeyPrev = c(`backhand-shot-on-goal-for` = "typeDescKeyPrev_backhand.shot.on.goal.for", 
        `blocked-shot-against` = "typeDescKeyPrev_blocked.shot.against", 
        `blocked-shot-for` = "typeDescKeyPrev_blocked.shot.for", 
        `deflected-shot-on-goal-against` = "typeDescKeyPrev_deflected.shot.on.goal.against", 
        `deflected-shot-on-goal-for` = "typeDescKeyPrev_deflected.shot.on.goal.for", 
        `giveaway-against` = "typeDescKeyPrev_giveaway.against", 
        `giveaway-for` = "typeDescKeyPrev_giveaway.for", `given-hit` = "typeDescKeyPrev_given.hit", 
        `high-missed-shot-against` = "typeDescKeyPrev_high.missed.shot.against", 
        `high-missed-shot-for` = "typeDescKeyPrev_high.missed.shot.for", 
        `lost-faceoff` = "typeDescKeyPrev_lost.faceoff", `other-missed-shot-against` = "typeDescKeyPrev_other.missed.shot.against", 
        `other-missed-shot-for` = "typeDescKeyPrev_other.missed.shot.for", 
        `other-shot-on-goal-against` = "typeDescKeyPrev_other.shot.on.goal.against", 
        `other-shot-on-goal-for` = "typeDescKeyPrev_other.shot.on.goal.for", 
        `post-missed-shot-against` = "typeDescKeyPrev_post.missed.shot.against", 
        `post-missed-shot-for` = "typeDescKeyPrev_post.missed.shot.for", 
        `slap-shot-on-goal-against` = "typeDescKeyPrev_slap.shot.on.goal.against", 
        `slap-shot-on-goal-for` = "typeDescKeyPrev_slap.shot.on.goal.for", 
        `snap-shot-on-goal-against` = "typeDescKeyPrev_snap.shot.on.goal.against", 
        `snap-shot-on-goal-for` = "typeDescKeyPrev_snap.shot.on.goal.for", 
        `takeaway-against` = "typeDescKeyPrev_takeaway.against", 
        `takeaway-for` = "typeDescKeyPrev_takeaway.for", `taken-hit` = "typeDescKeyPrev_taken.hit", 
        `tip-in-shot-on-goal-against` = "typeDescKeyPrev_tip.in.shot.on.goal.against", 
        `tip-in-shot-on-goal-for` = "typeDescKeyPrev_tip.in.shot.on.goal.for", 
        `wide-missed-shot-against` = "typeDescKeyPrev_wide.missed.shot.against", 
        `wide-missed-shot-for` = "typeDescKeyPrev_wide.missed.shot.for", 
        `won-faceoff` = "typeDescKeyPrev_won.faceoff", `wrist-shot-on-goal-against` = "typeDescKeyPrev_wrist.shot.on.goal.against", 
        `wrist-shot-on-goal-for` = "typeDescKeyPrev_wrist.shot.on.goal.for", 
        unknown = "typeDescKeyPrev_unknown", new = "typeDescKeyPrev_new"
        ), zoneCode = c(N = "zoneCode_N", O = "zoneCode_O", unknown = "zoneCode_unknown", 
        new = "zoneCode_new")), known_levels = list(isPlayoff = c("no", 
    "yes"), isHome = c("no", "yes"), isOvertime = c("no", "yes"
    ), zoneCode = c("D", "N", "O"), isBehindNet = c("no", "yes"
    ), crossedRoyalRoad = c("no", "yes"), typeDescKeyPrev = c("backhand-shot-on-goal-against", 
    "backhand-shot-on-goal-for", "blocked-shot-against", "blocked-shot-for", 
    "deflected-shot-on-goal-against", "deflected-shot-on-goal-for", 
    "giveaway-against", "giveaway-for", "given-hit", "high-missed-shot-against", 
    "high-missed-shot-for", "lost-faceoff", "other-missed-shot-against", 
    "other-missed-shot-for", "other-shot-on-goal-against", "other-shot-on-goal-for", 
    "post-missed-shot-against", "post-missed-shot-for", "slap-shot-on-goal-against", 
    "slap-shot-on-goal-for", "snap-shot-on-goal-against", "snap-shot-on-goal-for", 
    "takeaway-against", "takeaway-for", "taken-hit", "tip-in-shot-on-goal-against", 
    "tip-in-shot-on-goal-for", "wide-missed-shot-against", "wide-missed-shot-for", 
    "won-faceoff", "wrist-shot-on-goal-against", "wrist-shot-on-goal-for"
    ), shotType = c("backhand", "deflected", "other", "slap", 
    "snap", "tip-in", "wrist"), isRebound = c("no", "yes"), isRush = c("no", 
    "yes"), shooterHandCode = c("L", "R"), shooterPositionCode = c("C", 
    "D", "L", "R"), goalieHandCode = c("L", "R"), isEmptyNetFor = c("no", 
    "yes"), strengthState = c("even-strength", "penalty-kill"
    )), logical_vars = c("crossedRoyalRoad", "isBehindNet", "isEmptyNetFor", 
    "isHome", "isOvertime", "isPlayoff", "isRebound", "isRush"
    ), has_unknown = c(crossedRoyalRoad = TRUE, goalieHandCode = TRUE, 
    isBehindNet = TRUE, isEmptyNetFor = TRUE, isHome = TRUE, 
    isOvertime = TRUE, isPlayoff = TRUE, isRebound = TRUE, isRush = TRUE, 
    shooterHandCode = TRUE, shooterPositionCode = TRUE, shotType = TRUE, 
    strengthState = TRUE, typeDescKeyPrev = TRUE, zoneCode = TRUE
    ), has_new = c(crossedRoyalRoad = TRUE, goalieHandCode = TRUE, 
    isBehindNet = TRUE, isEmptyNetFor = TRUE, isHome = TRUE, 
    isOvertime = TRUE, isPlayoff = TRUE, isRebound = TRUE, isRush = TRUE, 
    shooterHandCode = TRUE, shooterPositionCode = TRUE, shotType = TRUE, 
    strengthState = TRUE, typeDescKeyPrev = TRUE, zoneCode = TRUE
    ), medians = c(distance = 27.6586333718787, xCoordNorm = 67, 
    angle = 29.9816393688493, shotType_snap = 0, avgSecondsElapsedInShiftFor = 27.6666666666667, 
    minSecondsElapsedInShiftFor = 15, dSecondsElapsedInSequence = 16, 
    dAngle = 7.12001497155098, typeDescKeyPrev_blocked.shot.for = 0, 
    dYCoordNorm = 0, typeDescKeyPrev_blocked.shot.against = 0, 
    skaterCountAgainst = 4, skaterCountFor = 4, maxSecondsElapsedSinceLastShiftAgainst = 249, 
    avgSecondsElapsedInShiftAgainst = 32, typeDescKeyPrev_giveaway.for = 0, 
    shooterPositionCode_D = 0, goalieHeight = 75, typeDescKeyPrev_snap.shot.on.goal.for = 0, 
    isOvertime_yes = 0, shotType_other = 0, typeDescKeyPrev_wide.missed.shot.for = 0, 
    shotType_slap = 0, shooterAge = 27, yCoordNorm = 0, minSecondsElapsedInShiftAgainst = 20, 
    typeDescKeyPrev_other.missed.shot.for = 0, goalDifferential = 0, 
    shooterHeight = 73, typeDescKeyPrev_slap.shot.on.goal.for = 0, 
    periodNumber = 3, typeDescKeyPrev_post.missed.shot.against = 0, 
    secondsElapsedInPeriod = 251, typeDescKeyPrev_other.shot.on.goal.against = 0, 
    goalieAge = 28, isPlayoff_yes = 0, shooterWeight = 200, typeDescKeyPrev_other.missed.shot.against = 0, 
    typeDescKeyPrev_taken.hit = 0, secondsElapsedInGame = 3357, 
    secondsElapsedInSequence = 43, shooterSecondsElapsedInShift = 26, 
    typeDescKeyPrev_deflected.shot.on.goal.against = 0, shooterHandCode_R = 0, 
    isRebound_yes = 0, typeDescKeyPrev_backhand.shot.on.goal.for = 0, 
    typeDescKeyPrev_wrist.shot.on.goal.for = 0, dAnglePerSecond = 0.333179278037169, 
    shooterPositionCode_R = 0, typeDescKeyPrev_high.missed.shot.against = 0, 
    typeDescKeyPrev_high.missed.shot.for = 0, manDifferential = 0, 
    isEmptyNetFor_yes = 0, strengthState_penalty.kill = 0, crossedRoyalRoad_yes = 0, 
    goalsAgainst = 2, shotDifferential = 0, zoneCode_N = 0, dDistance = -16.3988213205148, 
    typeDescKeyPrev_tip.in.shot.on.goal.against = 0, avgSecondsElapsedSinceLastShiftFor = 161.5, 
    goalieWeight = 201, goalsFor = 2, typeDescKeyPrev_slap.shot.on.goal.against = 0, 
    isRush_yes = 0, shooterSecondsElapsedSinceLastShift = 153.5, 
    zoneCode_O = 1, typeDescKeyPrev_wrist.shot.on.goal.against = 0, 
    typeDescKeyPrev_lost.faceoff = 0, dYCoordNormPerSecond = 0, 
    maxSecondsElapsedSinceLastShiftFor = 236, typeDescKeyPrev_takeaway.for = 0, 
    dDistancePerSecond = -1.1423923064826, typeDescKeyPrev_takeaway.against = 0, 
    avgSecondsElapsedSinceLastShiftAgainst = 167.291666666667, 
    minSecondsElapsedSinceLastShiftAgainst = 100, shooterPositionCode_L = 0, 
    typeDescKeyPrev_other.shot.on.goal.for = 0, maxSecondsElapsedInShiftAgainst = 42, 
    shotType_tip.in = 0, shotType_wrist = 1, maxSecondsElapsedInShiftFor = 38, 
    shotsFor = 23, typeDescKeyPrev_giveaway.against = 0, typeDescKeyPrev_deflected.shot.on.goal.for = 0, 
    isBehindNet_yes = 0, typeDescKeyPrev_post.missed.shot.for = 0, 
    shotType_deflected = 0, typeDescKeyPrev_wide.missed.shot.against = 0, 
    typeDescKeyPrev_given.hit = 0, goalieHandCode_R = 0, shotsAgainst = 23, 
    corsiAgainst = 47, corsiDifferential = 1, typeDescKeyPrev_snap.shot.on.goal.against = 0, 
    typeDescKeyPrev_won.faceoff = 0, fenwickDifferential = 1, 
    dXCoordNorm = 14, dXCoordNormPerSecond = 1.0377358490566, 
    fenwickFor = 35, typeDescKeyPrev_tip.in.shot.on.goal.for = 0, 
    isHome_yes = 1, corsiFor = 49, fenwickAgainst = 34, minSecondsElapsedSinceLastShiftFor = 91
    ), normalize_means = c(distance = 27.8836425441254, xCoordNorm = 65.8612236628849, 
    angle = 31.8111673046011, shotType_snap = 0.204213938411669, 
    avgSecondsElapsedInShiftFor = 29.1636311453268, minSecondsElapsedInShiftFor = 17.996961102107, 
    dSecondsElapsedInSequence = 20.5970421393841, dAngle = 5.65760894239027, 
    typeDescKeyPrev_blocked.shot.for = 0.0569286871961102, dYCoordNorm = -0.298622366288493, 
    typeDescKeyPrev_blocked.shot.against = 0.0423419773095624, 
    skaterCountAgainst = 3.55388978930308, skaterCountFor = 3.55388978930308, 
    maxSecondsElapsedSinceLastShiftAgainst = 274.257293354943, 
    avgSecondsElapsedInShiftAgainst = 34.0889282820097, typeDescKeyPrev_giveaway.for = 0.016612641815235, 
    shooterPositionCode_D = 0.31969205834684, goalieHeight = 74.9143030794165, 
    typeDescKeyPrev_snap.shot.on.goal.for = 0.0235008103727715, 
    isOvertime_yes = 0.475688816855754, shotType_other = 0.016612641815235, 
    typeDescKeyPrev_wide.missed.shot.for = 0.0601701782820097, 
    shotType_slap = 0.0682739059967585, shooterAge = 27.3869529983793, 
    yCoordNorm = 0.309967585089141, minSecondsElapsedInShiftAgainst = 23.2878849270665, 
    typeDescKeyPrev_other.missed.shot.for = 0.00141815235008104, 
    goalDifferential = -0.0415316045380875, shooterHeight = 73.115680713128, 
    typeDescKeyPrev_slap.shot.on.goal.for = 0.00607779578606159, 
    periodNumber = 2.98136142625608, typeDescKeyPrev_post.missed.shot.against = 0.00688816855753647, 
    secondsElapsedInPeriod = 401.321515397083, typeDescKeyPrev_other.shot.on.goal.against = 0.00121555915721232, 
    goalieAge = 28.4390194489465, isPlayoff_yes = 0.0425445705024311, 
    shooterWeight = 199.879862236629, typeDescKeyPrev_other.missed.shot.against = 0.0010129659643436, 
    typeDescKeyPrev_taken.hit = 0.0362641815235008, secondsElapsedInGame = 2778.95522690438, 
    secondsElapsedInSequence = 58.2838330632091, shooterSecondsElapsedInShift = 29.9902755267423, 
    typeDescKeyPrev_deflected.shot.on.goal.against = 0.000810372771474878, 
    shooterHandCode_R = 0.388371150729335, isRebound_yes = 0.0644246353322528, 
    typeDescKeyPrev_backhand.shot.on.goal.for = 0.0119529983792545, 
    typeDescKeyPrev_wrist.shot.on.goal.for = 0.0769854132901134, 
    dAnglePerSecond = 0.504619403742005, shooterPositionCode_R = 0.17240680713128, 
    typeDescKeyPrev_high.missed.shot.against = 0.00486223662884927, 
    typeDescKeyPrev_high.missed.shot.for = 0.00486223662884927, 
    manDifferential = -0.00668557536466775, isEmptyNetFor_yes = 0.00668557536466775, 
    strengthState_penalty.kill = 0.00668557536466775, crossedRoyalRoad_yes = 0.413695299837925, 
    goalsAgainst = 2.06138573743922, shotDifferential = 0.461507293354943, 
    zoneCode_N = 0.00567260940032415, dDistance = -37.5734424587598, 
    typeDescKeyPrev_tip.in.shot.on.goal.against = 0.00324149108589951, 
    avgSecondsElapsedSinceLastShiftFor = 206.954186925986, goalieWeight = 201.355145867099, 
    goalsFor = 2.01985413290113, typeDescKeyPrev_slap.shot.on.goal.against = 0.00648298217179903, 
    isRush_yes = 0.0285656401944895, shooterSecondsElapsedSinceLastShift = 207.469205834684, 
    zoneCode_O = 0.991693679092382, typeDescKeyPrev_wrist.shot.on.goal.against = 0.0547001620745543, 
    typeDescKeyPrev_lost.faceoff = 0.103727714748784, dYCoordNormPerSecond = -0.13209881857716, 
    maxSecondsElapsedSinceLastShiftFor = 268.787884927066, typeDescKeyPrev_takeaway.for = 0.0478119935170178, 
    dDistancePerSecond = -4.10845918884632, typeDescKeyPrev_takeaway.against = 0.0170178282009724, 
    avgSecondsElapsedSinceLastShiftAgainst = 214.34705902215, 
    minSecondsElapsedSinceLastShiftAgainst = 162, shooterPositionCode_L = 0.153768233387358, 
    typeDescKeyPrev_other.shot.on.goal.for = 0.00182333873581848, 
    maxSecondsElapsedInShiftAgainst = 46.2674230145867, shotType_tip.in = 0.0492301458670989, 
    shotType_wrist = 0.566653160453809, maxSecondsElapsedInShiftFor = 41.7013776337115, 
    shotsFor = 22.3243517017828, typeDescKeyPrev_giveaway.against = 0.053484602917342, 
    typeDescKeyPrev_deflected.shot.on.goal.for = 0.00162074554294976, 
    isBehindNet_yes = 0.0143841166936791, typeDescKeyPrev_post.missed.shot.for = 0.010129659643436, 
    shotType_deflected = 0.0119529983792545, typeDescKeyPrev_wide.missed.shot.against = 0.038290113452188, 
    typeDescKeyPrev_given.hit = 0.0334278768233387, goalieHandCode_R = 0.0518638573743922, 
    shotsAgainst = 21.8628444084279, corsiAgainst = 44.9564424635332, 
    corsiDifferential = 1.11932739059968, typeDescKeyPrev_snap.shot.on.goal.against = 0.0196515397082658, 
    typeDescKeyPrev_won.faceoff = 0.243517017828201, fenwickDifferential = 0.731158833063209, 
    dXCoordNorm = 37.512358184765, dXCoordNormPerSecond = 3.97051237542973, 
    fenwickFor = 32.9850081037277, typeDescKeyPrev_tip.in.shot.on.goal.for = 0.00506482982171799, 
    isHome_yes = 0.508914100486224, corsiFor = 46.0757698541329, 
    fenwickAgainst = 32.2538492706645, minSecondsElapsedSinceLastShiftFor = 151.900729335494
    ), normalize_sds = c(distance = 15.9300473972311, xCoordNorm = 15.967075662423, 
    angle = 21.5469685697741, shotType_snap = 0.403166883540809, 
    avgSecondsElapsedInShiftFor = 14.7399565542128, minSecondsElapsedInShiftFor = 14.3953650821835, 
    dSecondsElapsedInSequence = 18.0205979006272, dAngle = 32.7977598710415, 
    typeDescKeyPrev_blocked.shot.for = 0.231729779612907, dYCoordNorm = 24.6269834574023, 
    typeDescKeyPrev_blocked.shot.against = 0.201388557049044, 
    skaterCountAgainst = 0.51120481009207, skaterCountFor = 0.51120481009207, 
    maxSecondsElapsedSinceLastShiftAgainst = 134.627863568148, 
    avgSecondsElapsedInShiftAgainst = 17.4968959064147, typeDescKeyPrev_giveaway.for = 0.127827901157436, 
    shooterPositionCode_D = 0.466404456352566, goalieHeight = 1.5879963991926, 
    typeDescKeyPrev_snap.shot.on.goal.for = 0.15150304432943, 
    isOvertime_yes = 0.499459212720901, shotType_other = 0.127827901157434, 
    typeDescKeyPrev_wide.missed.shot.for = 0.237825959135982, 
    shotType_slap = 0.252240896453758, shooterAge = 4.08250573106685, 
    yCoordNorm = 15.519871561703, minSecondsElapsedInShiftAgainst = 16.4535385003685, 
    typeDescKeyPrev_other.missed.shot.for = 0.037635464029222, 
    goalDifferential = 1.37442894256115, shooterHeight = 2.12463460415575, 
    typeDescKeyPrev_slap.shot.on.goal.for = 0.0777308192982554, 
    periodNumber = 1.11217679992388, typeDescKeyPrev_post.missed.shot.against = 0.082717034859428, 
    secondsElapsedInPeriod = 356.227677486903, typeDescKeyPrev_other.shot.on.goal.against = 0.0348472034408927, 
    goalieAge = 3.7276492276995, isPlayoff_yes = 0.201848418953271, 
    shooterWeight = 15.5092139055743, typeDescKeyPrev_other.missed.shot.against = 0.0318142250883039, 
    typeDescKeyPrev_taken.hit = 0.186965698844831, secondsElapsedInGame = 1123.07200665801, 
    secondsElapsedInSequence = 50.5981873719287, shooterSecondsElapsedInShift = 20.4840884364671, 
    typeDescKeyPrev_deflected.shot.on.goal.against = 0.0284583932021896, 
    shooterHandCode_R = 0.487429106174922, isRebound_yes = 0.245532717354864, 
    typeDescKeyPrev_backhand.shot.on.goal.for = 0.108685405389147, 
    typeDescKeyPrev_wrist.shot.on.goal.for = 0.266595308189183, 
    dAnglePerSecond = 8.77034775526019, shooterPositionCode_R = 0.377771905238188, 
    typeDescKeyPrev_high.missed.shot.against = 0.0695670593666077, 
    typeDescKeyPrev_high.missed.shot.for = 0.0695670593666078, 
    manDifferential = 0.0814998412029298, isEmptyNetFor_yes = 0.0814998412029298, 
    strengthState_penalty.kill = 0.0814998412029298, crossedRoyalRoad_yes = 0.49254507201858, 
    goalsAgainst = 1.47222857085925, shotDifferential = 8.51832384996687, 
    zoneCode_N = 0.0751104110451705, dDistance = 55.9620289934552, 
    typeDescKeyPrev_tip.in.shot.on.goal.against = 0.0568475024025425, 
    avgSecondsElapsedSinceLastShiftFor = 113.798898663227, goalieWeight = 15.6479145526495, 
    goalsFor = 1.44090300791271, typeDescKeyPrev_slap.shot.on.goal.against = 0.0802636796542013, 
    isRush_yes = 0.166599121915498, shooterSecondsElapsedSinceLastShift = 137.618028053179, 
    zoneCode_O = 0.0907689104535364, typeDescKeyPrev_wrist.shot.on.goal.against = 0.227417088553474, 
    typeDescKeyPrev_lost.faceoff = 0.304937886295219, dYCoordNormPerSecond = 5.53933835742204, 
    maxSecondsElapsedSinceLastShiftFor = 134.041195648219, typeDescKeyPrev_takeaway.for = 0.213389858992813, 
    dDistancePerSecond = 13.3533983330833, typeDescKeyPrev_takeaway.against = 0.129350730322169, 
    avgSecondsElapsedSinceLastShiftAgainst = 116.279083696836, 
    minSecondsElapsedSinceLastShiftAgainst = 131.146455948308, 
    shooterPositionCode_L = 0.360762984906197, typeDescKeyPrev_other.shot.on.goal.for = 0.0426659462437079, 
    maxSecondsElapsedInShiftAgainst = 26.0848238402378, shotType_tip.in = 0.216370107021805, 
    shotType_wrist = 0.495587645660225, maxSecondsElapsedInShiftFor = 24.0877063013396, 
    shotsFor = 10.5823897696679, typeDescKeyPrev_giveaway.against = 0.225020573113164, 
    typeDescKeyPrev_deflected.shot.on.goal.for = 0.0402299218629799, 
    isBehindNet_yes = 0.119080169086438, typeDescKeyPrev_post.missed.shot.for = 0.100145301749902, 
    shotType_deflected = 0.108685405389145, typeDescKeyPrev_wide.missed.shot.against = 0.191915196020359, 
    typeDescKeyPrev_given.hit = 0.179769299600504, goalieHandCode_R = 0.221774574756755, 
    shotsAgainst = 10.2695203766714, corsiAgainst = 20.2983303705439, 
    corsiDifferential = 16.5137179545448, typeDescKeyPrev_snap.shot.on.goal.against = 0.138813761984803, 
    typeDescKeyPrev_won.faceoff = 0.429247956807713, fenwickDifferential = 12.1691576839932, 
    dXCoordNorm = 58.1427604865045, dXCoordNormPerSecond = 13.5488794054465, 
    fenwickFor = 15.2859995184002, typeDescKeyPrev_tip.in.shot.on.goal.for = 0.0709943549198634, 
    isHome_yes = 0.499971180441693, corsiFor = 21.1061660565772, 
    fenwickAgainst = 14.7693714045207, minSecondsElapsedSinceLastShiftFor = 128.445152162144
    )), pp = list(coefficients = c(`(Intercept)` = -2.40873593672909, 
distance = -0.54159493018628, angle = -0.215705911687938, shotType_snap = 0.19716907987083, 
xCoordNorm = 0.194974538661697, shotType_slap = 0.194897084952875, 
dDistancePerSecond = 0.114059176484837, skaterCountAgainst = -0.0805266678362151, 
isBehindNet_yes = -0.0749412656456376, fenwickDifferential = -0.0740644436487372, 
shotType_wrist = 0.0729746072456859, dAnglePerSecond = 0.0710273591130374, 
manDifferential = 0.0657540478232958, strengthState_power.play = -0.0651437396330941, 
shotType_tip.in = -0.0609302322226729, shooterSecondsElapsedInShift = 0.0604697258659946, 
dDistance = -0.0589946431545966, zoneCode_O = 0.0539114498200749, 
dXCoordNormPerSecond = -0.0519980536155228, crossedRoyalRoad_yes = 0.0476524205784241, 
shotDifferential = 0.046996053829332, corsiDifferential = 0.0466833242616486, 
typeDescKeyPrev_tip.in.shot.on.goal.against = -0.0443450271047899, 
avgSecondsElapsedInShiftAgainst = 0.0433982208658065, zoneCode_N = -0.0410018037204976, 
fenwickAgainst = 0.0405827524508978, dYCoordNormPerSecond = 0.0396071988167495, 
corsiAgainst = -0.0381725166417229, typeDescKeyPrev_other.missed.shot.against = -0.0370122592006922, 
shooterPositionCode_D = -0.0367724318156815, maxSecondsElapsedInShiftFor = -0.0367723514667785, 
typeDescKeyPrev_given.hit = -0.0359689768879517, goalsFor = 0.0338128533319229, 
secondsElapsedInPeriod = -0.0337400734552623, typeDescKeyPrev_backhand.shot.on.goal.for = -0.0330243547728242, 
goalieWeight = -0.0298369965872576, shotsAgainst = -0.0283553099429725, 
dXCoordNorm = -0.0274249327181236, shooterHandCode_R = 0.0265374425530595, 
avgSecondsElapsedSinceLastShiftAgainst = 0.025669819990372, typeDescKeyPrev_post.missed.shot.for = 0.0250219036651624, 
shotType_deflected = -0.0249885318857282, secondsElapsedInSequence = 0.0246819478374614, 
shooterSecondsElapsedSinceLastShift = -0.024266482507998, typeDescKeyPrev_wide.missed.shot.for = 0.024162116492808, 
typeDescKeyPrev_blocked.shot.for = -0.0241612316591937, goalieHandCode_R = -0.0240330305437289, 
maxSecondsElapsedSinceLastShiftAgainst = -0.0238816171555811, 
minSecondsElapsedInShiftAgainst = 0.023858561313903, typeDescKeyPrev_takeaway.against = 0.0225148172847808, 
goalDifferential = 0.0209467327052098, avgSecondsElapsedSinceLastShiftFor = 0.0208718465485786, 
typeDescKeyPrev_takeaway.for = 0.0208645584122001, typeDescKeyPrev_blocked.shot.against = -0.0200057949928402, 
typeDescKeyPrev_giveaway.for = -0.0198367624489711, typeDescKeyPrev_slap.shot.on.goal.against = -0.0191438988694104, 
typeDescKeyPrev_high.missed.shot.against = -0.0183676156559531, 
avgSecondsElapsedInShiftFor = 0.0178401601545399, periodNumber = 0.0176194837502181, 
typeDescKeyPrev_snap.shot.on.goal.against = -0.015866366866815, 
typeDescKeyPrev_slap.shot.on.goal.for = 0.0158540972697513, typeDescKeyPrev_deflected.shot.on.goal.against = 0.0156373458043986, 
shooterWeight = 0.0142853769189897, goalieAge = 0.0142374621400034, 
shooterPositionCode_L = -0.0140278286365682, dAngle = -0.0135530645839663, 
fenwickFor = -0.0134179545964687, yCoordNorm = 0.0127126548438979, 
shotType_other = 0.0123638354488715, isRush_yes = 0.0121347520256905, 
typeDescKeyPrev_high.missed.shot.for = 0.0121263670150074, skaterCountFor = -0.0120734981294251, 
typeDescKeyPrev_other.shot.on.goal.for = -0.0119337859318244, 
isPlayoff_yes = 0.0118545831958862, typeDescKeyPrev_giveaway.against = 0.0118150476882019, 
typeDescKeyPrev_wide.missed.shot.against = -0.0116482137834756, 
minSecondsElapsedInShiftFor = -0.0111270089676604, typeDescKeyPrev_post.missed.shot.against = -0.0104187024962581, 
isRebound_yes = -0.010148209868158, typeDescKeyPrev_other.missed.shot.for = 0.00982366700478954, 
typeDescKeyPrev_snap.shot.on.goal.for = 0.00956480712515684, 
maxSecondsElapsedInShiftAgainst = -0.00907648698578467, shooterPositionCode_R = -0.00907187449060681, 
isEmptyNetFor_yes = 0.00888728972455235, typeDescKeyPrev_other.shot.on.goal.against = 0.00837537319072141, 
isOvertime_yes = 0.00809371103567771, typeDescKeyPrev_tip.in.shot.on.goal.for = 0.0080170918474623, 
typeDescKeyPrev_won.faceoff = 0.00785244249448494, typeDescKeyPrev_wrist.shot.on.goal.against = 0.00781691479964121, 
shotsFor = 0.00761786303739305, isHome_yes = -0.00715136385551856, 
dSecondsElapsedInSequence = -0.00659622587702555, goalsAgainst = 0.00657488948434205, 
typeDescKeyPrev_taken.hit = 0.00622893212610536, shooterAge = 0.00622430309461466, 
maxSecondsElapsedSinceLastShiftFor = -0.00516577829045611, secondsElapsedInGame = 0.00460628671009295, 
corsiFor = -0.00438434350624629, goalieHeight = -0.00405974799713595, 
typeDescKeyPrev_deflected.shot.on.goal.for = -0.00356581981912205, 
minSecondsElapsedSinceLastShiftFor = -0.00274894577959475, dYCoordNorm = -0.00256418142314409, 
typeDescKeyPrev_wrist.shot.on.goal.for = 0.0020828784867278, 
shooterHeight = -0.00157456935417754, typeDescKeyPrev_lost.faceoff = -0.000759496272344574, 
minSecondsElapsedSinceLastShiftAgainst = -0.000364320801870089
), raw_terms = c("distance", "angle", "xCoordNorm", "dDistancePerSecond", 
"skaterCountAgainst", "fenwickDifferential", "dAnglePerSecond", 
"manDifferential", "shooterSecondsElapsedInShift", "dDistance", 
"dXCoordNormPerSecond", "shotDifferential", "corsiDifferential", 
"avgSecondsElapsedInShiftAgainst", "fenwickAgainst", "dYCoordNormPerSecond", 
"corsiAgainst", "maxSecondsElapsedInShiftFor", "goalsFor", "secondsElapsedInPeriod", 
"goalieWeight", "shotsAgainst", "dXCoordNorm", "avgSecondsElapsedSinceLastShiftAgainst", 
"secondsElapsedInSequence", "shooterSecondsElapsedSinceLastShift", 
"maxSecondsElapsedSinceLastShiftAgainst", "minSecondsElapsedInShiftAgainst", 
"goalDifferential", "avgSecondsElapsedSinceLastShiftFor", "avgSecondsElapsedInShiftFor", 
"periodNumber", "shooterWeight", "goalieAge", "dAngle", "fenwickFor", 
"yCoordNorm", "skaterCountFor", "minSecondsElapsedInShiftFor", 
"maxSecondsElapsedInShiftAgainst", "shotsFor", "dSecondsElapsedInSequence", 
"goalsAgainst", "shooterAge", "maxSecondsElapsedSinceLastShiftFor", 
"secondsElapsedInGame", "corsiFor", "goalieHeight", "minSecondsElapsedSinceLastShiftFor", 
"dYCoordNorm", "shooterHeight", "minSecondsElapsedSinceLastShiftAgainst"
), active_dummy_terms = c("shotType_snap", "shotType_slap", "isBehindNet_yes", 
"shotType_wrist", "strengthState_power.play", "shotType_tip.in", 
"zoneCode_O", "crossedRoyalRoad_yes", "typeDescKeyPrev_tip.in.shot.on.goal.against", 
"zoneCode_N", "typeDescKeyPrev_other.missed.shot.against", "shooterPositionCode_D", 
"typeDescKeyPrev_given.hit", "typeDescKeyPrev_backhand.shot.on.goal.for", 
"shooterHandCode_R", "typeDescKeyPrev_post.missed.shot.for", 
"shotType_deflected", "typeDescKeyPrev_wide.missed.shot.for", 
"typeDescKeyPrev_blocked.shot.for", "goalieHandCode_R", "typeDescKeyPrev_takeaway.against", 
"typeDescKeyPrev_takeaway.for", "typeDescKeyPrev_blocked.shot.against", 
"typeDescKeyPrev_giveaway.for", "typeDescKeyPrev_slap.shot.on.goal.against", 
"typeDescKeyPrev_high.missed.shot.against", "typeDescKeyPrev_snap.shot.on.goal.against", 
"typeDescKeyPrev_slap.shot.on.goal.for", "typeDescKeyPrev_deflected.shot.on.goal.against", 
"shooterPositionCode_L", "shotType_other", "isRush_yes", "typeDescKeyPrev_high.missed.shot.for", 
"typeDescKeyPrev_other.shot.on.goal.for", "isPlayoff_yes", "typeDescKeyPrev_giveaway.against", 
"typeDescKeyPrev_wide.missed.shot.against", "typeDescKeyPrev_post.missed.shot.against", 
"isRebound_yes", "typeDescKeyPrev_other.missed.shot.for", "typeDescKeyPrev_snap.shot.on.goal.for", 
"shooterPositionCode_R", "isEmptyNetFor_yes", "typeDescKeyPrev_other.shot.on.goal.against", 
"isOvertime_yes", "typeDescKeyPrev_tip.in.shot.on.goal.for", 
"typeDescKeyPrev_won.faceoff", "typeDescKeyPrev_wrist.shot.on.goal.against", 
"isHome_yes", "typeDescKeyPrev_taken.hit", "typeDescKeyPrev_deflected.shot.on.goal.for", 
"typeDescKeyPrev_wrist.shot.on.goal.for", "typeDescKeyPrev_lost.faceoff"
), active_dummy_by_var = list(crossedRoyalRoad = "crossedRoyalRoad_yes", 
    goalieHandCode = "goalieHandCode_R", isBehindNet = "isBehindNet_yes", 
    isEmptyNetFor = "isEmptyNetFor_yes", isHome = "isHome_yes", 
    isOvertime = "isOvertime_yes", isPlayoff = "isPlayoff_yes", 
    isRebound = "isRebound_yes", isRush = "isRush_yes", shooterHandCode = "shooterHandCode_R", 
    shooterPositionCode = c("shooterPositionCode_D", "shooterPositionCode_L", 
    "shooterPositionCode_R"), shotType = c("shotType_snap", "shotType_slap", 
    "shotType_wrist", "shotType_tip.in", "shotType_deflected", 
    "shotType_other"), strengthState = "strengthState_power.play", 
    typeDescKeyPrev = c("typeDescKeyPrev_tip.in.shot.on.goal.against", 
    "typeDescKeyPrev_other.missed.shot.against", "typeDescKeyPrev_given.hit", 
    "typeDescKeyPrev_backhand.shot.on.goal.for", "typeDescKeyPrev_post.missed.shot.for", 
    "typeDescKeyPrev_wide.missed.shot.for", "typeDescKeyPrev_blocked.shot.for", 
    "typeDescKeyPrev_takeaway.against", "typeDescKeyPrev_takeaway.for", 
    "typeDescKeyPrev_blocked.shot.against", "typeDescKeyPrev_giveaway.for", 
    "typeDescKeyPrev_slap.shot.on.goal.against", "typeDescKeyPrev_high.missed.shot.against", 
    "typeDescKeyPrev_snap.shot.on.goal.against", "typeDescKeyPrev_slap.shot.on.goal.for", 
    "typeDescKeyPrev_deflected.shot.on.goal.against", "typeDescKeyPrev_high.missed.shot.for", 
    "typeDescKeyPrev_other.shot.on.goal.for", "typeDescKeyPrev_giveaway.against", 
    "typeDescKeyPrev_wide.missed.shot.against", "typeDescKeyPrev_post.missed.shot.against", 
    "typeDescKeyPrev_other.missed.shot.for", "typeDescKeyPrev_snap.shot.on.goal.for", 
    "typeDescKeyPrev_other.shot.on.goal.against", "typeDescKeyPrev_tip.in.shot.on.goal.for", 
    "typeDescKeyPrev_won.faceoff", "typeDescKeyPrev_wrist.shot.on.goal.against", 
    "typeDescKeyPrev_taken.hit", "typeDescKeyPrev_deflected.shot.on.goal.for", 
    "typeDescKeyPrev_wrist.shot.on.goal.for", "typeDescKeyPrev_lost.faceoff"
    ), zoneCode = c("zoneCode_O", "zoneCode_N")), dummy_term_to_var = c(isPlayoff_yes = "isPlayoff", 
isPlayoff_unknown = "isPlayoff", isPlayoff_new = "isPlayoff", 
isHome_yes = "isHome", isHome_unknown = "isHome", isHome_new = "isHome", 
isOvertime_yes = "isOvertime", isOvertime_unknown = "isOvertime", 
isOvertime_new = "isOvertime", zoneCode_N = "zoneCode", zoneCode_O = "zoneCode", 
zoneCode_unknown = "zoneCode", zoneCode_new = "zoneCode", isBehindNet_yes = "isBehindNet", 
isBehindNet_unknown = "isBehindNet", isBehindNet_new = "isBehindNet", 
crossedRoyalRoad_yes = "crossedRoyalRoad", crossedRoyalRoad_unknown = "crossedRoyalRoad", 
crossedRoyalRoad_new = "crossedRoyalRoad", typeDescKeyPrev_backhand.shot.on.goal.for = "typeDescKeyPrev", 
typeDescKeyPrev_blocked.shot.against = "typeDescKeyPrev", typeDescKeyPrev_blocked.shot.for = "typeDescKeyPrev", 
typeDescKeyPrev_deflected.shot.on.goal.against = "typeDescKeyPrev", 
typeDescKeyPrev_deflected.shot.on.goal.for = "typeDescKeyPrev", 
typeDescKeyPrev_giveaway.against = "typeDescKeyPrev", typeDescKeyPrev_giveaway.for = "typeDescKeyPrev", 
typeDescKeyPrev_given.hit = "typeDescKeyPrev", typeDescKeyPrev_high.missed.shot.against = "typeDescKeyPrev", 
typeDescKeyPrev_high.missed.shot.for = "typeDescKeyPrev", typeDescKeyPrev_lost.faceoff = "typeDescKeyPrev", 
typeDescKeyPrev_other.missed.shot.against = "typeDescKeyPrev", 
typeDescKeyPrev_other.missed.shot.for = "typeDescKeyPrev", typeDescKeyPrev_other.shot.on.goal.against = "typeDescKeyPrev", 
typeDescKeyPrev_other.shot.on.goal.for = "typeDescKeyPrev", typeDescKeyPrev_post.missed.shot.against = "typeDescKeyPrev", 
typeDescKeyPrev_post.missed.shot.for = "typeDescKeyPrev", typeDescKeyPrev_slap.shot.on.goal.against = "typeDescKeyPrev", 
typeDescKeyPrev_slap.shot.on.goal.for = "typeDescKeyPrev", typeDescKeyPrev_snap.shot.on.goal.against = "typeDescKeyPrev", 
typeDescKeyPrev_snap.shot.on.goal.for = "typeDescKeyPrev", typeDescKeyPrev_takeaway.against = "typeDescKeyPrev", 
typeDescKeyPrev_takeaway.for = "typeDescKeyPrev", typeDescKeyPrev_taken.hit = "typeDescKeyPrev", 
typeDescKeyPrev_tip.in.shot.on.goal.against = "typeDescKeyPrev", 
typeDescKeyPrev_tip.in.shot.on.goal.for = "typeDescKeyPrev", 
typeDescKeyPrev_wide.missed.shot.against = "typeDescKeyPrev", 
typeDescKeyPrev_wide.missed.shot.for = "typeDescKeyPrev", typeDescKeyPrev_won.faceoff = "typeDescKeyPrev", 
typeDescKeyPrev_wrist.shot.on.goal.against = "typeDescKeyPrev", 
typeDescKeyPrev_wrist.shot.on.goal.for = "typeDescKeyPrev", typeDescKeyPrev_unknown = "typeDescKeyPrev", 
typeDescKeyPrev_new = "typeDescKeyPrev", shotType_deflected = "shotType", 
shotType_other = "shotType", shotType_slap = "shotType", shotType_snap = "shotType", 
shotType_tip.in = "shotType", shotType_wrist = "shotType", shotType_unknown = "shotType", 
shotType_new = "shotType", isRebound_yes = "isRebound", isRebound_unknown = "isRebound", 
isRebound_new = "isRebound", isRush_yes = "isRush", isRush_unknown = "isRush", 
isRush_new = "isRush", shooterHandCode_R = "shooterHandCode", 
shooterHandCode_unknown = "shooterHandCode", shooterHandCode_new = "shooterHandCode", 
shooterPositionCode_D = "shooterPositionCode", shooterPositionCode_L = "shooterPositionCode", 
shooterPositionCode_R = "shooterPositionCode", shooterPositionCode_unknown = "shooterPositionCode", 
shooterPositionCode_new = "shooterPositionCode", goalieHandCode_R = "goalieHandCode", 
goalieHandCode_unknown = "goalieHandCode", goalieHandCode_new = "goalieHandCode", 
isEmptyNetFor_yes = "isEmptyNetFor", isEmptyNetFor_unknown = "isEmptyNetFor", 
isEmptyNetFor_new = "isEmptyNetFor", strengthState_power.play = "strengthState", 
strengthState_unknown = "strengthState", strengthState_new = "strengthState"
), dummy_term_to_level = c(isPlayoff_yes = "yes", isPlayoff_unknown = "unknown", 
isPlayoff_new = "new", isHome_yes = "yes", isHome_unknown = "unknown", 
isHome_new = "new", isOvertime_yes = "yes", isOvertime_unknown = "unknown", 
isOvertime_new = "new", zoneCode_N = "N", zoneCode_O = "O", zoneCode_unknown = "unknown", 
zoneCode_new = "new", isBehindNet_yes = "yes", isBehindNet_unknown = "unknown", 
isBehindNet_new = "new", crossedRoyalRoad_yes = "yes", crossedRoyalRoad_unknown = "unknown", 
crossedRoyalRoad_new = "new", typeDescKeyPrev_backhand.shot.on.goal.for = "backhand-shot-on-goal-for", 
typeDescKeyPrev_blocked.shot.against = "blocked-shot-against", 
typeDescKeyPrev_blocked.shot.for = "blocked-shot-for", typeDescKeyPrev_deflected.shot.on.goal.against = "deflected-shot-on-goal-against", 
typeDescKeyPrev_deflected.shot.on.goal.for = "deflected-shot-on-goal-for", 
typeDescKeyPrev_giveaway.against = "giveaway-against", typeDescKeyPrev_giveaway.for = "giveaway-for", 
typeDescKeyPrev_given.hit = "given-hit", typeDescKeyPrev_high.missed.shot.against = "high-missed-shot-against", 
typeDescKeyPrev_high.missed.shot.for = "high-missed-shot-for", 
typeDescKeyPrev_lost.faceoff = "lost-faceoff", typeDescKeyPrev_other.missed.shot.against = "other-missed-shot-against", 
typeDescKeyPrev_other.missed.shot.for = "other-missed-shot-for", 
typeDescKeyPrev_other.shot.on.goal.against = "other-shot-on-goal-against", 
typeDescKeyPrev_other.shot.on.goal.for = "other-shot-on-goal-for", 
typeDescKeyPrev_post.missed.shot.against = "post-missed-shot-against", 
typeDescKeyPrev_post.missed.shot.for = "post-missed-shot-for", 
typeDescKeyPrev_slap.shot.on.goal.against = "slap-shot-on-goal-against", 
typeDescKeyPrev_slap.shot.on.goal.for = "slap-shot-on-goal-for", 
typeDescKeyPrev_snap.shot.on.goal.against = "snap-shot-on-goal-against", 
typeDescKeyPrev_snap.shot.on.goal.for = "snap-shot-on-goal-for", 
typeDescKeyPrev_takeaway.against = "takeaway-against", typeDescKeyPrev_takeaway.for = "takeaway-for", 
typeDescKeyPrev_taken.hit = "taken-hit", typeDescKeyPrev_tip.in.shot.on.goal.against = "tip-in-shot-on-goal-against", 
typeDescKeyPrev_tip.in.shot.on.goal.for = "tip-in-shot-on-goal-for", 
typeDescKeyPrev_wide.missed.shot.against = "wide-missed-shot-against", 
typeDescKeyPrev_wide.missed.shot.for = "wide-missed-shot-for", 
typeDescKeyPrev_won.faceoff = "won-faceoff", typeDescKeyPrev_wrist.shot.on.goal.against = "wrist-shot-on-goal-against", 
typeDescKeyPrev_wrist.shot.on.goal.for = "wrist-shot-on-goal-for", 
typeDescKeyPrev_unknown = "unknown", typeDescKeyPrev_new = "new", 
shotType_deflected = "deflected", shotType_other = "other", shotType_slap = "slap", 
shotType_snap = "snap", shotType_tip.in = "tip-in", shotType_wrist = "wrist", 
shotType_unknown = "unknown", shotType_new = "new", isRebound_yes = "yes", 
isRebound_unknown = "unknown", isRebound_new = "new", isRush_yes = "yes", 
isRush_unknown = "unknown", isRush_new = "new", shooterHandCode_R = "R", 
shooterHandCode_unknown = "unknown", shooterHandCode_new = "new", 
shooterPositionCode_D = "D", shooterPositionCode_L = "L", shooterPositionCode_R = "R", 
shooterPositionCode_unknown = "unknown", shooterPositionCode_new = "new", 
goalieHandCode_R = "R", goalieHandCode_unknown = "unknown", goalieHandCode_new = "new", 
isEmptyNetFor_yes = "yes", isEmptyNetFor_unknown = "unknown", 
isEmptyNetFor_new = "new", strengthState_power.play = "power-play", 
strengthState_unknown = "unknown", strengthState_new = "new"), 
    dummy_map = list(crossedRoyalRoad = c(yes = "crossedRoyalRoad_yes", 
    unknown = "crossedRoyalRoad_unknown", new = "crossedRoyalRoad_new"
    ), goalieHandCode = c(R = "goalieHandCode_R", unknown = "goalieHandCode_unknown", 
    new = "goalieHandCode_new"), isBehindNet = c(yes = "isBehindNet_yes", 
    unknown = "isBehindNet_unknown", new = "isBehindNet_new"), 
        isEmptyNetFor = c(yes = "isEmptyNetFor_yes", unknown = "isEmptyNetFor_unknown", 
        new = "isEmptyNetFor_new"), isHome = c(yes = "isHome_yes", 
        unknown = "isHome_unknown", new = "isHome_new"), isOvertime = c(yes = "isOvertime_yes", 
        unknown = "isOvertime_unknown", new = "isOvertime_new"
        ), isPlayoff = c(yes = "isPlayoff_yes", unknown = "isPlayoff_unknown", 
        new = "isPlayoff_new"), isRebound = c(yes = "isRebound_yes", 
        unknown = "isRebound_unknown", new = "isRebound_new"), 
        isRush = c(yes = "isRush_yes", unknown = "isRush_unknown", 
        new = "isRush_new"), shooterHandCode = c(R = "shooterHandCode_R", 
        unknown = "shooterHandCode_unknown", new = "shooterHandCode_new"
        ), shooterPositionCode = c(D = "shooterPositionCode_D", 
        L = "shooterPositionCode_L", R = "shooterPositionCode_R", 
        unknown = "shooterPositionCode_unknown", new = "shooterPositionCode_new"
        ), shotType = c(deflected = "shotType_deflected", other = "shotType_other", 
        slap = "shotType_slap", snap = "shotType_snap", `tip-in` = "shotType_tip.in", 
        wrist = "shotType_wrist", unknown = "shotType_unknown", 
        new = "shotType_new"), strengthState = c(`power-play` = "strengthState_power.play", 
        unknown = "strengthState_unknown", new = "strengthState_new"
        ), typeDescKeyPrev = c(`backhand-shot-on-goal-for` = "typeDescKeyPrev_backhand.shot.on.goal.for", 
        `blocked-shot-against` = "typeDescKeyPrev_blocked.shot.against", 
        `blocked-shot-for` = "typeDescKeyPrev_blocked.shot.for", 
        `deflected-shot-on-goal-against` = "typeDescKeyPrev_deflected.shot.on.goal.against", 
        `deflected-shot-on-goal-for` = "typeDescKeyPrev_deflected.shot.on.goal.for", 
        `giveaway-against` = "typeDescKeyPrev_giveaway.against", 
        `giveaway-for` = "typeDescKeyPrev_giveaway.for", `given-hit` = "typeDescKeyPrev_given.hit", 
        `high-missed-shot-against` = "typeDescKeyPrev_high.missed.shot.against", 
        `high-missed-shot-for` = "typeDescKeyPrev_high.missed.shot.for", 
        `lost-faceoff` = "typeDescKeyPrev_lost.faceoff", `other-missed-shot-against` = "typeDescKeyPrev_other.missed.shot.against", 
        `other-missed-shot-for` = "typeDescKeyPrev_other.missed.shot.for", 
        `other-shot-on-goal-against` = "typeDescKeyPrev_other.shot.on.goal.against", 
        `other-shot-on-goal-for` = "typeDescKeyPrev_other.shot.on.goal.for", 
        `post-missed-shot-against` = "typeDescKeyPrev_post.missed.shot.against", 
        `post-missed-shot-for` = "typeDescKeyPrev_post.missed.shot.for", 
        `slap-shot-on-goal-against` = "typeDescKeyPrev_slap.shot.on.goal.against", 
        `slap-shot-on-goal-for` = "typeDescKeyPrev_slap.shot.on.goal.for", 
        `snap-shot-on-goal-against` = "typeDescKeyPrev_snap.shot.on.goal.against", 
        `snap-shot-on-goal-for` = "typeDescKeyPrev_snap.shot.on.goal.for", 
        `takeaway-against` = "typeDescKeyPrev_takeaway.against", 
        `takeaway-for` = "typeDescKeyPrev_takeaway.for", `taken-hit` = "typeDescKeyPrev_taken.hit", 
        `tip-in-shot-on-goal-against` = "typeDescKeyPrev_tip.in.shot.on.goal.against", 
        `tip-in-shot-on-goal-for` = "typeDescKeyPrev_tip.in.shot.on.goal.for", 
        `wide-missed-shot-against` = "typeDescKeyPrev_wide.missed.shot.against", 
        `wide-missed-shot-for` = "typeDescKeyPrev_wide.missed.shot.for", 
        `won-faceoff` = "typeDescKeyPrev_won.faceoff", `wrist-shot-on-goal-against` = "typeDescKeyPrev_wrist.shot.on.goal.against", 
        `wrist-shot-on-goal-for` = "typeDescKeyPrev_wrist.shot.on.goal.for", 
        unknown = "typeDescKeyPrev_unknown", new = "typeDescKeyPrev_new"
        ), zoneCode = c(N = "zoneCode_N", O = "zoneCode_O", unknown = "zoneCode_unknown", 
        new = "zoneCode_new")), known_levels = list(isPlayoff = c("no", 
    "yes"), isHome = c("no", "yes"), isOvertime = c("no", "yes"
    ), zoneCode = c("D", "N", "O"), isBehindNet = c("no", "yes"
    ), crossedRoyalRoad = c("no", "yes"), typeDescKeyPrev = c("backhand-shot-on-goal-against", 
    "backhand-shot-on-goal-for", "blocked-shot-against", "blocked-shot-for", 
    "deflected-shot-on-goal-against", "deflected-shot-on-goal-for", 
    "giveaway-against", "giveaway-for", "given-hit", "high-missed-shot-against", 
    "high-missed-shot-for", "lost-faceoff", "other-missed-shot-against", 
    "other-missed-shot-for", "other-shot-on-goal-against", "other-shot-on-goal-for", 
    "post-missed-shot-against", "post-missed-shot-for", "slap-shot-on-goal-against", 
    "slap-shot-on-goal-for", "snap-shot-on-goal-against", "snap-shot-on-goal-for", 
    "takeaway-against", "takeaway-for", "taken-hit", "tip-in-shot-on-goal-against", 
    "tip-in-shot-on-goal-for", "wide-missed-shot-against", "wide-missed-shot-for", 
    "won-faceoff", "wrist-shot-on-goal-against", "wrist-shot-on-goal-for"
    ), shotType = c("backhand", "deflected", "other", "slap", 
    "snap", "tip-in", "wrist"), isRebound = c("no", "yes"), isRush = c("no", 
    "yes"), shooterHandCode = c("L", "R"), shooterPositionCode = c("C", 
    "D", "L", "R"), goalieHandCode = c("L", "R"), isEmptyNetFor = c("no", 
    "yes"), strengthState = c("even-strength", "power-play")), 
    logical_vars = c("crossedRoyalRoad", "isBehindNet", "isEmptyNetFor", 
    "isHome", "isOvertime", "isPlayoff", "isRebound", "isRush"
    ), has_unknown = c(crossedRoyalRoad = TRUE, goalieHandCode = TRUE, 
    isBehindNet = TRUE, isEmptyNetFor = TRUE, isHome = TRUE, 
    isOvertime = TRUE, isPlayoff = TRUE, isRebound = TRUE, isRush = TRUE, 
    shooterHandCode = TRUE, shooterPositionCode = TRUE, shotType = TRUE, 
    strengthState = TRUE, typeDescKeyPrev = TRUE, zoneCode = TRUE
    ), has_new = c(crossedRoyalRoad = TRUE, goalieHandCode = TRUE, 
    isBehindNet = TRUE, isEmptyNetFor = TRUE, isHome = TRUE, 
    isOvertime = TRUE, isPlayoff = TRUE, isRebound = TRUE, isRush = TRUE, 
    shooterHandCode = TRUE, shooterPositionCode = TRUE, shotType = TRUE, 
    strengthState = TRUE, typeDescKeyPrev = TRUE, zoneCode = TRUE
    ), medians = c(distance = 29.0688837074973, angle = 30.1413855520753, 
    shotType_snap = 0, xCoordNorm = 67, shotType_slap = 0, dDistancePerSecond = -0.710599964774739, 
    skaterCountAgainst = 4, isBehindNet_yes = 0, fenwickDifferential = 1, 
    shotType_wrist = 0, dAnglePerSecond = 0.129172955109414, 
    manDifferential = 1, strengthState_power.play = 1, shotType_tip.in = 0, 
    shooterSecondsElapsedInShift = 43, dDistance = -9.0351168524732, 
    zoneCode_O = 1, dXCoordNormPerSecond = 0.625, crossedRoyalRoad_yes = 0, 
    shotDifferential = 1, corsiDifferential = 2, typeDescKeyPrev_tip.in.shot.on.goal.against = 0, 
    avgSecondsElapsedInShiftAgainst = 34.5, zoneCode_N = 0, fenwickAgainst = 23, 
    dYCoordNormPerSecond = -0.0434782608695652, corsiAgainst = 32, 
    typeDescKeyPrev_other.missed.shot.against = 0, shooterPositionCode_D = 0, 
    maxSecondsElapsedInShiftFor = 61, typeDescKeyPrev_given.hit = 0, 
    goalsFor = 1, secondsElapsedInPeriod = 695, typeDescKeyPrev_backhand.shot.on.goal.for = 0, 
    goalieWeight = 201, shotsAgainst = 15, dXCoordNorm = 8, shooterHandCode_R = 0, 
    avgSecondsElapsedSinceLastShiftAgainst = 130.75, typeDescKeyPrev_post.missed.shot.for = 0, 
    shotType_deflected = 0, secondsElapsedInSequence = 38, shooterSecondsElapsedSinceLastShift = 142, 
    typeDescKeyPrev_wide.missed.shot.for = 0, typeDescKeyPrev_blocked.shot.for = 0, 
    goalieHandCode_R = 0, maxSecondsElapsedSinceLastShiftAgainst = 191, 
    minSecondsElapsedInShiftAgainst = 24, typeDescKeyPrev_takeaway.against = 0, 
    goalDifferential = 0, avgSecondsElapsedSinceLastShiftFor = 151.2, 
    typeDescKeyPrev_takeaway.for = 0, typeDescKeyPrev_blocked.shot.against = 0, 
    typeDescKeyPrev_giveaway.for = 0, typeDescKeyPrev_slap.shot.on.goal.against = 0, 
    typeDescKeyPrev_high.missed.shot.against = 0, avgSecondsElapsedInShiftFor = 44.2, 
    periodNumber = 2, typeDescKeyPrev_snap.shot.on.goal.against = 0, 
    typeDescKeyPrev_slap.shot.on.goal.for = 0, typeDescKeyPrev_deflected.shot.on.goal.against = 0, 
    shooterWeight = 200, goalieAge = 28, shooterPositionCode_L = 0, 
    dAngle = 2.43439897191186, fenwickFor = 24, yCoordNorm = 0, 
    shotType_other = 0, isRush_yes = 0, typeDescKeyPrev_high.missed.shot.for = 0, 
    skaterCountFor = 5, typeDescKeyPrev_other.shot.on.goal.for = 0, 
    isPlayoff_yes = 0, typeDescKeyPrev_giveaway.against = 0, 
    typeDescKeyPrev_wide.missed.shot.against = 0, minSecondsElapsedInShiftFor = 30, 
    typeDescKeyPrev_post.missed.shot.against = 0, isRebound_yes = 0, 
    typeDescKeyPrev_other.missed.shot.for = 0, typeDescKeyPrev_snap.shot.on.goal.for = 0, 
    maxSecondsElapsedInShiftAgainst = 46, shooterPositionCode_R = 0, 
    isEmptyNetFor_yes = 0, typeDescKeyPrev_other.shot.on.goal.against = 0, 
    isOvertime_yes = 0, typeDescKeyPrev_tip.in.shot.on.goal.for = 0, 
    typeDescKeyPrev_won.faceoff = 0, typeDescKeyPrev_wrist.shot.on.goal.against = 0, 
    shotsFor = 16, isHome_yes = 1, dSecondsElapsedInSequence = 13, 
    goalsAgainst = 1, typeDescKeyPrev_taken.hit = 0, shooterAge = 28, 
    maxSecondsElapsedSinceLastShiftFor = 219, secondsElapsedInGame = 2024, 
    corsiFor = 34, goalieHeight = 75, typeDescKeyPrev_deflected.shot.on.goal.for = 0, 
    minSecondsElapsedSinceLastShiftFor = 90, dYCoordNorm = -1, 
    typeDescKeyPrev_wrist.shot.on.goal.for = 0, shooterHeight = 73, 
    typeDescKeyPrev_lost.faceoff = 0, minSecondsElapsedSinceLastShiftAgainst = 75
    ), normalize_means = c(distance = 29.1825308626806, angle = 31.8740842498832, 
    shotType_snap = 0.182333358745648, xCoordNorm = 64.7012020024904, 
    shotType_slap = 0.190262000965668, dDistancePerSecond = -3.92513227181903, 
    skaterCountAgainst = 4.08754542451272, isBehindNet_yes = 0.0124774465706081, 
    fenwickDifferential = 1.43399151228685, shotType_wrist = 0.433178318213006, 
    dAnglePerSecond = 0.394836951007524, manDifferential = 0.8954791491957, 
    strengthState_power.play = 0.870981677721024, shotType_tip.in = 0.112297019135473, 
    shooterSecondsElapsedInShift = 49.4412848466367, dDistance = -30.5685391359683, 
    zoneCode_O = 0.994383878427486, dXCoordNormPerSecond = 3.74943871134502, 
    crossedRoyalRoad_yes = 0.432543010342812, shotDifferential = 0.795278391908719, 
    corsiDifferential = 2.3450229981449, typeDescKeyPrev_tip.in.shot.on.goal.against = 0.000432009351731849, 
    avgSecondsElapsedInShiftAgainst = 37.6706661414787, zoneCode_N = 0.0045488043505883, 
    fenwickAgainst = 23.3634215140657, dYCoordNormPerSecond = -0.126969700004367, 
    corsiAgainst = 32.3850982185967, typeDescKeyPrev_other.missed.shot.against = 0.000228710833269803, 
    shooterPositionCode_D = 0.18230794643084, maxSecondsElapsedInShiftFor = 67.6061599451094, 
    typeDescKeyPrev_given.hit = 0.0182460420319687, goalsFor = 1.36741124749053, 
    secondsElapsedInPeriod = 676.414779802292, typeDescKeyPrev_backhand.shot.on.goal.for = 0.0112830677746436, 
    goalieWeight = 201.753983380346, shotsAgainst = 15.8849584508653, 
    dXCoordNorm = 30.0671647480369, shooterHandCode_R = 0.405936316739092, 
    avgSecondsElapsedSinceLastShiftAgainst = 148.424941339906, 
    typeDescKeyPrev_post.missed.shot.for = 0.0130365174963787, 
    shotType_deflected = 0.0219308276790933, secondsElapsedInSequence = 46.8849838631801, 
    shooterSecondsElapsedSinceLastShift = 167.745698965719, typeDescKeyPrev_wide.missed.shot.for = 0.0988284922873625, 
    typeDescKeyPrev_blocked.shot.for = 0.138370054128231, goalieHandCode_R = 0.0564407511880257, 
    maxSecondsElapsedSinceLastShiftAgainst = 218.025666437956, 
    minSecondsElapsedInShiftAgainst = 27.7192955706335, typeDescKeyPrev_takeaway.against = 0.0156285736067698, 
    goalDifferential = -0.324743970928312, avgSecondsElapsedSinceLastShiftFor = 166.560267845798, 
    typeDescKeyPrev_takeaway.for = 0.0166704785138878, typeDescKeyPrev_blocked.shot.against = 0.0071916850905949, 
    typeDescKeyPrev_giveaway.for = 0.0265050443444893, typeDescKeyPrev_slap.shot.on.goal.against = 0.00180427435135066, 
    typeDescKeyPrev_high.missed.shot.against = 0.000533658610962873, 
    avgSecondsElapsedInShiftFor = 49.0909896402464, periodNumber = 2.12324972681762, 
    typeDescKeyPrev_snap.shot.on.goal.against = 0.00355772407308582, 
    typeDescKeyPrev_slap.shot.on.goal.for = 0.0311300856395009, 
    typeDescKeyPrev_deflected.shot.on.goal.against = 0.000177886203654291, 
    shooterWeight = 199.48771314579, goalieAge = 28.5687276053976, 
    shooterPositionCode_L = 0.220528067901705, dAngle = 2.46539410588522, 
    fenwickFor = 24.7974130263526, yCoordNorm = -0.153363319864806, 
    shotType_other = 0.0129348682371477, isRush_yes = 0.0254377271225636, 
    typeDescKeyPrev_high.missed.shot.for = 0.00820817768290514, 
    skaterCountFor = 5.12955198088994, typeDescKeyPrev_other.shot.on.goal.for = 0.0028207669436609, 
    isPlayoff_yes = 0.0642677441488145, typeDescKeyPrev_giveaway.against = 0.0311554979543087, 
    typeDescKeyPrev_wide.missed.shot.against = 0.00752204518309573, 
    minSecondsElapsedInShiftFor = 34.7852913521893, typeDescKeyPrev_post.missed.shot.against = 0.00106731722192575, 
    isRebound_yes = 0.117608192930294, typeDescKeyPrev_other.missed.shot.for = 0.00447256740616503, 
    typeDescKeyPrev_snap.shot.on.goal.for = 0.0345099235089324, 
    maxSecondsElapsedInShiftAgainst = 51.318975375467, shooterPositionCode_R = 0.210744326700719, 
    isEmptyNetFor_yes = 0.14652740718152, typeDescKeyPrev_other.shot.on.goal.against = 0.00030494777769307, 
    isOvertime_yes = 0.00942796879367742, typeDescKeyPrev_tip.in.shot.on.goal.for = 0.0201773779573581, 
    typeDescKeyPrev_won.faceoff = 0.218571319661508, typeDescKeyPrev_wrist.shot.on.goal.against = 0.018423928235623, 
    shotsFor = 16.680236842774, isHome_yes = 0.524561002261696, 
    dSecondsElapsedInSequence = 17.7462580366446, goalsAgainst = 1.69215521841885, 
    typeDescKeyPrev_taken.hit = 0.0452847449874209, shooterAge = 27.7757617341364, 
    maxSecondsElapsedSinceLastShiftFor = 242.675433915275, secondsElapsedInGame = 2024.31445198343, 
    corsiFor = 34.7301212167416, goalieHeight = 74.919493786689, 
    typeDescKeyPrev_deflected.shot.on.goal.for = 0.00424385657289523, 
    minSecondsElapsedSinceLastShiftFor = 104.568117709842, dYCoordNorm = -0.922594089095576, 
    typeDescKeyPrev_wrist.shot.on.goal.for = 0.0937968539554268, 
    shooterHeight = 72.9694798099159, typeDescKeyPrev_lost.faceoff = 0.12342761302127, 
    minSecondsElapsedSinceLastShiftAgainst = 93.0578130161876
    ), normalize_sds = c(distance = 17.1583418484218, angle = 22.0452025613815, 
    shotType_snap = 0.386123935801959, xCoordNorm = 17.1798785507251, 
    shotType_slap = 0.392512785951225, dDistancePerSecond = 15.0300317182372, 
    skaterCountAgainst = 0.398963269337967, isBehindNet_yes = 0.111004833363643, 
    fenwickDifferential = 10.0858000156472, shotType_wrist = 0.49552104154212, 
    dAnglePerSecond = 11.498787437631, manDifferential = 0.377617278689708, 
    strengthState_power.play = 0.335224477798939, shotType_tip.in = 0.31573554116574, 
    shooterSecondsElapsedInShift = 34.4353479956146, dDistance = 57.1889220770317, 
    zoneCode_O = 0.0747310020789636, dXCoordNormPerSecond = 15.4006870048607, 
    crossedRoyalRoad_yes = 0.49543495248741, shotDifferential = 7.32490965589123, 
    corsiDifferential = 13.6752390553583, typeDescKeyPrev_tip.in.shot.on.goal.against = 0.0207806085942067, 
    avgSecondsElapsedInShiftAgainst = 21.4078116651204, zoneCode_N = 0.0672921080240239, 
    fenwickAgainst = 13.8396973446054, dYCoordNormPerSecond = 6.31585281634119, 
    corsiAgainst = 18.8722248204091, typeDescKeyPrev_other.missed.shot.against = 0.0151216512165405, 
    shooterPositionCode_D = 0.386103026993762, maxSecondsElapsedInShiftFor = 39.4366029021034, 
    typeDescKeyPrev_given.hit = 0.133841619863337, goalsFor = 1.34481892692647, 
    secondsElapsedInPeriod = 354.534291015798, typeDescKeyPrev_backhand.shot.on.goal.for = 0.105622174078812, 
    goalieWeight = 15.8038237963044, shotsAgainst = 9.67362991872764, 
    dXCoordNorm = 59.3483643223646, shooterHandCode_R = 0.491078559782661, 
    avgSecondsElapsedSinceLastShiftAgainst = 76.2167035701549, 
    typeDescKeyPrev_post.missed.shot.for = 0.113432330865189, 
    shotType_deflected = 0.146459590266464, secondsElapsedInSequence = 38.2816876532339, 
    shooterSecondsElapsedSinceLastShift = 103.030093210562, typeDescKeyPrev_wide.missed.shot.for = 0.298435394539607, 
    typeDescKeyPrev_blocked.shot.for = 0.345292357398837, goalieHandCode_R = 0.230773798697999, 
    maxSecondsElapsedSinceLastShiftAgainst = 114.978414202739, 
    minSecondsElapsedInShiftAgainst = 18.867155017967, typeDescKeyPrev_takeaway.against = 0.124035125085396, 
    goalDifferential = 1.6851929845146, avgSecondsElapsedSinceLastShiftFor = 74.897713499265, 
    typeDescKeyPrev_takeaway.for = 0.128035113323765, typeDescKeyPrev_blocked.shot.against = 0.0844993858190727, 
    typeDescKeyPrev_giveaway.for = 0.160633691009623, typeDescKeyPrev_slap.shot.on.goal.against = 0.0424389527985708, 
    typeDescKeyPrev_high.missed.shot.against = 0.0230951807539552, 
    avgSecondsElapsedInShiftFor = 28.9302031044488, periodNumber = 0.81936906375636, 
    typeDescKeyPrev_snap.shot.on.goal.against = 0.0595412190263552, 
    typeDescKeyPrev_slap.shot.on.goal.for = 0.173671442350077, 
    typeDescKeyPrev_deflected.shot.on.goal.against = 0.013336381816806, 
    shooterWeight = 15.2288879916244, goalieAge = 3.74472564683238, 
    shooterPositionCode_L = 0.414608016735528, dAngle = 32.2121187715559, 
    fenwickFor = 14.4166896230049, yCoordNorm = 16.1379090363397, 
    shotType_other = 0.112995052468134, isRush_yes = 0.157452466367448, 
    typeDescKeyPrev_high.missed.shot.for = 0.0902275478108235, 
    skaterCountFor = 0.377699315051126, typeDescKeyPrev_other.shot.on.goal.for = 0.0530366071628462, 
    isPlayoff_yes = 0.245232398920371, typeDescKeyPrev_giveaway.against = 0.173740035649566, 
    typeDescKeyPrev_wide.missed.shot.against = 0.0864040145994382, 
    minSecondsElapsedInShiftFor = 25.7503886187896, typeDescKeyPrev_post.missed.shot.against = 0.0326527969799588, 
    isRebound_yes = 0.322147703940644, typeDescKeyPrev_other.missed.shot.for = 0.0667283800176815, 
    typeDescKeyPrev_snap.shot.on.goal.for = 0.182537216540878, 
    maxSecondsElapsedInShiftAgainst = 31.620876052298, shooterPositionCode_R = 0.407842349972714, 
    isEmptyNetFor_yes = 0.35363866332461, typeDescKeyPrev_other.shot.on.goal.against = 0.0174603130501346, 
    isOvertime_yes = 0.0966401548623797, typeDescKeyPrev_tip.in.shot.on.goal.for = 0.140608512532968, 
    typeDescKeyPrev_won.faceoff = 0.413282274436155, typeDescKeyPrev_wrist.shot.on.goal.against = 0.134480283626792, 
    shotsFor = 9.92035042136552, isHome_yes = 0.499402738356446, 
    dSecondsElapsedInSequence = 16.5505773566519, goalsAgainst = 1.56223513285134, 
    typeDescKeyPrev_taken.hit = 0.207930602758942, shooterAge = 4.33663898086633, 
    maxSecondsElapsedSinceLastShiftFor = 110.630508651649, secondsElapsedInGame = 1054.49872281385, 
    corsiFor = 20.0597708432829, goalieHeight = 1.5926527327773, 
    typeDescKeyPrev_deflected.shot.on.goal.for = 0.065007335321074, 
    minSecondsElapsedSinceLastShiftFor = 74.5816495106049, dYCoordNorm = 25.4658354094814, 
    typeDescKeyPrev_wrist.shot.on.goal.for = 0.291549591355914, 
    shooterHeight = 2.05312137394645, typeDescKeyPrev_lost.faceoff = 0.328931583882874, 
    minSecondsElapsedSinceLastShiftAgainst = 72.0762813257111
    )), sh = list(coefficients = c(`(Intercept)` = -3.63153798338081, 
distance = -0.966884796033344, xCoordNorm = 0.712287276359287, 
angle = -0.299721153736643, minSecondsElapsedInShiftFor = 0.270697844828597, 
dDistance = -0.270424342210878, shotType_tip.in = -0.18748895339856, 
shotType_snap = 0.181593017886797, zoneCode_O = 0.170362375447486, 
typeDescKeyPrev_tip.in.shot.on.goal.against = -0.159885480263973, 
typeDescKeyPrev_won.faceoff = -0.153910966629935, avgSecondsElapsedInShiftAgainst = 0.150788932169999, 
typeDescKeyPrev_post.missed.shot.against = -0.14744703173948, 
zoneCode_N = -0.122759549835248, minSecondsElapsedSinceLastShiftFor = 0.119446699869042, 
avgSecondsElapsedSinceLastShiftFor = -0.117335141414068, secondsElapsedInGame = -0.11386113608954, 
goalieHeight = 0.112983719002759, dXCoordNorm = 0.111461702734452, 
corsiDifferential = -0.109646778465175, isOvertime_yes = -0.108763551334847, 
shooterHandCode_R = 0.105819579002731, shooterPositionCode_D = -0.104538563426477, 
fenwickDifferential = 0.104244256422268, typeDescKeyPrev_blocked.shot.for = 0.0999938116499298, 
manDifferential = 0.0975666891266696, typeDescKeyPrev_takeaway.for = 0.0969216503133783, 
dDistancePerSecond = 0.0949942661470541, typeDescKeyPrev_lost.faceoff = 0.0942728934704784, 
shooterSecondsElapsedSinceLastShift = 0.0930235664484371, typeDescKeyPrev_post.missed.shot.for = 0.0900011186416822, 
shooterWeight = 0.089343021300825, periodNumber = -0.0892117065006534, 
dAngle = -0.0876346390397818, goalieWeight = -0.0867592980503014, 
dXCoordNormPerSecond = -0.0860803941318523, shooterHeight = -0.0849093889814402, 
goalieAge = 0.0839532813572198, shooterSecondsElapsedInShift = -0.0801969245795928, 
dYCoordNormPerSecond = 0.0795518417492723, corsiAgainst = 0.0755924357662071, 
secondsElapsedInPeriod = -0.0720412805370922, shooterPositionCode_R = 0.0636785445524335, 
maxSecondsElapsedSinceLastShiftAgainst = 0.0624502944569121, 
isRebound_yes = 0.0608391175688252, shotType_other = -0.0605088294240121, 
typeDescKeyPrev_deflected.shot.on.goal.against = -0.0602968646760614, 
dYCoordNorm = -0.0588440238072053, typeDescKeyPrev_slap.shot.on.goal.for = 0.0576767301623944, 
typeDescKeyPrev_other.shot.on.goal.for = -0.0567382282269528, 
dSecondsElapsedInSequence = -0.0559515265150227, typeDescKeyPrev_high.missed.shot.for = -0.052714401553124, 
avgSecondsElapsedInShiftFor = 0.0514710784218389, typeDescKeyPrev_snap.shot.on.goal.against = 0.0488086779809238, 
maxSecondsElapsedInShiftFor = 0.0483594781430845, crossedRoyalRoad_yes = 0.0472410451795902, 
typeDescKeyPrev_deflected.shot.on.goal.for = -0.0443317884863132, 
fenwickFor = 0.0425205663259666, typeDescKeyPrev_giveaway.against = 0.0412982762614141, 
typeDescKeyPrev_slap.shot.on.goal.against = 0.0396858019227885, 
typeDescKeyPrev_other.missed.shot.for = -0.0390228667144192, 
shotsFor = 0.0386766739245762, fenwickAgainst = -0.0369460332199352, 
maxSecondsElapsedSinceLastShiftFor = -0.0351154256210093, skaterCountFor = 0.0343034423586185, 
isHome_yes = -0.0340077143330081, shotType_slap = 0.0337787048249246, 
typeDescKeyPrev_giveaway.for = -0.0336722418317461, typeDescKeyPrev_taken.hit = -0.0330078733225434, 
skaterCountAgainst = -0.0316860879633458, typeDescKeyPrev_other.shot.on.goal.against = 0.0313133374320686, 
minSecondsElapsedSinceLastShiftAgainst = -0.0312521695137525, 
typeDescKeyPrev_tip.in.shot.on.goal.for = 0.031104374441944, 
typeDescKeyPrev_wrist.shot.on.goal.against = -0.0310693612044417, 
isBehindNet_yes = 0.0306816035521421, shooterPositionCode_L = -0.0299236912805296, 
yCoordNorm = 0.0289363151396329, typeDescKeyPrev_other.missed.shot.against = 0.0287245706785486, 
typeDescKeyPrev_blocked.shot.against = 0.0285931746315683, goalsFor = 0.0285508077234967, 
maxSecondsElapsedInShiftAgainst = -0.0285023865466986, typeDescKeyPrev_snap.shot.on.goal.for = -0.0269096392869296, 
isRush_yes = -0.026745104240082, minSecondsElapsedInShiftAgainst = -0.0238173645997878, 
shotsAgainst = 0.0234209182283407, avgSecondsElapsedSinceLastShiftAgainst = -0.0226078467351798, 
secondsElapsedInSequence = -0.0211884910172206, shotDifferential = 0.0209405477431257, 
typeDescKeyPrev_wide.missed.shot.against = 0.0205110639444662, 
shotType_deflected = -0.0203621698906344, shotType_wrist = -0.0201989463446854, 
goalsAgainst = 0.0200509202816621, typeDescKeyPrev_wrist.shot.on.goal.for = 0.0196509176599285, 
dAnglePerSecond = 0.0196432283184315, shooterAge = 0.0163202459346931, 
typeDescKeyPrev_high.missed.shot.against = 0.0159443789044939, 
isEmptyNetFor_yes = -0.0153174831542125, goalieHandCode_R = -0.0119914869246025, 
typeDescKeyPrev_given.hit = -0.0109804652957711, goalDifferential = 0.00742708264657712, 
corsiFor = -0.0062692423970964, isPlayoff_yes = 0.0060658315479522, 
typeDescKeyPrev_takeaway.against = -0.00548341528040623, typeDescKeyPrev_wide.missed.shot.for = -0.0022947453173044, 
typeDescKeyPrev_backhand.shot.on.goal.for = 0.00164041606227585
), raw_terms = c("distance", "xCoordNorm", "angle", "minSecondsElapsedInShiftFor", 
"dDistance", "avgSecondsElapsedInShiftAgainst", "minSecondsElapsedSinceLastShiftFor", 
"avgSecondsElapsedSinceLastShiftFor", "secondsElapsedInGame", 
"goalieHeight", "dXCoordNorm", "corsiDifferential", "fenwickDifferential", 
"manDifferential", "dDistancePerSecond", "shooterSecondsElapsedSinceLastShift", 
"shooterWeight", "periodNumber", "dAngle", "goalieWeight", "dXCoordNormPerSecond", 
"shooterHeight", "goalieAge", "shooterSecondsElapsedInShift", 
"dYCoordNormPerSecond", "corsiAgainst", "secondsElapsedInPeriod", 
"maxSecondsElapsedSinceLastShiftAgainst", "dYCoordNorm", "dSecondsElapsedInSequence", 
"avgSecondsElapsedInShiftFor", "maxSecondsElapsedInShiftFor", 
"fenwickFor", "shotsFor", "fenwickAgainst", "maxSecondsElapsedSinceLastShiftFor", 
"skaterCountFor", "skaterCountAgainst", "minSecondsElapsedSinceLastShiftAgainst", 
"yCoordNorm", "goalsFor", "maxSecondsElapsedInShiftAgainst", 
"minSecondsElapsedInShiftAgainst", "shotsAgainst", "avgSecondsElapsedSinceLastShiftAgainst", 
"secondsElapsedInSequence", "shotDifferential", "goalsAgainst", 
"dAnglePerSecond", "shooterAge", "goalDifferential", "corsiFor"
), active_dummy_terms = c("shotType_tip.in", "shotType_snap", 
"zoneCode_O", "typeDescKeyPrev_tip.in.shot.on.goal.against", 
"typeDescKeyPrev_won.faceoff", "typeDescKeyPrev_post.missed.shot.against", 
"zoneCode_N", "isOvertime_yes", "shooterHandCode_R", "shooterPositionCode_D", 
"typeDescKeyPrev_blocked.shot.for", "typeDescKeyPrev_takeaway.for", 
"typeDescKeyPrev_lost.faceoff", "typeDescKeyPrev_post.missed.shot.for", 
"shooterPositionCode_R", "isRebound_yes", "shotType_other", "typeDescKeyPrev_deflected.shot.on.goal.against", 
"typeDescKeyPrev_slap.shot.on.goal.for", "typeDescKeyPrev_other.shot.on.goal.for", 
"typeDescKeyPrev_high.missed.shot.for", "typeDescKeyPrev_snap.shot.on.goal.against", 
"crossedRoyalRoad_yes", "typeDescKeyPrev_deflected.shot.on.goal.for", 
"typeDescKeyPrev_giveaway.against", "typeDescKeyPrev_slap.shot.on.goal.against", 
"typeDescKeyPrev_other.missed.shot.for", "isHome_yes", "shotType_slap", 
"typeDescKeyPrev_giveaway.for", "typeDescKeyPrev_taken.hit", 
"typeDescKeyPrev_other.shot.on.goal.against", "typeDescKeyPrev_tip.in.shot.on.goal.for", 
"typeDescKeyPrev_wrist.shot.on.goal.against", "isBehindNet_yes", 
"shooterPositionCode_L", "typeDescKeyPrev_other.missed.shot.against", 
"typeDescKeyPrev_blocked.shot.against", "typeDescKeyPrev_snap.shot.on.goal.for", 
"isRush_yes", "typeDescKeyPrev_wide.missed.shot.against", "shotType_deflected", 
"shotType_wrist", "typeDescKeyPrev_wrist.shot.on.goal.for", "typeDescKeyPrev_high.missed.shot.against", 
"isEmptyNetFor_yes", "goalieHandCode_R", "typeDescKeyPrev_given.hit", 
"isPlayoff_yes", "typeDescKeyPrev_takeaway.against", "typeDescKeyPrev_wide.missed.shot.for", 
"typeDescKeyPrev_backhand.shot.on.goal.for"), active_dummy_by_var = list(
    crossedRoyalRoad = "crossedRoyalRoad_yes", goalieHandCode = "goalieHandCode_R", 
    isBehindNet = "isBehindNet_yes", isEmptyNetFor = "isEmptyNetFor_yes", 
    isHome = "isHome_yes", isOvertime = "isOvertime_yes", isPlayoff = "isPlayoff_yes", 
    isRebound = "isRebound_yes", isRush = "isRush_yes", shooterHandCode = "shooterHandCode_R", 
    shooterPositionCode = c("shooterPositionCode_D", "shooterPositionCode_R", 
    "shooterPositionCode_L"), shotType = c("shotType_tip.in", 
    "shotType_snap", "shotType_other", "shotType_slap", "shotType_deflected", 
    "shotType_wrist"), typeDescKeyPrev = c("typeDescKeyPrev_tip.in.shot.on.goal.against", 
    "typeDescKeyPrev_won.faceoff", "typeDescKeyPrev_post.missed.shot.against", 
    "typeDescKeyPrev_blocked.shot.for", "typeDescKeyPrev_takeaway.for", 
    "typeDescKeyPrev_lost.faceoff", "typeDescKeyPrev_post.missed.shot.for", 
    "typeDescKeyPrev_deflected.shot.on.goal.against", "typeDescKeyPrev_slap.shot.on.goal.for", 
    "typeDescKeyPrev_other.shot.on.goal.for", "typeDescKeyPrev_high.missed.shot.for", 
    "typeDescKeyPrev_snap.shot.on.goal.against", "typeDescKeyPrev_deflected.shot.on.goal.for", 
    "typeDescKeyPrev_giveaway.against", "typeDescKeyPrev_slap.shot.on.goal.against", 
    "typeDescKeyPrev_other.missed.shot.for", "typeDescKeyPrev_giveaway.for", 
    "typeDescKeyPrev_taken.hit", "typeDescKeyPrev_other.shot.on.goal.against", 
    "typeDescKeyPrev_tip.in.shot.on.goal.for", "typeDescKeyPrev_wrist.shot.on.goal.against", 
    "typeDescKeyPrev_other.missed.shot.against", "typeDescKeyPrev_blocked.shot.against", 
    "typeDescKeyPrev_snap.shot.on.goal.for", "typeDescKeyPrev_wide.missed.shot.against", 
    "typeDescKeyPrev_wrist.shot.on.goal.for", "typeDescKeyPrev_high.missed.shot.against", 
    "typeDescKeyPrev_given.hit", "typeDescKeyPrev_takeaway.against", 
    "typeDescKeyPrev_wide.missed.shot.for", "typeDescKeyPrev_backhand.shot.on.goal.for"
    ), zoneCode = c("zoneCode_O", "zoneCode_N")), dummy_term_to_var = c(isPlayoff_yes = "isPlayoff", 
isPlayoff_unknown = "isPlayoff", isPlayoff_new = "isPlayoff", 
isHome_yes = "isHome", isHome_unknown = "isHome", isHome_new = "isHome", 
isOvertime_yes = "isOvertime", isOvertime_unknown = "isOvertime", 
isOvertime_new = "isOvertime", zoneCode_N = "zoneCode", zoneCode_O = "zoneCode", 
zoneCode_unknown = "zoneCode", zoneCode_new = "zoneCode", isBehindNet_yes = "isBehindNet", 
isBehindNet_unknown = "isBehindNet", isBehindNet_new = "isBehindNet", 
crossedRoyalRoad_yes = "crossedRoyalRoad", crossedRoyalRoad_unknown = "crossedRoyalRoad", 
crossedRoyalRoad_new = "crossedRoyalRoad", typeDescKeyPrev_backhand.shot.on.goal.for = "typeDescKeyPrev", 
typeDescKeyPrev_blocked.shot.against = "typeDescKeyPrev", typeDescKeyPrev_blocked.shot.for = "typeDescKeyPrev", 
typeDescKeyPrev_deflected.shot.on.goal.against = "typeDescKeyPrev", 
typeDescKeyPrev_deflected.shot.on.goal.for = "typeDescKeyPrev", 
typeDescKeyPrev_giveaway.against = "typeDescKeyPrev", typeDescKeyPrev_giveaway.for = "typeDescKeyPrev", 
typeDescKeyPrev_given.hit = "typeDescKeyPrev", typeDescKeyPrev_high.missed.shot.against = "typeDescKeyPrev", 
typeDescKeyPrev_high.missed.shot.for = "typeDescKeyPrev", typeDescKeyPrev_lost.faceoff = "typeDescKeyPrev", 
typeDescKeyPrev_other.missed.shot.against = "typeDescKeyPrev", 
typeDescKeyPrev_other.missed.shot.for = "typeDescKeyPrev", typeDescKeyPrev_other.shot.on.goal.against = "typeDescKeyPrev", 
typeDescKeyPrev_other.shot.on.goal.for = "typeDescKeyPrev", typeDescKeyPrev_post.missed.shot.against = "typeDescKeyPrev", 
typeDescKeyPrev_post.missed.shot.for = "typeDescKeyPrev", typeDescKeyPrev_slap.shot.on.goal.against = "typeDescKeyPrev", 
typeDescKeyPrev_slap.shot.on.goal.for = "typeDescKeyPrev", typeDescKeyPrev_snap.shot.on.goal.against = "typeDescKeyPrev", 
typeDescKeyPrev_snap.shot.on.goal.for = "typeDescKeyPrev", typeDescKeyPrev_takeaway.against = "typeDescKeyPrev", 
typeDescKeyPrev_takeaway.for = "typeDescKeyPrev", typeDescKeyPrev_taken.hit = "typeDescKeyPrev", 
typeDescKeyPrev_tip.in.shot.on.goal.against = "typeDescKeyPrev", 
typeDescKeyPrev_tip.in.shot.on.goal.for = "typeDescKeyPrev", 
typeDescKeyPrev_wide.missed.shot.against = "typeDescKeyPrev", 
typeDescKeyPrev_wide.missed.shot.for = "typeDescKeyPrev", typeDescKeyPrev_won.faceoff = "typeDescKeyPrev", 
typeDescKeyPrev_wrist.shot.on.goal.against = "typeDescKeyPrev", 
typeDescKeyPrev_wrist.shot.on.goal.for = "typeDescKeyPrev", typeDescKeyPrev_unknown = "typeDescKeyPrev", 
typeDescKeyPrev_new = "typeDescKeyPrev", shotType_deflected = "shotType", 
shotType_other = "shotType", shotType_slap = "shotType", shotType_snap = "shotType", 
shotType_tip.in = "shotType", shotType_wrist = "shotType", shotType_unknown = "shotType", 
shotType_new = "shotType", isRebound_yes = "isRebound", isRebound_unknown = "isRebound", 
isRebound_new = "isRebound", isRush_yes = "isRush", isRush_unknown = "isRush", 
isRush_new = "isRush", shooterHandCode_R = "shooterHandCode", 
shooterHandCode_unknown = "shooterHandCode", shooterHandCode_new = "shooterHandCode", 
shooterPositionCode_D = "shooterPositionCode", shooterPositionCode_L = "shooterPositionCode", 
shooterPositionCode_R = "shooterPositionCode", shooterPositionCode_unknown = "shooterPositionCode", 
shooterPositionCode_new = "shooterPositionCode", goalieHandCode_R = "goalieHandCode", 
goalieHandCode_unknown = "goalieHandCode", goalieHandCode_new = "goalieHandCode", 
isEmptyNetFor_yes = "isEmptyNetFor", isEmptyNetFor_unknown = "isEmptyNetFor", 
isEmptyNetFor_new = "isEmptyNetFor", strengthState_unknown = "strengthState", 
strengthState_new = "strengthState"), dummy_term_to_level = c(isPlayoff_yes = "yes", 
isPlayoff_unknown = "unknown", isPlayoff_new = "new", isHome_yes = "yes", 
isHome_unknown = "unknown", isHome_new = "new", isOvertime_yes = "yes", 
isOvertime_unknown = "unknown", isOvertime_new = "new", zoneCode_N = "N", 
zoneCode_O = "O", zoneCode_unknown = "unknown", zoneCode_new = "new", 
isBehindNet_yes = "yes", isBehindNet_unknown = "unknown", isBehindNet_new = "new", 
crossedRoyalRoad_yes = "yes", crossedRoyalRoad_unknown = "unknown", 
crossedRoyalRoad_new = "new", typeDescKeyPrev_backhand.shot.on.goal.for = "backhand-shot-on-goal-for", 
typeDescKeyPrev_blocked.shot.against = "blocked-shot-against", 
typeDescKeyPrev_blocked.shot.for = "blocked-shot-for", typeDescKeyPrev_deflected.shot.on.goal.against = "deflected-shot-on-goal-against", 
typeDescKeyPrev_deflected.shot.on.goal.for = "deflected-shot-on-goal-for", 
typeDescKeyPrev_giveaway.against = "giveaway-against", typeDescKeyPrev_giveaway.for = "giveaway-for", 
typeDescKeyPrev_given.hit = "given-hit", typeDescKeyPrev_high.missed.shot.against = "high-missed-shot-against", 
typeDescKeyPrev_high.missed.shot.for = "high-missed-shot-for", 
typeDescKeyPrev_lost.faceoff = "lost-faceoff", typeDescKeyPrev_other.missed.shot.against = "other-missed-shot-against", 
typeDescKeyPrev_other.missed.shot.for = "other-missed-shot-for", 
typeDescKeyPrev_other.shot.on.goal.against = "other-shot-on-goal-against", 
typeDescKeyPrev_other.shot.on.goal.for = "other-shot-on-goal-for", 
typeDescKeyPrev_post.missed.shot.against = "post-missed-shot-against", 
typeDescKeyPrev_post.missed.shot.for = "post-missed-shot-for", 
typeDescKeyPrev_slap.shot.on.goal.against = "slap-shot-on-goal-against", 
typeDescKeyPrev_slap.shot.on.goal.for = "slap-shot-on-goal-for", 
typeDescKeyPrev_snap.shot.on.goal.against = "snap-shot-on-goal-against", 
typeDescKeyPrev_snap.shot.on.goal.for = "snap-shot-on-goal-for", 
typeDescKeyPrev_takeaway.against = "takeaway-against", typeDescKeyPrev_takeaway.for = "takeaway-for", 
typeDescKeyPrev_taken.hit = "taken-hit", typeDescKeyPrev_tip.in.shot.on.goal.against = "tip-in-shot-on-goal-against", 
typeDescKeyPrev_tip.in.shot.on.goal.for = "tip-in-shot-on-goal-for", 
typeDescKeyPrev_wide.missed.shot.against = "wide-missed-shot-against", 
typeDescKeyPrev_wide.missed.shot.for = "wide-missed-shot-for", 
typeDescKeyPrev_won.faceoff = "won-faceoff", typeDescKeyPrev_wrist.shot.on.goal.against = "wrist-shot-on-goal-against", 
typeDescKeyPrev_wrist.shot.on.goal.for = "wrist-shot-on-goal-for", 
typeDescKeyPrev_unknown = "unknown", typeDescKeyPrev_new = "new", 
shotType_deflected = "deflected", shotType_other = "other", shotType_slap = "slap", 
shotType_snap = "snap", shotType_tip.in = "tip-in", shotType_wrist = "wrist", 
shotType_unknown = "unknown", shotType_new = "new", isRebound_yes = "yes", 
isRebound_unknown = "unknown", isRebound_new = "new", isRush_yes = "yes", 
isRush_unknown = "unknown", isRush_new = "new", shooterHandCode_R = "R", 
shooterHandCode_unknown = "unknown", shooterHandCode_new = "new", 
shooterPositionCode_D = "D", shooterPositionCode_L = "L", shooterPositionCode_R = "R", 
shooterPositionCode_unknown = "unknown", shooterPositionCode_new = "new", 
goalieHandCode_R = "R", goalieHandCode_unknown = "unknown", goalieHandCode_new = "new", 
isEmptyNetFor_yes = "yes", isEmptyNetFor_unknown = "unknown", 
isEmptyNetFor_new = "new", strengthState_unknown = "unknown", 
strengthState_new = "new"), dummy_map = list(crossedRoyalRoad = c(yes = "crossedRoyalRoad_yes", 
unknown = "crossedRoyalRoad_unknown", new = "crossedRoyalRoad_new"
), goalieHandCode = c(R = "goalieHandCode_R", unknown = "goalieHandCode_unknown", 
new = "goalieHandCode_new"), isBehindNet = c(yes = "isBehindNet_yes", 
unknown = "isBehindNet_unknown", new = "isBehindNet_new"), isEmptyNetFor = c(yes = "isEmptyNetFor_yes", 
unknown = "isEmptyNetFor_unknown", new = "isEmptyNetFor_new"), 
    isHome = c(yes = "isHome_yes", unknown = "isHome_unknown", 
    new = "isHome_new"), isOvertime = c(yes = "isOvertime_yes", 
    unknown = "isOvertime_unknown", new = "isOvertime_new"), 
    isPlayoff = c(yes = "isPlayoff_yes", unknown = "isPlayoff_unknown", 
    new = "isPlayoff_new"), isRebound = c(yes = "isRebound_yes", 
    unknown = "isRebound_unknown", new = "isRebound_new"), isRush = c(yes = "isRush_yes", 
    unknown = "isRush_unknown", new = "isRush_new"), shooterHandCode = c(R = "shooterHandCode_R", 
    unknown = "shooterHandCode_unknown", new = "shooterHandCode_new"
    ), shooterPositionCode = c(D = "shooterPositionCode_D", L = "shooterPositionCode_L", 
    R = "shooterPositionCode_R", unknown = "shooterPositionCode_unknown", 
    new = "shooterPositionCode_new"), shotType = c(deflected = "shotType_deflected", 
    other = "shotType_other", slap = "shotType_slap", snap = "shotType_snap", 
    `tip-in` = "shotType_tip.in", wrist = "shotType_wrist", unknown = "shotType_unknown", 
    new = "shotType_new"), strengthState = c(unknown = "strengthState_unknown", 
    new = "strengthState_new"), typeDescKeyPrev = c(`backhand-shot-on-goal-for` = "typeDescKeyPrev_backhand.shot.on.goal.for", 
    `blocked-shot-against` = "typeDescKeyPrev_blocked.shot.against", 
    `blocked-shot-for` = "typeDescKeyPrev_blocked.shot.for", 
    `deflected-shot-on-goal-against` = "typeDescKeyPrev_deflected.shot.on.goal.against", 
    `deflected-shot-on-goal-for` = "typeDescKeyPrev_deflected.shot.on.goal.for", 
    `giveaway-against` = "typeDescKeyPrev_giveaway.against", 
    `giveaway-for` = "typeDescKeyPrev_giveaway.for", `given-hit` = "typeDescKeyPrev_given.hit", 
    `high-missed-shot-against` = "typeDescKeyPrev_high.missed.shot.against", 
    `high-missed-shot-for` = "typeDescKeyPrev_high.missed.shot.for", 
    `lost-faceoff` = "typeDescKeyPrev_lost.faceoff", `other-missed-shot-against` = "typeDescKeyPrev_other.missed.shot.against", 
    `other-missed-shot-for` = "typeDescKeyPrev_other.missed.shot.for", 
    `other-shot-on-goal-against` = "typeDescKeyPrev_other.shot.on.goal.against", 
    `other-shot-on-goal-for` = "typeDescKeyPrev_other.shot.on.goal.for", 
    `post-missed-shot-against` = "typeDescKeyPrev_post.missed.shot.against", 
    `post-missed-shot-for` = "typeDescKeyPrev_post.missed.shot.for", 
    `slap-shot-on-goal-against` = "typeDescKeyPrev_slap.shot.on.goal.against", 
    `slap-shot-on-goal-for` = "typeDescKeyPrev_slap.shot.on.goal.for", 
    `snap-shot-on-goal-against` = "typeDescKeyPrev_snap.shot.on.goal.against", 
    `snap-shot-on-goal-for` = "typeDescKeyPrev_snap.shot.on.goal.for", 
    `takeaway-against` = "typeDescKeyPrev_takeaway.against", 
    `takeaway-for` = "typeDescKeyPrev_takeaway.for", `taken-hit` = "typeDescKeyPrev_taken.hit", 
    `tip-in-shot-on-goal-against` = "typeDescKeyPrev_tip.in.shot.on.goal.against", 
    `tip-in-shot-on-goal-for` = "typeDescKeyPrev_tip.in.shot.on.goal.for", 
    `wide-missed-shot-against` = "typeDescKeyPrev_wide.missed.shot.against", 
    `wide-missed-shot-for` = "typeDescKeyPrev_wide.missed.shot.for", 
    `won-faceoff` = "typeDescKeyPrev_won.faceoff", `wrist-shot-on-goal-against` = "typeDescKeyPrev_wrist.shot.on.goal.against", 
    `wrist-shot-on-goal-for` = "typeDescKeyPrev_wrist.shot.on.goal.for", 
    unknown = "typeDescKeyPrev_unknown", new = "typeDescKeyPrev_new"
    ), zoneCode = c(N = "zoneCode_N", O = "zoneCode_O", unknown = "zoneCode_unknown", 
    new = "zoneCode_new")), known_levels = list(isPlayoff = c("no", 
"yes"), isHome = c("no", "yes"), isOvertime = c("no", "yes"), 
    zoneCode = c("D", "N", "O"), isBehindNet = c("no", "yes"), 
    crossedRoyalRoad = c("no", "yes"), typeDescKeyPrev = c("backhand-shot-on-goal-against", 
    "backhand-shot-on-goal-for", "blocked-shot-against", "blocked-shot-for", 
    "deflected-shot-on-goal-against", "deflected-shot-on-goal-for", 
    "giveaway-against", "giveaway-for", "given-hit", "high-missed-shot-against", 
    "high-missed-shot-for", "lost-faceoff", "other-missed-shot-against", 
    "other-missed-shot-for", "other-shot-on-goal-against", "other-shot-on-goal-for", 
    "post-missed-shot-against", "post-missed-shot-for", "slap-shot-on-goal-against", 
    "slap-shot-on-goal-for", "snap-shot-on-goal-against", "snap-shot-on-goal-for", 
    "takeaway-against", "takeaway-for", "taken-hit", "tip-in-shot-on-goal-against", 
    "tip-in-shot-on-goal-for", "wide-missed-shot-against", "wide-missed-shot-for", 
    "won-faceoff", "wrist-shot-on-goal-against", "wrist-shot-on-goal-for"
    ), shotType = c("backhand", "deflected", "other", "slap", 
    "snap", "tip-in", "wrist"), isRebound = c("no", "yes"), isRush = c("no", 
    "yes"), shooterHandCode = c("L", "R"), shooterPositionCode = c("C", 
    "D", "L", "R"), goalieHandCode = c("L", "R"), isEmptyNetFor = c("no", 
    "yes"), strengthState = "penalty-kill"), logical_vars = c("crossedRoyalRoad", 
"isBehindNet", "isEmptyNetFor", "isHome", "isOvertime", "isPlayoff", 
"isRebound", "isRush"), has_unknown = c(crossedRoyalRoad = TRUE, 
goalieHandCode = TRUE, isBehindNet = TRUE, isEmptyNetFor = TRUE, 
isHome = TRUE, isOvertime = TRUE, isPlayoff = TRUE, isRebound = TRUE, 
isRush = TRUE, shooterHandCode = TRUE, shooterPositionCode = TRUE, 
shotType = TRUE, strengthState = TRUE, typeDescKeyPrev = TRUE, 
zoneCode = TRUE), has_new = c(crossedRoyalRoad = TRUE, goalieHandCode = TRUE, 
isBehindNet = TRUE, isEmptyNetFor = TRUE, isHome = TRUE, isOvertime = TRUE, 
isPlayoff = TRUE, isRebound = TRUE, isRush = TRUE, shooterHandCode = TRUE, 
shooterPositionCode = TRUE, shotType = TRUE, strengthState = TRUE, 
typeDescKeyPrev = TRUE, zoneCode = TRUE), medians = c(distance = 36.1247837363769, 
xCoordNorm = 59, angle = 21.8014094863518, minSecondsElapsedInShiftFor = 12, 
dDistance = -8.43579169116009, shotType_tip.in = 0, shotType_snap = 0, 
zoneCode_O = 1, typeDescKeyPrev_tip.in.shot.on.goal.against = 0, 
typeDescKeyPrev_won.faceoff = 0, avgSecondsElapsedInShiftAgainst = 40.4, 
typeDescKeyPrev_post.missed.shot.against = 0, zoneCode_N = 0, 
minSecondsElapsedSinceLastShiftFor = 62, avgSecondsElapsedSinceLastShiftFor = 119.5, 
secondsElapsedInGame = 1815, goalieHeight = 75, dXCoordNorm = 7, 
corsiDifferential = 0, isOvertime_yes = 0, shooterHandCode_R = 0, 
shooterPositionCode_D = 0, fenwickDifferential = 0, typeDescKeyPrev_blocked.shot.for = 0, 
manDifferential = -1, typeDescKeyPrev_takeaway.for = 0, dDistancePerSecond = -0.57176654128078, 
typeDescKeyPrev_lost.faceoff = 0, shooterSecondsElapsedSinceLastShift = 113, 
typeDescKeyPrev_post.missed.shot.for = 0, shooterWeight = 201, 
periodNumber = 2, dAngle = 1.43318147538709, goalieWeight = 201, 
dXCoordNormPerSecond = 0.454545454545455, shooterHeight = 73, 
goalieAge = 28, shooterSecondsElapsedInShift = 24, dYCoordNormPerSecond = 0.0535714285714286, 
corsiAgainst = 29, secondsElapsedInPeriod = 616, shooterPositionCode_R = 0, 
maxSecondsElapsedSinceLastShiftAgainst = 220, isRebound_yes = 0, 
shotType_other = 0, typeDescKeyPrev_deflected.shot.on.goal.against = 0, 
dYCoordNorm = 1, typeDescKeyPrev_slap.shot.on.goal.for = 0, typeDescKeyPrev_other.shot.on.goal.for = 0, 
dSecondsElapsedInSequence = 9, typeDescKeyPrev_high.missed.shot.for = 0, 
avgSecondsElapsedInShiftFor = 23.75, typeDescKeyPrev_snap.shot.on.goal.against = 0, 
maxSecondsElapsedInShiftFor = 35, crossedRoyalRoad_yes = 0, typeDescKeyPrev_deflected.shot.on.goal.for = 0, 
fenwickFor = 21, typeDescKeyPrev_giveaway.against = 0, typeDescKeyPrev_slap.shot.on.goal.against = 0, 
typeDescKeyPrev_other.missed.shot.for = 0, shotsFor = 14, fenwickAgainst = 21, 
maxSecondsElapsedSinceLastShiftFor = 183, skaterCountFor = 4, 
isHome_yes = 0, shotType_slap = 0, typeDescKeyPrev_giveaway.for = 0, 
typeDescKeyPrev_taken.hit = 0, skaterCountAgainst = 5, typeDescKeyPrev_other.shot.on.goal.against = 0, 
minSecondsElapsedSinceLastShiftAgainst = 89, typeDescKeyPrev_tip.in.shot.on.goal.for = 0, 
typeDescKeyPrev_wrist.shot.on.goal.against = 0, isBehindNet_yes = 0, 
shooterPositionCode_L = 0, yCoordNorm = 1, typeDescKeyPrev_other.missed.shot.against = 0, 
typeDescKeyPrev_blocked.shot.against = 0, goalsFor = 1, maxSecondsElapsedInShiftAgainst = 57, 
typeDescKeyPrev_snap.shot.on.goal.for = 0, isRush_yes = 0, minSecondsElapsedInShiftAgainst = 24, 
shotsAgainst = 14, avgSecondsElapsedSinceLastShiftAgainst = 150.8, 
secondsElapsedInSequence = 39, shotDifferential = 0, typeDescKeyPrev_wide.missed.shot.against = 0, 
shotType_deflected = 0, shotType_wrist = 1, goalsAgainst = 1, 
typeDescKeyPrev_wrist.shot.on.goal.for = 0, dAnglePerSecond = 0.1090902697479, 
shooterAge = 28, typeDescKeyPrev_high.missed.shot.against = 0, 
isEmptyNetFor_yes = 0, goalieHandCode_R = 0, typeDescKeyPrev_given.hit = 0, 
goalDifferential = 0, corsiFor = 29, isPlayoff_yes = 0, typeDescKeyPrev_takeaway.against = 0, 
typeDescKeyPrev_wide.missed.shot.for = 0, typeDescKeyPrev_backhand.shot.on.goal.for = 0
), normalize_means = c(distance = 63.1809537417715, xCoordNorm = 30.3849470091611, 
angle = 25.9799070157217, minSecondsElapsedInShiftFor = 13.9951499910185, 
dDistance = -15.168903996702, shotType_tip.in = 0.0226333752469912, 
shotType_snap = 0.152326208011496, zoneCode_O = 0.711514280582001, 
typeDescKeyPrev_tip.in.shot.on.goal.against = 0.00952038800071852, 
typeDescKeyPrev_won.faceoff = 0.216992994431471, avgSecondsElapsedInShiftAgainst = 43.4482126818753, 
typeDescKeyPrev_post.missed.shot.against = 0.00844260822705227, 
zoneCode_N = 0.0506556493623136, minSecondsElapsedSinceLastShiftFor = 81.1692114244656, 
avgSecondsElapsedSinceLastShiftFor = 137.533923118376, secondsElapsedInGame = 1817.75678103108, 
goalieHeight = 74.9342554338064, dXCoordNorm = 14.591880725705, 
corsiDifferential = -0.10185018861146, isOvertime_yes = 0.00359259924555416, 
shooterHandCode_R = 0.364109933536914, shooterPositionCode_D = 0.267828273756062, 
fenwickDifferential = -0.124483563858452, typeDescKeyPrev_blocked.shot.for = 0.0111370576612179, 
manDifferential = -1.00467037901922, typeDescKeyPrev_takeaway.for = 0.0934075803844081, 
dDistancePerSecond = -1.2452145492716, typeDescKeyPrev_lost.faceoff = 0.105263157894737, 
shooterSecondsElapsedSinceLastShift = 144.58828812646, typeDescKeyPrev_post.missed.shot.for = 0.00287407939644333, 
shooterWeight = 201.8785701455, periodNumber = 2.00125740973594, 
dAngle = 1.01807593296847, goalieWeight = 201.932459134184, dXCoordNormPerSecond = 0.989775309528442, 
shooterHeight = 73.4576971438836, goalieAge = 28.5611640021556, 
shooterSecondsElapsedInShift = 28.0046703790192, dYCoordNormPerSecond = 0.20206839262364, 
corsiAgainst = 30.1780132926172, secondsElapsedInPeriod = 616.247889347943, 
shooterPositionCode_R = 0.143703969822166, maxSecondsElapsedSinceLastShiftAgainst = 243.927788755164, 
isRebound_yes = 0.0465241602299264, shotType_other = 0.0113166876234956, 
typeDescKeyPrev_deflected.shot.on.goal.against = 0.00125740973594396, 
dYCoordNorm = 0.985270343093228, typeDescKeyPrev_slap.shot.on.goal.for = 0.0021555595473325, 
typeDescKeyPrev_other.shot.on.goal.for = 0.000538889886833124, 
dSecondsElapsedInSequence = 15.5194898509071, typeDescKeyPrev_high.missed.shot.for = 0.00089814981138854, 
avgSecondsElapsedInShiftFor = 25.578025267948, typeDescKeyPrev_snap.shot.on.goal.against = 0.0176037363032154, 
maxSecondsElapsedInShiftFor = 39.9904796119993, crossedRoyalRoad_yes = 0.437398958146219, 
typeDescKeyPrev_deflected.shot.on.goal.for = 0.000538889886833124, 
fenwickFor = 21.6030177833663, typeDescKeyPrev_giveaway.against = 0.128255793066283, 
typeDescKeyPrev_slap.shot.on.goal.against = 0.0197592958505479, 
typeDescKeyPrev_other.missed.shot.for = 0.000359259924555416, 
shotsFor = 14.6671456798994, fenwickAgainst = 21.7275013472247, 
maxSecondsElapsedSinceLastShiftFor = 208.098796479253, skaterCountFor = 3.99335369139572, 
isHome_yes = 0.486617567810311, shotType_slap = 0.0635890066463086, 
typeDescKeyPrev_giveaway.for = 0.014729656906772, typeDescKeyPrev_taken.hit = 0.0219148553978804, 
skaterCountAgainst = 4.99766481049039, typeDescKeyPrev_other.shot.on.goal.against = 0.00197592958505479, 
minSecondsElapsedSinceLastShiftAgainst = 105.816777438477, typeDescKeyPrev_tip.in.shot.on.goal.for = 0.00251481947188791, 
typeDescKeyPrev_wrist.shot.on.goal.against = 0.0441889707203161, 
isBehindNet_yes = 0.0113166876234956, shooterPositionCode_L = 0.172265133824322, 
yCoordNorm = 0.92635171546614, typeDescKeyPrev_other.missed.shot.against = 0.0044907490569427, 
typeDescKeyPrev_blocked.shot.against = 0.0946649901203521, goalsFor = 1.37039698221663, 
maxSecondsElapsedInShiftAgainst = 62.3698580923298, typeDescKeyPrev_snap.shot.on.goal.for = 0.00754445841566373, 
isRush_yes = 0.084246452308245, minSecondsElapsedInShiftAgainst = 28.7937848033052, 
shotsAgainst = 14.7253457876774, avgSecondsElapsedSinceLastShiftAgainst = 168.054158433627, 
secondsElapsedInSequence = 44.1534039877852, shotDifferential = -0.0582001077779774, 
typeDescKeyPrev_wide.missed.shot.against = 0.0528112089096461, 
shotType_deflected = 0.00700556852883061, shotType_wrist = 0.638045626010419, 
goalsAgainst = 1.34506915753548, typeDescKeyPrev_wrist.shot.on.goal.for = 0.0440093407580384, 
dAnglePerSecond = 0.00429356766359049, shooterAge = 28.4118915035028, 
typeDescKeyPrev_high.missed.shot.against = 0.00395185917010957, 
isEmptyNetFor_yes = 0.000359259924555416, goalieHandCode_R = 0.0574815879288665, 
typeDescKeyPrev_given.hit = 0.0481408298904257, goalDifferential = 0.0253278246811568, 
corsiFor = 30.0761631040057, isPlayoff_yes = 0.0610741871744207, 
typeDescKeyPrev_takeaway.against = 0.0111370576612179, typeDescKeyPrev_wide.missed.shot.for = 0.0176037363032154, 
typeDescKeyPrev_backhand.shot.on.goal.for = 0.0068259385665529
), normalize_sds = c(distance = 58.6677538893601, xCoordNorm = 59.8407427368433, 
angle = 21.1496411383108, minSecondsElapsedInShiftFor = 12.8123838893787, 
dDistance = 76.8631528193355, shotType_tip.in = 0.148745016384372, 
shotType_snap = 0.35936907613108, zoneCode_O = 0.453098870984346, 
typeDescKeyPrev_tip.in.shot.on.goal.against = 0.0971156237844054, 
typeDescKeyPrev_won.faceoff = 0.412234836806347, avgSecondsElapsedInShiftAgainst = 25.1049188403975, 
typeDescKeyPrev_post.missed.shot.against = 0.0915031945089388, 
zoneCode_N = 0.21931323362902, minSecondsElapsedSinceLastShiftFor = 70.7051219197829, 
avgSecondsElapsedSinceLastShiftFor = 73.5945589068384, secondsElapsedInGame = 938.507272145994, 
goalieHeight = 1.63295304921384, dXCoordNorm = 79.1491366609479, 
corsiDifferential = 12.8502475815637, isOvertime_yes = 0.059835905706905, 
shooterHandCode_R = 0.481222908570225, shooterPositionCode_D = 0.442867384925269, 
fenwickDifferential = 9.63784324618641, typeDescKeyPrev_blocked.shot.for = 0.104952380784357, 
manDifferential = 0.0681865217685952, typeDescKeyPrev_takeaway.for = 0.291028896464069, 
dDistancePerSecond = 29.490560588503, typeDescKeyPrev_lost.faceoff = 0.306919772223429, 
shooterSecondsElapsedSinceLastShift = 103.38073003469, typeDescKeyPrev_post.missed.shot.for = 0.0535381540914937, 
shooterWeight = 14.9852359573519, periodNumber = 0.778920911406041, 
dAngle = 30.9008544780758, goalieWeight = 15.4345639522836, dXCoordNormPerSecond = 30.8451887863004, 
shooterHeight = 2.09270363261508, goalieAge = 3.69529626080676, 
shooterSecondsElapsedInShift = 19.4431733162066, dYCoordNormPerSecond = 10.365677123193, 
corsiAgainst = 17.0954633408751, secondsElapsedInPeriod = 337.523589602319, 
shooterPositionCode_R = 0.350820818768588, maxSecondsElapsedSinceLastShiftAgainst = 110.176783572376, 
isRebound_yes = 0.210636256378092, shotType_other = 0.105785775873895, 
typeDescKeyPrev_deflected.shot.on.goal.against = 0.0354408561082151, 
dYCoordNorm = 29.5408047182312, typeDescKeyPrev_slap.shot.on.goal.for = 0.0463821037494733, 
typeDescKeyPrev_other.shot.on.goal.for = 0.0232098309022316, 
dSecondsElapsedInSequence = 16.4104273669405, typeDescKeyPrev_high.missed.shot.for = 0.029958377075181, 
avgSecondsElapsedInShiftFor = 14.0698717367964, typeDescKeyPrev_snap.shot.on.goal.against = 0.131517876435811, 
maxSecondsElapsedInShiftFor = 25.9106736061195, crossedRoyalRoad_yes = 0.496110190422404, 
typeDescKeyPrev_deflected.shot.on.goal.for = 0.0232098309022309, 
fenwickFor = 12.9887916336736, typeDescKeyPrev_giveaway.against = 0.334404443707038, 
typeDescKeyPrev_slap.shot.on.goal.against = 0.139184575049848, 
typeDescKeyPrev_other.missed.shot.for = 0.0189524504778257, shotsFor = 9.02788649845418, 
fenwickAgainst = 12.5672436343953, maxSecondsElapsedSinceLastShiftFor = 110.294115393318, 
skaterCountFor = 0.106181634243063, isHome_yes = 0.499865775875685, 
shotType_slap = 0.244041273041567, typeDescKeyPrev_giveaway.for = 0.120479465043808, 
typeDescKeyPrev_taken.hit = 0.146418733425504, skaterCountAgainst = 0.0857945076631566, 
typeDescKeyPrev_other.shot.on.goal.against = 0.0444114803378586, 
minSecondsElapsedSinceLastShiftAgainst = 76.9201922404384, typeDescKeyPrev_tip.in.shot.on.goal.for = 0.0500893784824438, 
typeDescKeyPrev_wrist.shot.on.goal.against = 0.205533194049181, 
isBehindNet_yes = 0.105785775873894, shooterPositionCode_L = 0.377644641833166, 
yCoordNorm = 20.4044349038331, typeDescKeyPrev_other.missed.shot.against = 0.0668684187389328, 
typeDescKeyPrev_blocked.shot.against = 0.292777949056241, goalsFor = 1.41473696227119, 
maxSecondsElapsedInShiftAgainst = 36.6084679402859, typeDescKeyPrev_snap.shot.on.goal.for = 0.0865383428947544, 
isRush_yes = 0.27778201587083, minSecondsElapsedInShiftAgainst = 23.6446141914994, 
shotsAgainst = 8.83447675113178, avgSecondsElapsedSinceLastShiftAgainst = 76.0260045129353, 
secondsElapsedInSequence = 32.9875437705848, shotDifferential = 7.02138746912391, 
typeDescKeyPrev_wide.missed.shot.against = 0.223676490093908, 
shotType_deflected = 0.0834130706607534, shotType_wrist = 0.480608881469885, 
goalsAgainst = 1.38482368618566, typeDescKeyPrev_wrist.shot.on.goal.for = 0.205134291445436, 
dAnglePerSecond = 12.9392293300766, shooterAge = 3.83247214686059, 
typeDescKeyPrev_high.missed.shot.against = 0.0627451127438685, 
isEmptyNetFor_yes = 0.0189524504778259, goalieHandCode_R = 0.232781418117279, 
typeDescKeyPrev_given.hit = 0.214082981814658, goalDifferential = 1.7152393806928, 
corsiFor = 17.8397853770828, isPlayoff_yes = 0.239487856498219, 
typeDescKeyPrev_takeaway.against = 0.104952380784357, typeDescKeyPrev_wide.missed.shot.for = 0.131517876435809, 
typeDescKeyPrev_backhand.shot.on.goal.for = 0.0823441747881165
)), en = list(coefficients = c(`(Intercept)` = 0.358992590226874, 
distance = -0.339259719257798, angle = -0.322322770061326, xCoordNorm = 0.234621243387866, 
zoneCode_O = 0.21534584416679, shotType_wrist = 0.181597924633319, 
dDistancePerSecond = -0.153153415641791, typeDescKeyPrev_takeaway.against = -0.138881176805622, 
shotType_snap = 0.138188123096424, dDistance = -0.13801366597764, 
corsiFor = 0.135638265681385, shotType_other = 0.129322136271426, 
typeDescKeyPrev_blocked.shot.for = -0.128445353256351, dAngle = -0.125034687868652, 
typeDescKeyPrev_blocked.shot.against = 0.110808240565555, dYCoordNormPerSecond = -0.104422517312544, 
dXCoordNormPerSecond = 0.09845469169962, isRush_yes = -0.0971751230311377, 
shotType_deflected = 0.0927685209789503, typeDescKeyPrev_high.missed.shot.against = 0.0884401808524156, 
typeDescKeyPrev_takeaway.for = 0.0881819866655735, minSecondsElapsedInShiftFor = 0.072896424098742, 
typeDescKeyPrev_high.missed.shot.for = -0.0718080015191672, isHome_yes = -0.0712966389442882, 
zoneCode_N = -0.0687102939677219, maxSecondsElapsedInShiftAgainst = 0.0684352635817362, 
maxSecondsElapsedInShiftFor = 0.0672820377865518, isPlayoff_yes = 0.0671836564327116, 
typeDescKeyPrev_deflected.shot.on.goal.against = 0.0671695907051486, 
shotType_slap = 0.0657160014861867, crossedRoyalRoad_yes = -0.061731021473829, 
shooterPositionCode_R = 0.0598889101623524, shooterPositionCode_L = -0.0583103923007061, 
dXCoordNorm = 0.0566962948009291, corsiDifferential = 0.0566395103440728, 
avgSecondsElapsedInShiftFor = 0.0553996501594768, secondsElapsedInPeriod = -0.054318403297663, 
shooterWeight = 0.0495921017692478, typeDescKeyPrev_given.hit = -0.0476581923611311, 
secondsElapsedInGame = -0.0443119003674056, typeDescKeyPrev_other.shot.on.goal.against = -0.0425469800798999, 
skaterCountAgainst = 0.0412794646706844, typeDescKeyPrev_giveaway.against = 0.0395032838511861, 
fenwickFor = -0.0388249241472325, typeDescKeyPrev_post.missed.shot.for = 0.0377128045820563, 
isRebound_yes = -0.0363963007464233, corsiAgainst = 0.0338868984092933, 
avgSecondsElapsedSinceLastShiftFor = -0.0334931649244189, isOvertime_yes = 0.0332468981879563, 
periodNumber = 0.0332427613358308, typeDescKeyPrev_lost.faceoff = -0.0329052664237163, 
maxSecondsElapsedSinceLastShiftFor = 0.032385486765552, shooterAge = 0.0316700916540132, 
goalDifferential = -0.0316304951877376, fenwickDifferential = -0.0310776265813251, 
maxSecondsElapsedSinceLastShiftAgainst = 0.0309954611251061, 
dAnglePerSecond = 0.0300889688595502, shooterSecondsElapsedSinceLastShift = -0.0299043130556757, 
goalsAgainst = 0.028867370763428, typeDescKeyPrev_tip.in.shot.on.goal.against = 0.0280193698069366, 
dYCoordNorm = 0.02704421220711, typeDescKeyPrev_won.faceoff = -0.0264136334899004, 
typeDescKeyPrev_wide.missed.shot.for = -0.0260846134307286, minSecondsElapsedInShiftAgainst = 0.0258828774869373, 
shooterHeight = -0.0254869214514688, typeDescKeyPrev_snap.shot.on.goal.against = -0.0254745741172278, 
manDifferential = -0.0253481208172621, minSecondsElapsedSinceLastShiftFor = 0.024985176822828, 
shooterPositionCode_D = 0.0237316157078179, shotsAgainst = -0.0229905732024914, 
typeDescKeyPrev_wide.missed.shot.against = -0.0227472174191103, 
typeDescKeyPrev_wrist.shot.on.goal.against = -0.0215450881694877, 
shotType_tip.in = -0.0197091411616381, shooterSecondsElapsedInShift = -0.0182158560675903, 
fenwickAgainst = 0.0144940715332119, strengthState_penalty.kill = -0.0129773384245651, 
secondsElapsedInSequence = -0.0123082172822855, typeDescKeyPrev_other.missed.shot.against = 0.0122735653613287, 
avgSecondsElapsedInShiftAgainst = 0.0116870089929426, yCoordNorm = 0.0113480484338671, 
typeDescKeyPrev_wrist.shot.on.goal.for = -0.0105914774885016, 
strengthState_power.play = 0.0102648585563287, shotsFor = -0.0101001219082209, 
isBehindNet_yes = 0.0100330680989801, typeDescKeyPrev_slap.shot.on.goal.against = 0.0099315727329714, 
goalsFor = 0.0095755716860291, minSecondsElapsedSinceLastShiftAgainst = -0.00887533754159351, 
shotDifferential = 0.00864494268147159, avgSecondsElapsedSinceLastShiftAgainst = -0.0073785340518477, 
shooterHandCode_R = -0.00442281829414478, skaterCountFor = 0.00254772706094163, 
typeDescKeyPrev_post.missed.shot.against = -0.0019381584795818, 
typeDescKeyPrev_giveaway.for = 0.00188063209656073, typeDescKeyPrev_backhand.shot.on.goal.for = -0.00187168118066526, 
dSecondsElapsedInSequence = 0.000997763377465499, typeDescKeyPrev_taken.hit = -0.00013632266227135
), raw_terms = c("distance", "angle", "xCoordNorm", "dDistancePerSecond", 
"dDistance", "corsiFor", "dAngle", "dYCoordNormPerSecond", "dXCoordNormPerSecond", 
"minSecondsElapsedInShiftFor", "maxSecondsElapsedInShiftAgainst", 
"maxSecondsElapsedInShiftFor", "dXCoordNorm", "corsiDifferential", 
"avgSecondsElapsedInShiftFor", "secondsElapsedInPeriod", "shooterWeight", 
"secondsElapsedInGame", "skaterCountAgainst", "fenwickFor", "corsiAgainst", 
"avgSecondsElapsedSinceLastShiftFor", "periodNumber", "maxSecondsElapsedSinceLastShiftFor", 
"shooterAge", "goalDifferential", "fenwickDifferential", "maxSecondsElapsedSinceLastShiftAgainst", 
"dAnglePerSecond", "shooterSecondsElapsedSinceLastShift", "goalsAgainst", 
"dYCoordNorm", "minSecondsElapsedInShiftAgainst", "shooterHeight", 
"manDifferential", "minSecondsElapsedSinceLastShiftFor", "shotsAgainst", 
"shooterSecondsElapsedInShift", "fenwickAgainst", "secondsElapsedInSequence", 
"avgSecondsElapsedInShiftAgainst", "yCoordNorm", "shotsFor", 
"goalsFor", "minSecondsElapsedSinceLastShiftAgainst", "shotDifferential", 
"avgSecondsElapsedSinceLastShiftAgainst", "skaterCountFor", "dSecondsElapsedInSequence"
), active_dummy_terms = c("zoneCode_O", "shotType_wrist", "typeDescKeyPrev_takeaway.against", 
"shotType_snap", "shotType_other", "typeDescKeyPrev_blocked.shot.for", 
"typeDescKeyPrev_blocked.shot.against", "isRush_yes", "shotType_deflected", 
"typeDescKeyPrev_high.missed.shot.against", "typeDescKeyPrev_takeaway.for", 
"typeDescKeyPrev_high.missed.shot.for", "isHome_yes", "zoneCode_N", 
"isPlayoff_yes", "typeDescKeyPrev_deflected.shot.on.goal.against", 
"shotType_slap", "crossedRoyalRoad_yes", "shooterPositionCode_R", 
"shooterPositionCode_L", "typeDescKeyPrev_given.hit", "typeDescKeyPrev_other.shot.on.goal.against", 
"typeDescKeyPrev_giveaway.against", "typeDescKeyPrev_post.missed.shot.for", 
"isRebound_yes", "isOvertime_yes", "typeDescKeyPrev_lost.faceoff", 
"typeDescKeyPrev_tip.in.shot.on.goal.against", "typeDescKeyPrev_won.faceoff", 
"typeDescKeyPrev_wide.missed.shot.for", "typeDescKeyPrev_snap.shot.on.goal.against", 
"shooterPositionCode_D", "typeDescKeyPrev_wide.missed.shot.against", 
"typeDescKeyPrev_wrist.shot.on.goal.against", "shotType_tip.in", 
"strengthState_penalty.kill", "typeDescKeyPrev_other.missed.shot.against", 
"typeDescKeyPrev_wrist.shot.on.goal.for", "strengthState_power.play", 
"isBehindNet_yes", "typeDescKeyPrev_slap.shot.on.goal.against", 
"shooterHandCode_R", "typeDescKeyPrev_post.missed.shot.against", 
"typeDescKeyPrev_giveaway.for", "typeDescKeyPrev_backhand.shot.on.goal.for", 
"typeDescKeyPrev_taken.hit"), active_dummy_by_var = list(crossedRoyalRoad = "crossedRoyalRoad_yes", 
    isBehindNet = "isBehindNet_yes", isHome = "isHome_yes", isOvertime = "isOvertime_yes", 
    isPlayoff = "isPlayoff_yes", isRebound = "isRebound_yes", 
    isRush = "isRush_yes", shooterHandCode = "shooterHandCode_R", 
    shooterPositionCode = c("shooterPositionCode_R", "shooterPositionCode_L", 
    "shooterPositionCode_D"), shotType = c("shotType_wrist", 
    "shotType_snap", "shotType_other", "shotType_deflected", 
    "shotType_slap", "shotType_tip.in"), strengthState = c("strengthState_penalty.kill", 
    "strengthState_power.play"), typeDescKeyPrev = c("typeDescKeyPrev_takeaway.against", 
    "typeDescKeyPrev_blocked.shot.for", "typeDescKeyPrev_blocked.shot.against", 
    "typeDescKeyPrev_high.missed.shot.against", "typeDescKeyPrev_takeaway.for", 
    "typeDescKeyPrev_high.missed.shot.for", "typeDescKeyPrev_deflected.shot.on.goal.against", 
    "typeDescKeyPrev_given.hit", "typeDescKeyPrev_other.shot.on.goal.against", 
    "typeDescKeyPrev_giveaway.against", "typeDescKeyPrev_post.missed.shot.for", 
    "typeDescKeyPrev_lost.faceoff", "typeDescKeyPrev_tip.in.shot.on.goal.against", 
    "typeDescKeyPrev_won.faceoff", "typeDescKeyPrev_wide.missed.shot.for", 
    "typeDescKeyPrev_snap.shot.on.goal.against", "typeDescKeyPrev_wide.missed.shot.against", 
    "typeDescKeyPrev_wrist.shot.on.goal.against", "typeDescKeyPrev_other.missed.shot.against", 
    "typeDescKeyPrev_wrist.shot.on.goal.for", "typeDescKeyPrev_slap.shot.on.goal.against", 
    "typeDescKeyPrev_post.missed.shot.against", "typeDescKeyPrev_giveaway.for", 
    "typeDescKeyPrev_backhand.shot.on.goal.for", "typeDescKeyPrev_taken.hit"
    ), zoneCode = c("zoneCode_O", "zoneCode_N")), dummy_term_to_var = c(isPlayoff_yes = "isPlayoff", 
isPlayoff_unknown = "isPlayoff", isPlayoff_new = "isPlayoff", 
isHome_yes = "isHome", isHome_unknown = "isHome", isHome_new = "isHome", 
isOvertime_yes = "isOvertime", isOvertime_unknown = "isOvertime", 
isOvertime_new = "isOvertime", zoneCode_N = "zoneCode", zoneCode_O = "zoneCode", 
zoneCode_unknown = "zoneCode", zoneCode_new = "zoneCode", isBehindNet_yes = "isBehindNet", 
isBehindNet_unknown = "isBehindNet", isBehindNet_new = "isBehindNet", 
crossedRoyalRoad_yes = "crossedRoyalRoad", crossedRoyalRoad_unknown = "crossedRoyalRoad", 
crossedRoyalRoad_new = "crossedRoyalRoad", typeDescKeyPrev_backhand.shot.on.goal.for = "typeDescKeyPrev", 
typeDescKeyPrev_blocked.shot.against = "typeDescKeyPrev", typeDescKeyPrev_blocked.shot.for = "typeDescKeyPrev", 
typeDescKeyPrev_deflected.shot.on.goal.against = "typeDescKeyPrev", 
typeDescKeyPrev_giveaway.against = "typeDescKeyPrev", typeDescKeyPrev_giveaway.for = "typeDescKeyPrev", 
typeDescKeyPrev_given.hit = "typeDescKeyPrev", typeDescKeyPrev_high.missed.shot.against = "typeDescKeyPrev", 
typeDescKeyPrev_high.missed.shot.for = "typeDescKeyPrev", typeDescKeyPrev_lost.faceoff = "typeDescKeyPrev", 
typeDescKeyPrev_other.missed.shot.against = "typeDescKeyPrev", 
typeDescKeyPrev_other.shot.on.goal.against = "typeDescKeyPrev", 
typeDescKeyPrev_post.missed.shot.against = "typeDescKeyPrev", 
typeDescKeyPrev_post.missed.shot.for = "typeDescKeyPrev", typeDescKeyPrev_slap.shot.on.goal.against = "typeDescKeyPrev", 
typeDescKeyPrev_snap.shot.on.goal.against = "typeDescKeyPrev", 
typeDescKeyPrev_takeaway.against = "typeDescKeyPrev", typeDescKeyPrev_takeaway.for = "typeDescKeyPrev", 
typeDescKeyPrev_taken.hit = "typeDescKeyPrev", typeDescKeyPrev_tip.in.shot.on.goal.against = "typeDescKeyPrev", 
typeDescKeyPrev_wide.missed.shot.against = "typeDescKeyPrev", 
typeDescKeyPrev_wide.missed.shot.for = "typeDescKeyPrev", typeDescKeyPrev_won.faceoff = "typeDescKeyPrev", 
typeDescKeyPrev_wrist.shot.on.goal.against = "typeDescKeyPrev", 
typeDescKeyPrev_wrist.shot.on.goal.for = "typeDescKeyPrev", typeDescKeyPrev_unknown = "typeDescKeyPrev", 
typeDescKeyPrev_new = "typeDescKeyPrev", shotType_deflected = "shotType", 
shotType_other = "shotType", shotType_slap = "shotType", shotType_snap = "shotType", 
shotType_tip.in = "shotType", shotType_wrist = "shotType", shotType_unknown = "shotType", 
shotType_new = "shotType", isRebound_yes = "isRebound", isRebound_unknown = "isRebound", 
isRebound_new = "isRebound", isRush_yes = "isRush", isRush_unknown = "isRush", 
isRush_new = "isRush", shooterHandCode_R = "shooterHandCode", 
shooterHandCode_unknown = "shooterHandCode", shooterHandCode_new = "shooterHandCode", 
shooterPositionCode_D = "shooterPositionCode", shooterPositionCode_L = "shooterPositionCode", 
shooterPositionCode_R = "shooterPositionCode", shooterPositionCode_unknown = "shooterPositionCode", 
shooterPositionCode_new = "shooterPositionCode", isEmptyNetFor_yes = "isEmptyNetFor", 
isEmptyNetFor_unknown = "isEmptyNetFor", isEmptyNetFor_new = "isEmptyNetFor", 
strengthState_penalty.kill = "strengthState", strengthState_power.play = "strengthState", 
strengthState_unknown = "strengthState", strengthState_new = "strengthState"
), dummy_term_to_level = c(isPlayoff_yes = "yes", isPlayoff_unknown = "unknown", 
isPlayoff_new = "new", isHome_yes = "yes", isHome_unknown = "unknown", 
isHome_new = "new", isOvertime_yes = "yes", isOvertime_unknown = "unknown", 
isOvertime_new = "new", zoneCode_N = "N", zoneCode_O = "O", zoneCode_unknown = "unknown", 
zoneCode_new = "new", isBehindNet_yes = "yes", isBehindNet_unknown = "unknown", 
isBehindNet_new = "new", crossedRoyalRoad_yes = "yes", crossedRoyalRoad_unknown = "unknown", 
crossedRoyalRoad_new = "new", typeDescKeyPrev_backhand.shot.on.goal.for = "backhand-shot-on-goal-for", 
typeDescKeyPrev_blocked.shot.against = "blocked-shot-against", 
typeDescKeyPrev_blocked.shot.for = "blocked-shot-for", typeDescKeyPrev_deflected.shot.on.goal.against = "deflected-shot-on-goal-against", 
typeDescKeyPrev_giveaway.against = "giveaway-against", typeDescKeyPrev_giveaway.for = "giveaway-for", 
typeDescKeyPrev_given.hit = "given-hit", typeDescKeyPrev_high.missed.shot.against = "high-missed-shot-against", 
typeDescKeyPrev_high.missed.shot.for = "high-missed-shot-for", 
typeDescKeyPrev_lost.faceoff = "lost-faceoff", typeDescKeyPrev_other.missed.shot.against = "other-missed-shot-against", 
typeDescKeyPrev_other.shot.on.goal.against = "other-shot-on-goal-against", 
typeDescKeyPrev_post.missed.shot.against = "post-missed-shot-against", 
typeDescKeyPrev_post.missed.shot.for = "post-missed-shot-for", 
typeDescKeyPrev_slap.shot.on.goal.against = "slap-shot-on-goal-against", 
typeDescKeyPrev_snap.shot.on.goal.against = "snap-shot-on-goal-against", 
typeDescKeyPrev_takeaway.against = "takeaway-against", typeDescKeyPrev_takeaway.for = "takeaway-for", 
typeDescKeyPrev_taken.hit = "taken-hit", typeDescKeyPrev_tip.in.shot.on.goal.against = "tip-in-shot-on-goal-against", 
typeDescKeyPrev_wide.missed.shot.against = "wide-missed-shot-against", 
typeDescKeyPrev_wide.missed.shot.for = "wide-missed-shot-for", 
typeDescKeyPrev_won.faceoff = "won-faceoff", typeDescKeyPrev_wrist.shot.on.goal.against = "wrist-shot-on-goal-against", 
typeDescKeyPrev_wrist.shot.on.goal.for = "wrist-shot-on-goal-for", 
typeDescKeyPrev_unknown = "unknown", typeDescKeyPrev_new = "new", 
shotType_deflected = "deflected", shotType_other = "other", shotType_slap = "slap", 
shotType_snap = "snap", shotType_tip.in = "tip-in", shotType_wrist = "wrist", 
shotType_unknown = "unknown", shotType_new = "new", isRebound_yes = "yes", 
isRebound_unknown = "unknown", isRebound_new = "new", isRush_yes = "yes", 
isRush_unknown = "unknown", isRush_new = "new", shooterHandCode_R = "R", 
shooterHandCode_unknown = "unknown", shooterHandCode_new = "new", 
shooterPositionCode_D = "D", shooterPositionCode_L = "L", shooterPositionCode_R = "R", 
shooterPositionCode_unknown = "unknown", shooterPositionCode_new = "new", 
isEmptyNetFor_yes = "yes", isEmptyNetFor_unknown = "unknown", 
isEmptyNetFor_new = "new", strengthState_penalty.kill = "penalty-kill", 
strengthState_power.play = "power-play", strengthState_unknown = "unknown", 
strengthState_new = "new"), dummy_map = list(crossedRoyalRoad = c(yes = "crossedRoyalRoad_yes", 
unknown = "crossedRoyalRoad_unknown", new = "crossedRoyalRoad_new"
), isBehindNet = c(yes = "isBehindNet_yes", unknown = "isBehindNet_unknown", 
new = "isBehindNet_new"), isEmptyNetFor = c(yes = "isEmptyNetFor_yes", 
unknown = "isEmptyNetFor_unknown", new = "isEmptyNetFor_new"), 
    isHome = c(yes = "isHome_yes", unknown = "isHome_unknown", 
    new = "isHome_new"), isOvertime = c(yes = "isOvertime_yes", 
    unknown = "isOvertime_unknown", new = "isOvertime_new"), 
    isPlayoff = c(yes = "isPlayoff_yes", unknown = "isPlayoff_unknown", 
    new = "isPlayoff_new"), isRebound = c(yes = "isRebound_yes", 
    unknown = "isRebound_unknown", new = "isRebound_new"), isRush = c(yes = "isRush_yes", 
    unknown = "isRush_unknown", new = "isRush_new"), shooterHandCode = c(R = "shooterHandCode_R", 
    unknown = "shooterHandCode_unknown", new = "shooterHandCode_new"
    ), shooterPositionCode = c(D = "shooterPositionCode_D", L = "shooterPositionCode_L", 
    R = "shooterPositionCode_R", unknown = "shooterPositionCode_unknown", 
    new = "shooterPositionCode_new"), shotType = c(deflected = "shotType_deflected", 
    other = "shotType_other", slap = "shotType_slap", snap = "shotType_snap", 
    `tip-in` = "shotType_tip.in", wrist = "shotType_wrist", unknown = "shotType_unknown", 
    new = "shotType_new"), strengthState = c(`penalty-kill` = "strengthState_penalty.kill", 
    `power-play` = "strengthState_power.play", unknown = "strengthState_unknown", 
    new = "strengthState_new"), typeDescKeyPrev = c(`backhand-shot-on-goal-for` = "typeDescKeyPrev_backhand.shot.on.goal.for", 
    `blocked-shot-against` = "typeDescKeyPrev_blocked.shot.against", 
    `blocked-shot-for` = "typeDescKeyPrev_blocked.shot.for", 
    `deflected-shot-on-goal-against` = "typeDescKeyPrev_deflected.shot.on.goal.against", 
    `giveaway-against` = "typeDescKeyPrev_giveaway.against", 
    `giveaway-for` = "typeDescKeyPrev_giveaway.for", `given-hit` = "typeDescKeyPrev_given.hit", 
    `high-missed-shot-against` = "typeDescKeyPrev_high.missed.shot.against", 
    `high-missed-shot-for` = "typeDescKeyPrev_high.missed.shot.for", 
    `lost-faceoff` = "typeDescKeyPrev_lost.faceoff", `other-missed-shot-against` = "typeDescKeyPrev_other.missed.shot.against", 
    `other-shot-on-goal-against` = "typeDescKeyPrev_other.shot.on.goal.against", 
    `post-missed-shot-against` = "typeDescKeyPrev_post.missed.shot.against", 
    `post-missed-shot-for` = "typeDescKeyPrev_post.missed.shot.for", 
    `slap-shot-on-goal-against` = "typeDescKeyPrev_slap.shot.on.goal.against", 
    `snap-shot-on-goal-against` = "typeDescKeyPrev_snap.shot.on.goal.against", 
    `takeaway-against` = "typeDescKeyPrev_takeaway.against", 
    `takeaway-for` = "typeDescKeyPrev_takeaway.for", `taken-hit` = "typeDescKeyPrev_taken.hit", 
    `tip-in-shot-on-goal-against` = "typeDescKeyPrev_tip.in.shot.on.goal.against", 
    `wide-missed-shot-against` = "typeDescKeyPrev_wide.missed.shot.against", 
    `wide-missed-shot-for` = "typeDescKeyPrev_wide.missed.shot.for", 
    `won-faceoff` = "typeDescKeyPrev_won.faceoff", `wrist-shot-on-goal-against` = "typeDescKeyPrev_wrist.shot.on.goal.against", 
    `wrist-shot-on-goal-for` = "typeDescKeyPrev_wrist.shot.on.goal.for", 
    unknown = "typeDescKeyPrev_unknown", new = "typeDescKeyPrev_new"
    ), zoneCode = c(N = "zoneCode_N", O = "zoneCode_O", unknown = "zoneCode_unknown", 
    new = "zoneCode_new")), known_levels = list(isPlayoff = c("no", 
"yes"), isHome = c("no", "yes"), isOvertime = c("no", "yes"), 
    zoneCode = c("D", "N", "O"), isBehindNet = c("no", "yes"), 
    crossedRoyalRoad = c("no", "yes"), typeDescKeyPrev = c("backhand-shot-on-goal-against", 
    "backhand-shot-on-goal-for", "blocked-shot-against", "blocked-shot-for", 
    "deflected-shot-on-goal-against", "giveaway-against", "giveaway-for", 
    "given-hit", "high-missed-shot-against", "high-missed-shot-for", 
    "lost-faceoff", "other-missed-shot-against", "other-shot-on-goal-against", 
    "post-missed-shot-against", "post-missed-shot-for", "slap-shot-on-goal-against", 
    "snap-shot-on-goal-against", "takeaway-against", "takeaway-for", 
    "taken-hit", "tip-in-shot-on-goal-against", "wide-missed-shot-against", 
    "wide-missed-shot-for", "won-faceoff", "wrist-shot-on-goal-against", 
    "wrist-shot-on-goal-for"), shotType = c("backhand", "deflected", 
    "other", "slap", "snap", "tip-in", "wrist"), isRebound = c("no", 
    "yes"), isRush = c("no", "yes"), shooterHandCode = c("L", 
    "R"), shooterPositionCode = c("C", "D", "L", "R"), isEmptyNetFor = c("no", 
    "yes"), strengthState = c("even-strength", "penalty-kill", 
    "power-play")), logical_vars = c("crossedRoyalRoad", "isBehindNet", 
"isEmptyNetFor", "isHome", "isOvertime", "isPlayoff", "isRebound", 
"isRush"), has_unknown = c(crossedRoyalRoad = TRUE, isBehindNet = TRUE, 
isEmptyNetFor = TRUE, isHome = TRUE, isOvertime = TRUE, isPlayoff = TRUE, 
isRebound = TRUE, isRush = TRUE, shooterHandCode = TRUE, shooterPositionCode = TRUE, 
shotType = TRUE, strengthState = TRUE, typeDescKeyPrev = TRUE, 
zoneCode = TRUE), has_new = c(crossedRoyalRoad = TRUE, isBehindNet = TRUE, 
isEmptyNetFor = TRUE, isHome = TRUE, isOvertime = TRUE, isPlayoff = TRUE, 
isRebound = TRUE, isRush = TRUE, shooterHandCode = TRUE, shooterPositionCode = TRUE, 
shotType = TRUE, strengthState = TRUE, typeDescKeyPrev = TRUE, 
zoneCode = TRUE), medians = c(distance = 83.1955405552883, angle = 15.8380000013696, 
xCoordNorm = 11, zoneCode_O = 0, shotType_wrist = 1, dDistancePerSecond = 1.18128575642463, 
typeDescKeyPrev_takeaway.against = 0, shotType_snap = 0, dDistance = 15.6124665490398, 
corsiFor = 56, shotType_other = 0, typeDescKeyPrev_blocked.shot.for = 0, 
dAngle = -3.36402503261127, typeDescKeyPrev_blocked.shot.against = 0, 
dYCoordNormPerSecond = 0.149839743589744, dXCoordNormPerSecond = -1.22649572649573, 
isRush_yes = 0, shotType_deflected = 0, typeDescKeyPrev_high.missed.shot.against = 0, 
typeDescKeyPrev_takeaway.for = 0, minSecondsElapsedInShiftFor = 24, 
typeDescKeyPrev_high.missed.shot.for = 0, isHome_yes = 1, zoneCode_N = 0, 
maxSecondsElapsedInShiftAgainst = 83, maxSecondsElapsedInShiftFor = 62, 
isPlayoff_yes = 0, typeDescKeyPrev_deflected.shot.on.goal.against = 0, 
shotType_slap = 0, crossedRoyalRoad_yes = 0, shooterPositionCode_R = 0, 
shooterPositionCode_L = 0, dXCoordNorm = -17, corsiDifferential = -4, 
avgSecondsElapsedInShiftFor = 42.9, secondsElapsedInPeriod = 1121, 
shooterWeight = 200, typeDescKeyPrev_given.hit = 0, secondsElapsedInGame = 3521, 
typeDescKeyPrev_other.shot.on.goal.against = 0, skaterCountAgainst = 6, 
typeDescKeyPrev_giveaway.against = 0, fenwickFor = 41, typeDescKeyPrev_post.missed.shot.for = 0, 
isRebound_yes = 0, corsiAgainst = 59, avgSecondsElapsedSinceLastShiftFor = 130.9, 
isOvertime_yes = 0, periodNumber = 3, typeDescKeyPrev_lost.faceoff = 0, 
maxSecondsElapsedSinceLastShiftFor = 182, shooterAge = 28, goalDifferential = 2, 
fenwickDifferential = -1, maxSecondsElapsedSinceLastShiftAgainst = 206.5, 
dAnglePerSecond = -0.273920225223822, shooterSecondsElapsedSinceLastShift = 129, 
goalsAgainst = 2, typeDescKeyPrev_tip.in.shot.on.goal.against = 0, 
dYCoordNorm = 2, typeDescKeyPrev_won.faceoff = 0, typeDescKeyPrev_wide.missed.shot.for = 0, 
minSecondsElapsedInShiftAgainst = 26, shooterHeight = 73, typeDescKeyPrev_snap.shot.on.goal.against = 0, 
manDifferential = 0, minSecondsElapsedSinceLastShiftFor = 84, 
shooterPositionCode_D = 0, shotsAgainst = 28, typeDescKeyPrev_wide.missed.shot.against = 0, 
typeDescKeyPrev_wrist.shot.on.goal.against = 0, shotType_tip.in = 0, 
shooterSecondsElapsedInShift = 39, fenwickAgainst = 42, strengthState_penalty.kill = 0, 
secondsElapsedInSequence = 40, typeDescKeyPrev_other.missed.shot.against = 0, 
avgSecondsElapsedInShiftAgainst = 56, yCoordNorm = 2, typeDescKeyPrev_wrist.shot.on.goal.for = 0, 
strengthState_power.play = 0, shotsFor = 27, isBehindNet_yes = 0, 
typeDescKeyPrev_slap.shot.on.goal.against = 0, goalsFor = 3, 
minSecondsElapsedSinceLastShiftAgainst = 79.5, shotDifferential = 0, 
avgSecondsElapsedSinceLastShiftAgainst = 141.75, shooterHandCode_R = 0, 
skaterCountFor = 5, typeDescKeyPrev_post.missed.shot.against = 0, 
typeDescKeyPrev_giveaway.for = 0, typeDescKeyPrev_backhand.shot.on.goal.for = 0, 
dSecondsElapsedInSequence = 9, typeDescKeyPrev_taken.hit = 0), 
    normalize_means = c(distance = 88.1871627898831, angle = 20.1315121152732, 
    xCoordNorm = 5.43409586056645, zoneCode_O = 0.434640522875817, 
    shotType_wrist = 0.769063180827887, dDistancePerSecond = 3.73172164667088, 
    typeDescKeyPrev_takeaway.against = 0.0163398692810458, shotType_snap = 0.0964052287581699, 
    dDistance = 15.8014687880717, corsiFor = 56.2075163398693, 
    shotType_other = 0.0136165577342048, typeDescKeyPrev_blocked.shot.for = 0.0484749455337691, 
    dAngle = -9.13232699145456, typeDescKeyPrev_blocked.shot.against = 0.157952069716776, 
    dYCoordNormPerSecond = 0.466647317036255, dXCoordNormPerSecond = -4.15172162831412, 
    isRush_yes = 0.0833333333333333, shotType_deflected = 0.00163398692810458, 
    typeDescKeyPrev_high.missed.shot.against = 0.00435729847494553, 
    typeDescKeyPrev_takeaway.for = 0.0615468409586057, minSecondsElapsedInShiftFor = 28.6437908496732, 
    typeDescKeyPrev_high.missed.shot.for = 0.000544662309368192, 
    isHome_yes = 0.550653594771242, zoneCode_N = 0.218954248366013, 
    maxSecondsElapsedInShiftAgainst = 90.1350762527233, maxSecondsElapsedInShiftFor = 68.1541394335512, 
    isPlayoff_yes = 0.0718954248366013, typeDescKeyPrev_deflected.shot.on.goal.against = 0.000544662309368192, 
    shotType_slap = 0.0174291938997821, crossedRoyalRoad_yes = 0.467864923747277, 
    shooterPositionCode_R = 0.202069716775599, shooterPositionCode_L = 0.254901960784314, 
    dXCoordNorm = -17.5697167755991, corsiDifferential = -3.6318082788671, 
    avgSecondsElapsedInShiftFor = 46.0640341321714, secondsElapsedInPeriod = 1103.83387799564, 
    shooterWeight = 200.181917211329, typeDescKeyPrev_given.hit = 0.037037037037037, 
    secondsElapsedInGame = 3504.48747276688, typeDescKeyPrev_other.shot.on.goal.against = 0.000544662309368192, 
    skaterCountAgainst = 5.96296296296296, typeDescKeyPrev_giveaway.against = 0.104030501089325, 
    fenwickFor = 41.0076252723312, typeDescKeyPrev_post.missed.shot.for = 0.0103485838779956, 
    isRebound_yes = 0.0206971677559913, corsiAgainst = 59.8393246187364, 
    avgSecondsElapsedSinceLastShiftFor = 136.430001815541, isOvertime_yes = 0.000544662309368192, 
    periodNumber = 3.00054466230937, typeDescKeyPrev_lost.faceoff = 0.0964052287581699, 
    maxSecondsElapsedSinceLastShiftFor = 195.557189542484, shooterAge = 28.328431372549, 
    goalDifferential = 1.70152505446623, fenwickDifferential = -1.01307189542484, 
    maxSecondsElapsedSinceLastShiftAgainst = 220.966775599129, 
    dAnglePerSecond = -2.03163545092558, shooterSecondsElapsedSinceLastShift = 141.507625272331, 
    goalsAgainst = 1.80174291938998, typeDescKeyPrev_tip.in.shot.on.goal.against = 0.00544662309368192, 
    dYCoordNorm = 2.02124183006536, typeDescKeyPrev_won.faceoff = 0.148148148148148, 
    typeDescKeyPrev_wide.missed.shot.for = 0.0419389978213508, 
    minSecondsElapsedInShiftAgainst = 34.2478213507625, shooterHeight = 73.1399782135076, 
    typeDescKeyPrev_snap.shot.on.goal.against = 0.0163398692810458, 
    manDifferential = -0.0392156862745098, minSecondsElapsedSinceLastShiftFor = 89.4242919389978, 
    shooterPositionCode_D = 0.13562091503268, shotsAgainst = 27.7184095860566, 
    typeDescKeyPrev_wide.missed.shot.against = 0.065359477124183, 
    typeDescKeyPrev_wrist.shot.on.goal.against = 0.062636165577342, 
    shotType_tip.in = 0.00871459694989107, shooterSecondsElapsedInShift = 43.9635076252723, 
    fenwickAgainst = 42.020697167756, strengthState_penalty.kill = 0.0610021786492375, 
    secondsElapsedInSequence = 59.4651416122004, typeDescKeyPrev_other.missed.shot.against = 0.00925925925925926, 
    avgSecondsElapsedInShiftAgainst = 62.3196169208425, yCoordNorm = 2.26579520697168, 
    typeDescKeyPrev_wrist.shot.on.goal.for = 0.00326797385620915, 
    strengthState_power.play = 0.0206971677559913, shotsFor = 27.8126361655773, 
    isBehindNet_yes = 0.00217864923747277, typeDescKeyPrev_slap.shot.on.goal.against = 0.0174291938997821, 
    goalsFor = 3.50326797385621, minSecondsElapsedSinceLastShiftAgainst = 86.5065359477124, 
    shotDifferential = 0.0942265795206972, avgSecondsElapsedSinceLastShiftAgainst = 146.344480755265, 
    shooterHandCode_R = 0.342047930283224, skaterCountFor = 4.92374727668845, 
    typeDescKeyPrev_post.missed.shot.against = 0.00599128540305011, 
    typeDescKeyPrev_giveaway.for = 0.0245098039215686, typeDescKeyPrev_backhand.shot.on.goal.for = 0.00108932461873638, 
    dSecondsElapsedInSequence = 14.4673202614379, typeDescKeyPrev_taken.hit = 0.0561002178649237
    ), normalize_sds = c(distance = 53.6100444542208, angle = 17.4929574635285, 
    xCoordNorm = 55.2599752450788, zoneCode_O = 0.495844784728335, 
    shotType_wrist = 0.421546903904294, dDistancePerSecond = 24.7978688935219, 
    typeDescKeyPrev_takeaway.against = 0.126813394460044, shotType_snap = 0.295226578584803, 
    dDistance = 76.7243925540284, corsiFor = 11.216131246985, 
    shotType_other = 0.115924400002255, typeDescKeyPrev_blocked.shot.for = 0.214826119215686, 
    dAngle = 33.405874605476, typeDescKeyPrev_blocked.shot.against = 0.364795414861761, 
    dYCoordNormPerSecond = 10.9751342567029, dXCoordNormPerSecond = 26.7917681875398, 
    isRush_yes = 0.276460698312024, shotType_deflected = 0.040400569499963, 
    typeDescKeyPrev_high.missed.shot.against = 0.0658838115769126, 
    typeDescKeyPrev_takeaway.for = 0.24039613875186, minSecondsElapsedInShiftFor = 21.916599897594, 
    typeDescKeyPrev_high.missed.shot.for = 0.0233380014004673, 
    isHome_yes = 0.497563116468556, zoneCode_N = 0.413650191272091, 
    maxSecondsElapsedInShiftAgainst = 48.1635525424483, maxSecondsElapsedInShiftFor = 36.1888580753221, 
    isPlayoff_yes = 0.258385053601326, typeDescKeyPrev_deflected.shot.on.goal.against = 0.0233380014004672, 
    shotType_slap = 0.130899769870523, crossedRoyalRoad_yes = 0.499102207866331, 
    shooterPositionCode_R = 0.401653350802023, shooterPositionCode_L = 0.435924825627467, 
    dXCoordNorm = 80.2549210804602, corsiDifferential = 19.4077585316867, 
    avgSecondsElapsedInShiftFor = 23.732073682097, secondsElapsedInPeriod = 85.6869797109394, 
    shooterWeight = 15.5681719547181, typeDescKeyPrev_given.hit = 0.188904026035916, 
    secondsElapsedInGame = 83.4117808440893, typeDescKeyPrev_other.shot.on.goal.against = 0.023338001400467, 
    skaterCountAgainst = 0.19736890793884, typeDescKeyPrev_giveaway.against = 0.305383284689608, 
    fenwickFor = 8.58970593737442, typeDescKeyPrev_post.missed.shot.for = 0.101227821687282, 
    isRebound_yes = 0.142407305527925, corsiAgainst = 11.9041494554423, 
    avgSecondsElapsedSinceLastShiftFor = 45.2518971818069, isOvertime_yes = 0.0233380014004672, 
    periodNumber = 0.0233380014004672, typeDescKeyPrev_lost.faceoff = 0.295226578584803, 
    maxSecondsElapsedSinceLastShiftFor = 84.7116120613761, shooterAge = 4.02640845649108, 
    goalDifferential = 0.689522889127525, fenwickDifferential = 14.2781952292712, 
    maxSecondsElapsedSinceLastShiftAgainst = 102.413238280516, 
    dAnglePerSecond = 12.4040747046006, shooterSecondsElapsedSinceLastShift = 77.0580689536785, 
    goalsAgainst = 1.14359594021359, typeDescKeyPrev_tip.in.shot.on.goal.against = 0.0736200340324108, 
    dYCoordNorm = 34.1493607567096, typeDescKeyPrev_won.faceoff = 0.355343563808172, 
    typeDescKeyPrev_wide.missed.shot.for = 0.200504400962461, 
    minSecondsElapsedInShiftAgainst = 29.4002932503624, shooterHeight = 2.09098566110518, 
    typeDescKeyPrev_snap.shot.on.goal.against = 0.126813394460044, 
    manDifferential = 0.288920258638785, minSecondsElapsedSinceLastShiftFor = 37.8365945764699, 
    shooterPositionCode_D = 0.342478856052427, shotsAgainst = 6.64512760208197, 
    typeDescKeyPrev_wide.missed.shot.against = 0.247226426840092, 
    typeDescKeyPrev_wrist.shot.on.goal.against = 0.242373415326444, 
    shotType_tip.in = 0.0929696749621195, shooterSecondsElapsedInShift = 28.9907676275631, 
    fenwickAgainst = 8.98813063849919, strengthState_penalty.kill = 0.239399516719656, 
    secondsElapsedInSequence = 61.8256173330889, typeDescKeyPrev_other.missed.shot.against = 0.0958046166613085, 
    avgSecondsElapsedInShiftAgainst = 34.7772901431202, yCoordNorm = 24.6856894852434, 
    typeDescKeyPrev_wrist.shot.on.goal.for = 0.0570882588216965, 
    strengthState_power.play = 0.142407305527925, shotsFor = 6.32858429705112, 
    isBehindNet_yes = 0.0466378324228981, typeDescKeyPrev_slap.shot.on.goal.against = 0.130899769870524, 
    goalsFor = 1.17024424944335, minSecondsElapsedSinceLastShiftAgainst = 45.055623639711, 
    shotDifferential = 9.8483514658523, avgSecondsElapsedSinceLastShiftAgainst = 53.2909390438439, 
    shooterHandCode_R = 0.474524801614421, skaterCountFor = 0.267519251120546, 
    typeDescKeyPrev_post.missed.shot.against = 0.0771921974448055, 
    typeDescKeyPrev_giveaway.for = 0.154667717708335, typeDescKeyPrev_backhand.shot.on.goal.for = 0.0329959237079672, 
    dSecondsElapsedInSequence = 15.2618032084928, typeDescKeyPrev_taken.hit = 0.230177845658759
    )), ps = list(coefficients = c(`(Intercept)` = -0.780853160081028, 
shotType_other = 0.0374854886988706, goalieWeight = 0.0299253741734925, 
yCoordNorm = 0.0284818528565124, shotType_snap = 0.0249259290776625, 
shooterHandCode_R = -0.0236758893185456, shooterPositionCode_D = -0.0223388143191858, 
isPlayoff_yes = 0.0199466856355296, goalsAgainst = -0.0183804473385284, 
goalsFor = -0.0164524460835742, distance = -0.0156122702729602, 
fenwickDifferential = 0.0149245382082734, fenwickAgainst = -0.014513922004296, 
isHome_yes = 0.013654982345578, angle = -0.0127221762612523, 
shotType_deflected = -0.0109112865771066, shooterPositionCode_L = 0.0101605184964408, 
shooterHeight = -0.00913965125477881, goalieHandCode_R = 0.00882681470881424, 
xCoordNorm = 0.00820518594658108, shooterWeight = -0.00802568774346184, 
corsiAgainst = -0.00766575385917949, shotType_slap = -0.00709296640090848, 
corsiDifferential = 0.00685855166229266, goalieHeight = 0.00601482698906022, 
shooterAge = -0.0058236330928557, goalDifferential = 0.00549980338474507, 
fenwickFor = 0.00525385588164898, goalieAge = 0.00504448533018919, 
shotsAgainst = -0.00438268295869598, shotsFor = -0.00260723728893, 
corsiFor = 0.0015887603073083, shotType_wrist = -0.00147520997341168, 
shotDifferential = 0.0014140598744273, shooterPositionCode_R = -0.000304683893460496
), raw_terms = c("goalieWeight", "yCoordNorm", "goalsAgainst", 
"goalsFor", "distance", "fenwickDifferential", "fenwickAgainst", 
"angle", "shooterHeight", "xCoordNorm", "shooterWeight", "corsiAgainst", 
"corsiDifferential", "goalieHeight", "shooterAge", "goalDifferential", 
"fenwickFor", "goalieAge", "shotsAgainst", "shotsFor", "corsiFor", 
"shotDifferential"), active_dummy_terms = c("shotType_other", 
"shotType_snap", "shooterHandCode_R", "shooterPositionCode_D", 
"isPlayoff_yes", "isHome_yes", "shotType_deflected", "shooterPositionCode_L", 
"goalieHandCode_R", "shotType_slap", "shotType_wrist", "shooterPositionCode_R"
), active_dummy_by_var = list(goalieHandCode = "goalieHandCode_R", 
    isHome = "isHome_yes", isPlayoff = "isPlayoff_yes", shooterHandCode = "shooterHandCode_R", 
    shooterPositionCode = c("shooterPositionCode_D", "shooterPositionCode_L", 
    "shooterPositionCode_R"), shotType = c("shotType_other", 
    "shotType_snap", "shotType_deflected", "shotType_slap", "shotType_wrist"
    )), dummy_term_to_var = c(isPlayoff_yes = "isPlayoff", isPlayoff_unknown = "isPlayoff", 
isPlayoff_new = "isPlayoff", isHome_yes = "isHome", isHome_unknown = "isHome", 
isHome_new = "isHome", shotType_deflected = "shotType", shotType_other = "shotType", 
shotType_slap = "shotType", shotType_snap = "shotType", shotType_wrist = "shotType", 
shotType_unknown = "shotType", shotType_new = "shotType", shooterHandCode_R = "shooterHandCode", 
shooterHandCode_unknown = "shooterHandCode", shooterHandCode_new = "shooterHandCode", 
shooterPositionCode_D = "shooterPositionCode", shooterPositionCode_L = "shooterPositionCode", 
shooterPositionCode_R = "shooterPositionCode", shooterPositionCode_unknown = "shooterPositionCode", 
shooterPositionCode_new = "shooterPositionCode", goalieHandCode_R = "goalieHandCode", 
goalieHandCode_unknown = "goalieHandCode", goalieHandCode_new = "goalieHandCode"
), dummy_term_to_level = c(isPlayoff_yes = "yes", isPlayoff_unknown = "unknown", 
isPlayoff_new = "new", isHome_yes = "yes", isHome_unknown = "unknown", 
isHome_new = "new", shotType_deflected = "deflected", shotType_other = "other", 
shotType_slap = "slap", shotType_snap = "snap", shotType_wrist = "wrist", 
shotType_unknown = "unknown", shotType_new = "new", shooterHandCode_R = "R", 
shooterHandCode_unknown = "unknown", shooterHandCode_new = "new", 
shooterPositionCode_D = "D", shooterPositionCode_L = "L", shooterPositionCode_R = "R", 
shooterPositionCode_unknown = "unknown", shooterPositionCode_new = "new", 
goalieHandCode_R = "R", goalieHandCode_unknown = "unknown", goalieHandCode_new = "new"
), dummy_map = list(goalieHandCode = c(R = "goalieHandCode_R", 
unknown = "goalieHandCode_unknown", new = "goalieHandCode_new"
), isHome = c(yes = "isHome_yes", unknown = "isHome_unknown", 
new = "isHome_new"), isPlayoff = c(yes = "isPlayoff_yes", unknown = "isPlayoff_unknown", 
new = "isPlayoff_new"), shooterHandCode = c(R = "shooterHandCode_R", 
unknown = "shooterHandCode_unknown", new = "shooterHandCode_new"
), shooterPositionCode = c(D = "shooterPositionCode_D", L = "shooterPositionCode_L", 
R = "shooterPositionCode_R", unknown = "shooterPositionCode_unknown", 
new = "shooterPositionCode_new"), shotType = c(deflected = "shotType_deflected", 
other = "shotType_other", slap = "shotType_slap", snap = "shotType_snap", 
wrist = "shotType_wrist", unknown = "shotType_unknown", new = "shotType_new"
)), known_levels = list(isPlayoff = c("no", "yes"), isHome = c("no", 
"yes"), shotType = c("backhand", "deflected", "other", "slap", 
"snap", "wrist"), shooterHandCode = c("L", "R"), shooterPositionCode = c("C", 
"D", "L", "R"), goalieHandCode = c("L", "R")), logical_vars = c("isHome", 
"isPlayoff"), has_unknown = c(goalieHandCode = TRUE, isHome = TRUE, 
isPlayoff = TRUE, shooterHandCode = TRUE, shooterPositionCode = TRUE, 
shotType = TRUE), has_new = c(goalieHandCode = TRUE, isHome = TRUE, 
isPlayoff = TRUE, shooterHandCode = TRUE, shooterPositionCode = TRUE, 
shotType = TRUE), medians = c(shotType_other = 0, goalieWeight = 201, 
yCoordNorm = 0, shotType_snap = 0, shooterHandCode_R = 0, shooterPositionCode_D = 0, 
isPlayoff_yes = 0, goalsAgainst = 3, goalsFor = 3, distance = 13.0384048104053, 
fenwickDifferential = 0, fenwickAgainst = 47, isHome_yes = 1, 
angle = 10.6196552761551, shotType_deflected = 0, shooterPositionCode_L = 0, 
shooterHeight = 73, goalieHandCode_R = 0, xCoordNorm = 76, shooterWeight = 198, 
corsiAgainst = 65, shotType_slap = 0, corsiDifferential = 0, 
goalieHeight = 75, shooterAge = 27, goalDifferential = 0, fenwickFor = 46, 
goalieAge = 28, shotsAgainst = 32, shotsFor = 31, corsiFor = 65, 
shotType_wrist = 1, shotDifferential = 0, shooterPositionCode_R = 0
), normalize_means = c(shotType_other = 0.00251677852348993, 
goalieWeight = 200.947986577181, yCoordNorm = -0.0276845637583893, 
shotType_snap = 0.140939597315436, shooterHandCode_R = 0.417785234899329, 
shooterPositionCode_D = 0.0562080536912752, isPlayoff_yes = 0.000838926174496644, 
goalsAgainst = 3.20721476510067, goalsFor = 3.06208053691275, 
distance = 14.1162288604514, fenwickDifferential = -0.326342281879195, 
fenwickAgainst = 46.9093959731544, isHome_yes = 0.518456375838926, 
angle = 15.8529645126295, shotType_deflected = 0.000838926174496644, 
shooterPositionCode_L = 0.202181208053691, shooterHeight = 72.7298657718121, 
goalieHandCode_R = 0.0553691275167785, xCoordNorm = 75.6870805369127, 
shooterWeight = 197.462248322148, corsiAgainst = 64.3464765100671, 
shotType_slap = 0.00419463087248322, corsiDifferential = -0.278523489932886, 
goalieHeight = 74.8859060402685, shooterAge = 27.3951342281879, 
goalDifferential = -0.145134228187919, fenwickFor = 46.5830536912752, 
goalieAge = 28.4840604026846, shotsAgainst = 31.8724832214765, 
shotsFor = 31.5444630872483, corsiFor = 64.0679530201342, shotType_wrist = 0.656040268456376, 
shotDifferential = -0.328020134228188, shooterPositionCode_R = 0.275167785234899
), normalize_sds = c(shotType_other = 0.0501253647882481, goalieWeight = 16.1798969079781, 
yCoordNorm = 4.24284713524948, shotType_snap = 0.348105280082041, 
shooterHandCode_R = 0.493401423541137, shooterPositionCode_D = 0.230419725085298, 
isPlayoff_yes = 0.0289642223181745, goalsAgainst = 1.49721766948129, 
goalsFor = 1.446326607353, distance = 5.90127586207415, fenwickDifferential = 14.9971744568645, 
fenwickAgainst = 11.4025721745455, isHome_yes = 0.499868966651878, 
angle = 16.2204685269784, shotType_deflected = 0.0289642223181745, 
shooterPositionCode_L = 0.401795225089013, shooterHeight = 2.11249864561555, 
goalieHandCode_R = 0.228795329404374, xCoordNorm = 6.23499246320141, 
shooterWeight = 15.0218508961002, corsiAgainst = 14.5048677431509, 
shotType_slap = 0.0646571195721434, corsiDifferential = 19.4936216441126, 
goalieHeight = 1.59777427619789, shooterAge = 4.43943209529498, 
goalDifferential = 0.677013604807505, fenwickFor = 11.096166828729, 
goalieAge = 3.7245297515799, shotsAgainst = 8.1947648424196, 
shotsFor = 8.01246108938845, corsiFor = 14.1606915577925, shotType_wrist = 0.475227207197835, 
shotDifferential = 10.6112412917972, shooterPositionCode_R = 0.446786235148888
)))
