% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/Clean.R
\name{.require_shift_chart_columns}
\alias{.require_shift_chart_columns}
\title{Validate required shift-chart columns}
\usage{
.require_shift_chart_columns(shift_chart, cols, fn_name)
}
\arguments{
\item{shift_chart}{data.frame shift chart object}

\item{cols}{character vector of required columns}

\item{fn_name}{calling function name used in the error message}
}
\value{
\code{NULL}, invisibly, or an error if required columns are missing
}
\description{
\code{.require_shift_chart_columns()} errors when a helper is called with a shift
chart missing required public schema columns.
}
\keyword{internal}
