% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/Game.R
\name{.lookup_roster_player_id}
\alias{.lookup_roster_player_id}
\title{Resolve a roster player ID}
\usage{
.lookup_roster_player_id(
  roster_lookup,
  team_id,
  sweater_number,
  player_name = NA_character_
)
}
\arguments{
\item{roster_lookup}{standardized roster lookup data.frame}

\item{team_id}{team ID}

\item{sweater_number}{sweater number}

\item{player_name}{optional player name}
}
\value{
integer player ID or \code{NA_integer_}
}
\description{
\code{.lookup_roster_player_id()} resolves a player ID from team, sweater number,
and optional name information within a roster lookup table.
}
\keyword{internal}
