% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/TeamOld.R
\name{get_team_roster}
\alias{get_team_roster}
\title{Access the roster for a team, season, and player type}
\usage{
get_team_roster(team = "NJD", season = "current", player_type = "forwards")
}
\arguments{
\item{team}{three-letter code (e.g., 'COL'); see \code{\link[=teams]{teams()}} for reference}

\item{season}{integer in YYYYYYYY (e.g., 20242025); see \code{\link[=seasons]{seasons()}} for
reference}

\item{player_type}{character of 'forwards', 'defensemen', or 'goalies'}
}
\value{
data.frame with one row per player
}
\description{
\code{get_team_roster()} is deprecated. Use \code{\link[=roster]{roster()}} instead.
}
