% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/Game.R
\name{.assign_html_on_ice_player_ids}
\alias{.assign_html_on_ice_player_ids}
\title{Assign resolved HTML on-ice IDs to scalar columns}
\usage{
.assign_html_on_ice_player_ids(
  play_by_play,
  idx,
  home_goalie,
  away_goalie,
  home_skaters,
  away_skaters
)
}
\arguments{
\item{play_by_play}{data.frame play-by-play object}

\item{idx}{row index to update}

\item{home_goalie}{resolved home goalie player ID}

\item{away_goalie}{resolved away goalie player ID}

\item{home_skaters}{integer vector of resolved home skater IDs}

\item{away_skaters}{integer vector of resolved away skater IDs}
}
\value{
data.frame with scalar on-ice player-ID columns assigned for \code{idx}
}
\description{
\code{.assign_html_on_ice_player_ids()} copies resolved HTML goalie and skater IDs
into the public scalar on-ice player-ID columns for one play-by-play row.
}
\keyword{internal}
