% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/Clean.R
\name{.assign_on_ice_shift_metric}
\alias{.assign_on_ice_shift_metric}
\title{Assign scalar on-ice timing metrics}
\usage{
.assign_on_ice_shift_metric(
  play_by_play,
  home_matrix,
  away_matrix,
  metric_suffix
)
}
\arguments{
\item{play_by_play}{data.frame play-by-play object}

\item{home_matrix}{numeric matrix for home on-ice players}

\item{away_matrix}{numeric matrix for away on-ice players}

\item{metric_suffix}{scalar timing suffix}
}
\value{
data.frame with timing columns assigned
}
\description{
\code{.assign_on_ice_shift_metric()} copies goalie and skater timing matrices into
home, away, for, and against scalar play-by-play columns.
}
\keyword{internal}
