% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/Clean.R
\name{add_goalie_biometrics}
\alias{add_goalie_biometrics}
\title{Add goalie biometrics to (a) play-by-play(s)}
\usage{
add_goalie_biometrics(play_by_play)
}
\arguments{
\item{play_by_play}{data.frame of play-by-play(s) using the current public schema returned by \code{\link[=gc_play_by_play]{gc_play_by_play()}}, \code{\link[=gc_play_by_plays]{gc_play_by_plays()}}, \code{\link[=wsc_play_by_play]{wsc_play_by_play()}}, or \code{\link[=wsc_play_by_plays]{wsc_play_by_plays()}}}
}
\value{
data.frame with one row per event (play) and added columns: \code{goalieHeight}, \code{goalieWeight}, \code{goalieHandCode}, and \code{goalieAge}
}
\description{
\code{add_goalie_biometrics()} adds goalie biometrics (height, weight, hand, and age at game date) to (a) play-by-play(s) for shot attempts. Goalie identity is resolved from \code{goalieInNetId} first and \code{goaliePlayerIdAgainst} second. If neither is available on a row, the added goalie biometrics are left as \code{NA}.
}
