% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/Game.R
\name{.match_html_pbp_to_api}
\alias{.match_html_pbp_to_api}
\title{Match HTML play-by-play rows to API rows}
\usage{
.match_html_pbp_to_api(play_by_play, html_rows)
}
\arguments{
\item{play_by_play}{data.frame API play-by-play object}

\item{html_rows}{data.frame parsed HTML play-by-play rows}
}
\value{
data.frame of matched HTML rows with \code{apiIndex}
}
\description{
\code{.match_html_pbp_to_api()} aligns parsed HTML play-by-play rows back to API
play-by-play rows using exact keys, greedy scoring, and a reciprocal-best
fallback for duplicate clusters.
}
\keyword{internal}
