% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/Game.R
\name{.supported_strength_event_types}
\alias{.supported_strength_event_types}
\title{List strength-context event types}
\usage{
.supported_strength_event_types()
}
\value{
character vector of supported event type keys
}
\description{
\code{.supported_strength_event_types()} returns the event types that support the
HTML row-matching pipeline.
}
\keyword{internal}
