% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/Game.R
\name{.supported_html_on_ice_id_event_types}
\alias{.supported_html_on_ice_id_event_types}
\title{List HTML on-ice player-ID event types}
\usage{
.supported_html_on_ice_id_event_types()
}
\value{
character vector of supported on-ice player-ID event type keys
}
\description{
\code{.supported_html_on_ice_id_event_types()} returns the event types that are
allowed to receive HTML-derived on-ice player IDs.
}
\keyword{internal}
