% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/Game.R
\name{.html_event_code_to_type_desc}
\alias{.html_event_code_to_type_desc}
\title{Map HTML event codes to event type keys}
\usage{
.html_event_code_to_type_desc(event_code, description = NA_character_)
}
\arguments{
\item{event_code}{HTML event code}

\item{description}{optional HTML event description}
}
\value{
event type key or \code{NA_character_}
}
\description{
\code{.html_event_code_to_type_desc()} converts HTML report event codes and select
description fallbacks into internal play-by-play event type keys.
}
\keyword{internal}
