% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/Clean.R
\name{.parse_situation_code_components}
\alias{.parse_situation_code_components}
\title{Parse situation-code components}
\usage{
.parse_situation_code_components(situation_code)
}
\arguments{
\item{situation_code}{vector of raw situation codes}
}
\value{
integer matrix with away/home goalie and skater counts
}
\description{
\code{.parse_situation_code_components()} converts situation codes into away/home
goalie and skater counts without mutating the original source vector.
}
\keyword{internal}
