% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/Clean.R
\name{.normalize_situation_code_for_parse}
\alias{.normalize_situation_code_for_parse}
\title{Normalize situation codes for parsing}
\usage{
.normalize_situation_code_for_parse(situation_code)
}
\arguments{
\item{situation_code}{vector of raw situation codes}
}
\value{
character vector of parse-ready situation codes
}
\description{
\code{.normalize_situation_code_for_parse()} pads 1-4 digit situation codes to
four characters for internal parsing without rewriting the source column.
}
\keyword{internal}
