% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/League.R
\name{standings}
\alias{standings}
\title{Access the standings for a date}
\usage{
standings(date = "now")
}
\arguments{
\item{date}{character in 'YYYY-MM-DD' (e.g., '2025-01-01'); see
\code{\link[=seasons]{seasons()}} for reference}
}
\value{
data.frame with one row per team
}
\description{
\code{standings()} retrieves the standings for a date as a \code{data.frame} where each row represents team and includes detail on date/season filtering windows and chronological context, production, workload, efficiency, and result-level performance outcomes, and ranking movement, points pace, and division/conference position signals.
}
\examples{
standings_Halloween_2025 <- standings(date = '2025-10-31')
}
