% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/Skater.R
\name{skater_report_configurations}
\alias{skater_report_configurations}
\alias{skater_report_configs}
\title{Access the configurations for skater reports}
\usage{
skater_report_configurations()

skater_report_configs()
}
\value{
list with various items
}
\description{
\code{skater_report_configurations()} retrieves the configurations for skater reports as a nested \code{list} that separates summary and detail blocks for production, workload, efficiency, and result-level performance outcomes, situational splits across home/road, strength state, and overtime/shootout states, and configuration catalogs for valid report categories and filters.
}
\examples{
skater_report_configs <- skater_report_configurations()
}
