% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/ESPNGame.R
\name{espn_game_summary}
\alias{espn_game_summary}
\title{Access the ESPN summary for a game}
\usage{
espn_game_summary(game = 401777460)
}
\arguments{
\item{game}{integer ID (e.g., 401777460); see \code{\link[=espn_games]{espn_games()}} for
reference}
}
\value{
list with various items
}
\description{
\code{espn_game_summary()} retrieves the ESPN summary for a game as a nested \code{list} that separates summary and detail blocks for date/season filtering windows and chronological context, venue/location geography and regional metadata, and playoff-series progression, round status, and series leverage.
}
\examples{
ESPN_summary_SCF_20242025 <- espn_game_summary(game = 401777460)
}
