% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/Goalie.R
\name{goalie_game_statistics}
\alias{goalie_game_statistics}
\alias{goalie_game_stats}
\title{Access the statistics for all the goalies by game}
\usage{
goalie_game_statistics()

goalie_game_stats()
}
\value{
data.frame with one row per goalie per game
}
\description{
\code{goalie_game_statistics()} retrieves the statistics for all the goalies by game as a \code{data.frame} with detail on game timeline state, period/clock progression, and matchup flow, date/season filtering windows and chronological context, and team identity, affiliation, and matchup-side context.
}
\examples{
\donttest{goalie_game_stats <- goalie_game_statistics()}
}
