% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/Clean.R
\name{.compute_on_ice_shift_timing_matrices}
\alias{.compute_on_ice_shift_timing_matrices}
\title{Compute on-ice shift timing matrices}
\usage{
.compute_on_ice_shift_timing_matrices(play_by_play, shift_data)
}
\arguments{
\item{play_by_play}{data.frame play-by-play object with on-ice player IDs}

\item{shift_data}{data.frame shift chart data}
}
\value{
list containing home and away timing matrices
}
\description{
\code{.compute_on_ice_shift_timing_matrices()} uses the native timing resolver
when available and falls back to the R implementation otherwise.
}
\keyword{internal}
