% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/Game.R
\name{.empty_public_pbp_column}
\alias{.empty_public_pbp_column}
\title{Allocate a missing public play-by-play column}
\usage{
.empty_public_pbp_column(name, n)
}
\arguments{
\item{name}{public play-by-play column name}

\item{n}{output row count}
}
\value{
typed vector of missing values
}
\description{
\code{.empty_public_pbp_column()} returns a typed \code{NA} vector for a public
play-by-play column that is absent in the upstream source data.
}
\keyword{internal}
