% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/Clean.R
\name{.drop_illogical_ordered_events}
\alias{.drop_illogical_ordered_events}
\title{Remove illogically ordered boundary events from a play-by-play}
\usage{
.drop_illogical_ordered_events(play_by_play)
}
\arguments{
\item{play_by_play}{data.frame of play-by-play(s); see \code{\link[=gc_play_by_play]{gc_play_by_play()}} and/or \code{\link[=wsc_play_by_play]{wsc_play_by_play()}} for reference}
}
\value{
data.frame with illogically ordered boundary events removed
}
\description{
\code{.drop_illogical_ordered_events()} removes stray boundary rows that can
appear between a period's \code{period-end} and the following period's
\code{period-start}. In practice, these are most often duplicated \code{0:00}
\code{faceoff}/\code{stoppage} rows that are still tagged to the previous period even
though the actual opening sequence for the next period follows immediately
after.
}
\keyword{internal}
