% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/Clean.R
\name{.add_on_ice_shift_timing_context}
\alias{.add_on_ice_shift_timing_context}
\title{Add on-ice shift timing context}
\usage{
.add_on_ice_shift_timing_context(play_by_play, game, shift_data = NULL)
}
\arguments{
\item{play_by_play}{data.frame play-by-play object with on-ice player IDs}

\item{game}{game ID}

\item{shift_data}{optional shift chart data.frame}
}
\value{
data.frame with scalar on-ice timing columns added
}
\description{
\code{.add_on_ice_shift_timing_context()} enriches play-by-play rows with scalar
shift elapsed and since-last-shift columns for the on-ice goalies and
skaters.
}
\keyword{internal}
