% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/Clean.R
\name{.public_pbp_legal_period_seconds}
\alias{.public_pbp_legal_period_seconds}
\title{Derive the legal period length in seconds}
\usage{
.public_pbp_legal_period_seconds(game_id, game_type_id, period)
}
\arguments{
\item{game_id}{integer game IDs}

\item{game_type_id}{integer game type IDs}

\item{period}{integer period numbers}
}
\value{
integer vector of legal period lengths in seconds
}
\description{
\code{.public_pbp_legal_period_seconds()} returns the nominal legal length for each
play-by-play row's period under the relevant game context.
}
\keyword{internal}
