% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/Clean.R
\name{.ensure_local_native_symbol}
\alias{.ensure_local_native_symbol}
\title{Ensure a native symbol is available}
\usage{
.ensure_local_native_symbol(symbol)
}
\arguments{
\item{symbol}{native symbol name}
}
\value{
logical scalar indicating whether the symbol is available
}
\description{
\code{.ensure_local_native_symbol()} checks whether a native symbol is already
registered and, if needed, tries to load the installed package shared object.
It does not trust the current working directory.
}
\keyword{internal}
