% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/Game.R
\name{boxscore}
\alias{boxscore}
\title{Access the boxscore for a game, team, and position}
\usage{
boxscore(game = 2023030417, team = "home", position = "forwards")
}
\arguments{
\item{game}{integer ID (e.g., 2025020275); see \code{\link[=games]{games()}} for reference}

\item{team}{character of 'h'/'home' or 'a'/'away'}

\item{position}{character of 'f'/'forwards', 'd'/'defensemen', or
'g'/'goalies'}
}
\value{
data.frame with one row per player
}
\description{
\code{boxscore()} retrieves the boxscore for a game, team, and position as a \code{data.frame} where each row represents player and includes detail on player identity, role, handedness, and biographical profile plus production, workload, efficiency, and result-level performance outcomes.
}
\examples{
boxscore_COL_forwards_Martin_Necas_legacy_game <- boxscore(
  game     = 2025020275,
  team     = 'H',
  position = 'F'
)
}
