% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/Game.R
\name{.override_strength_context_from_html}
\alias{.override_strength_context_from_html}
\title{Override derived strength context from resolved on-ice players}
\usage{
.override_strength_context_from_html(
  play_by_play,
  idx,
  home_goalie,
  away_goalie,
  home_skaters,
  away_skaters
)
}
\arguments{
\item{play_by_play}{data.frame play-by-play object}

\item{idx}{row index to update}

\item{home_goalie}{resolved home goalie player ID}

\item{away_goalie}{resolved away goalie player ID}

\item{home_skaters}{integer vector of resolved home skater IDs}

\item{away_skaters}{integer vector of resolved away skater IDs}
}
\value{
data.frame with derived strength context updated for \code{idx}
}
\description{
\code{.override_strength_context_from_html()} updates the derived strength/count
columns from a resolved HTML on-ice signature while leaving the raw
\code{situationCode} column untouched.
}
\keyword{internal}
