% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/Clean.R
\name{.require_public_pbp_columns}
\alias{.require_public_pbp_columns}
\title{Validate required public play-by-play columns}
\usage{
.require_public_pbp_columns(play_by_play, cols, fn_name)
}
\arguments{
\item{play_by_play}{data.frame play-by-play object}

\item{cols}{character vector of required columns}

\item{fn_name}{calling function name used in the error message}
}
\value{
\code{NULL}, invisibly, or an error if required columns are missing
}
\description{
\code{.require_public_pbp_columns()} errors when a public helper is called with a
play-by-play missing required public schema columns.
}
\keyword{internal}
