% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/TeamOld.R
\name{get_team_scoreboard}
\alias{get_team_scoreboard}
\title{Access the team scoreboard as of now}
\usage{
get_team_scoreboard()
}
\description{
\code{get_team_scoreboard()} is defunct.
}
