% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/Game.R
\name{.build_game_roster_lookup}
\alias{.build_game_roster_lookup}
\title{Build a game-roster lookup table}
\usage{
.build_game_roster_lookup(rosters)
}
\arguments{
\item{rosters}{roster data.frame from the game play-by-play metadata}
}
\value{
standardized roster lookup data.frame
}
\description{
\code{.build_game_roster_lookup()} standardizes roster columns and prepares a
lookup table used to resolve HTML sweater numbers to player IDs.
}
\keyword{internal}
