% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/Clean.R
\name{.apply_pbp_delta_columns}
\alias{.apply_pbp_delta_columns}
\title{Attach delta context columns to play-by-play}
\usage{
.apply_pbp_delta_columns(play_by_play, delta_ctx)
}
\arguments{
\item{play_by_play}{data.frame of play-by-play(s) using the current public schema returned by \code{\link[=gc_play_by_play]{gc_play_by_play()}}, \code{\link[=gc_play_by_plays]{gc_play_by_plays()}}, \code{\link[=wsc_play_by_play]{wsc_play_by_play()}}, or \code{\link[=wsc_play_by_plays]{wsc_play_by_plays()}}}

\item{delta_ctx}{named list returned by \code{.compute_pbp_deltas()}}
}
\value{
data.frame with public delta columns inserted
}
\description{
\code{.apply_pbp_delta_columns()} inserts computed delta columns into a
play-by-play and reorders them into the public schema.
}
\keyword{internal}
