% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/Game.R
\name{.finalize_pbp_output}
\alias{.finalize_pbp_output}
\title{Finalize public play-by-play output}
\usage{
.finalize_pbp_output(play_by_play, source = c("gc", "wsc"))
}
\arguments{
\item{play_by_play}{data.frame play-by-play object}

\item{source}{output source, either \code{"gc"} or \code{"wsc"}}
}
\value{
data.frame with the finalized public play-by-play schema
}
\description{
\code{.finalize_pbp_output()} selects and orders the final GC or WSC public
play-by-play column set.
}
\keyword{internal}
