% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/Clean.R
\name{.apply_shot_context}
\alias{.apply_shot_context}
\title{Attach shot context columns to play-by-play}
\usage{
.apply_shot_context(play_by_play)
}
\arguments{
\item{play_by_play}{data.frame play-by-play object}
}
\value{
data.frame with shot context columns added
}
\description{
\code{.apply_shot_context()} appends rush, rebound, and running score/attempt
context columns to a play-by-play.
}
\keyword{internal}
