% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/Clean.R
\name{.shot_event_mask}
\alias{.shot_event_mask}
\title{Build a shot-event mask}
\usage{
.shot_event_mask(play_by_play, types)
}
\arguments{
\item{play_by_play}{data.frame play-by-play object}

\item{types}{character vector of event type keys to keep}
}
\value{
logical vector
}
\description{
\code{.shot_event_mask()} flags play-by-play rows matching selected event types.
}
\keyword{internal}
