% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/ESPNPlayer.R
\name{espn_player_summary}
\alias{espn_player_summary}
\title{Access the ESPN summary for a player}
\usage{
espn_player_summary(player = 3988803)
}
\arguments{
\item{player}{integer ID (e.g., 3988803); see \code{\link[=espn_players]{espn_players()}} for
reference}
}
\value{
data.frame with one row
}
\description{
\code{espn_player_summary()} retrieves the ESPN summary for a player as a \code{data.frame} where each row represents one result and includes detail on game timing, matchup state, scoring flow, and situational event detail.
}
\examples{
ESPN_summary_Charlie_McAvoy <- espn_player_summary(player = 3988803)
}
