% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/Game.R
\name{.mask_strength_context_block}
\alias{.mask_strength_context_block}
\title{Mask HTML on-ice columns on unsupported events}
\usage{
.mask_strength_context_block(play_by_play)
}
\arguments{
\item{play_by_play}{data.frame play-by-play object}
}
\value{
data.frame with unsupported rows masked
}
\description{
\code{.mask_strength_context_block()} sets HTML-derived on-ice player-ID and
timing columns to \code{NA} on event types that are not supported by the HTML
on-ice player pipeline.
}
\keyword{internal}
