% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/Clean.R
\name{.public_pbp_is_shootout_eligible}
\alias{.public_pbp_is_shootout_eligible}
\title{Identify shootout-eligible games for public play-by-play cleanup}
\usage{
.public_pbp_is_shootout_eligible(game_id, game_type_id)
}
\arguments{
\item{game_id}{integer game IDs}

\item{game_type_id}{integer game type IDs}
}
\value{
logical vector
}
\description{
\code{.public_pbp_is_shootout_eligible()} returns \code{TRUE} for games whose overtime
rules follow the regular-season shootout path.
}
\keyword{internal}
