% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/Game.R
\name{.parallel_request_failed}
\alias{.parallel_request_failed}
\title{Check whether a parallel request failed}
\usage{
.parallel_request_failed(resp)
}
\arguments{
\item{resp}{response or failure object}
}
\value{
logical scalar
}
\description{
\code{.parallel_request_failed()} returns \code{TRUE} when a response object from
\code{.perform_parallel_requests()} is an httr2 failure.
}
\keyword{internal}
