% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/Game.R
\name{.optional_html_pbp_rows_from_response}
\alias{.optional_html_pbp_rows_from_response}
\title{Parse optional HTML on-ice rows from a parallel response}
\usage{
.optional_html_pbp_rows_from_response(
  resp,
  game,
  rosters,
  home_team_id,
  away_team_id,
  home_abbrev,
  away_abbrev
)
}
\arguments{
\item{resp}{response or failure object}

\item{game}{game ID}

\item{rosters}{roster data.frame from play-by-play metadata}

\item{home_team_id}{home-team ID}

\item{away_team_id}{away-team ID}

\item{home_abbrev}{home-team abbreviation}

\item{away_abbrev}{away-team abbreviation}
}
\value{
data.frame of parsed HTML rows or an empty data.frame
}
\description{
\code{.optional_html_pbp_rows_from_response()} parses a fetched HTML play-by-play
response when it succeeded and otherwise returns an empty data frame.
}
\keyword{internal}
