% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/Clean.R
\name{.format_elapsed_clock}
\alias{.format_elapsed_clock}
\title{Format elapsed seconds as an \code{MM:SS} clock}
\usage{
.format_elapsed_clock(seconds)
}
\arguments{
\item{seconds}{integer/numeric vector of elapsed seconds}
}
\value{
character vector
}
\description{
\code{.format_elapsed_clock()} converts elapsed-in-period seconds back into
zero-padded \code{MM:SS} strings.
}
\keyword{internal}
