% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/PlayoffOld.R
\name{get_series}
\alias{get_series}
\title{Access the playoff series for a season and round}
\usage{
get_series()
}
\description{
\code{get_series()} is defunct.
}
